## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Nb v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Nb::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Nb

=head1 NAME

TeX::Hyphen::Pattern::Nb - class for hyphenation in locale Nb

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
title: Hyphenation patterns for Norwegian, bokmål
copyright: Copyright (C) 2004–2005 Rune Kleveland, Ole Michael Selberg, 2007 Karl Ove Hufthammer
notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information.
language:
    name: Norwegian Bokmål, bokmål, norsk bokmål
    tag: nb
authors:
    - name: Rune Kleveland
    - name: Ole Michael Selberg
    - name: Karl Ove HuftHammer
version: 2007-02-10
licence:
    text: >
        Copying and distribution of this file, with or without modification,
        are permitted in any medium without royalty, provided the copyright
        notice and this notice are preserved.
hyphenmins:
    typesetting:
        left: 2
        right: 2
texlive:
    synonyms:
        - norwegian
        - norsk
    encoding: ec
    babelname: bokmal
    message: Norwegian Bokmal hyphenation patterns
    package: norwegian
==========================================
This file contains hyphenation patterns for Norwegian Bokmål.
It uses the Norwegian hyphenation patterns from hyph-no.tex,
created by Rune Kleveland and Ole Michael Selberg. Please see
that file for copyright information on those patterns.

The patterns in hyph-no.tex are based on both Norwegian Bokmål
and Norwegian Nynorsk, and works about equally well for both
languages. This file, hyph-nb.tex, contains only a few hyphenation
exceptions, for words that needs to be hyphenated differently for
the two languages.

Please send bugs or suggestions to karl@huftis.org.
=end text

=cut

__DATA__
\input hyph-no.tex
\hyphenation{
at-ten-de
be-tre
}
