## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Mk v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Mk::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Mk

=head1 NAME

TeX::Hyphen::Pattern::Mk - class for hyphenation in locale Mk

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
title: Hyphenation patterns for Macedonian
copyright: Copyright (C) 2006 Vasil Taneski
notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information.
licence:
    - name: GPL
language:
    name: Macedonian
    tag: mk
hyphenmins:
    typesetting:
        left: 2
        right: 2
version: 0.1
authors:
    -
        name: Vasil Taneski
        contact: vasil (dot) taneski (at) gmail (dot) com
changes:
    - Last change 2006-09-26
texlive:
    babelname: macedonian
    message: Macedonian hyphenation patterns
    description: |-
        Hyphenation patterns for Macedonian
=end text

=cut

__DATA__
\patterns{
.б2
.в2
.вр5зан.
.г2
.д2
.др5жат
.др5жи.
.з2
.к2
.м2
.ос3в
.ос3л
.п2
.пос2
.по3ср
.по5ста
.по5ств
.с2
.стап5к
.т2
.ш2
а1а
аб1л
аб1р2
а1ва
а1ве
ав1л
а1во
ав1р2
ав1т
аг1л
аг1р
ад1в
ад1л
ад1р
а1е
а1жа
а1жи
а1жу
аз1д
а1зу
а1и
а1ји
а1ка
ак1в
а1ки
ак1л
а1ко
ак1р
а1ла
а1ле
а1ло
а1лу
а1м
а1о
а1па
а1пе
а3пкат
а3пки
ап1л
ап1р
а1ра
ар1в
ар1д
а1ре
а1ри
ар1л
а1ро
арт2
ар3тн
ар3ту
а1ру
ас1в
ас1к
ас1л
ас1п
ас1р
ас1т
а1т
а2т1в
а2тн
а2т1р
а1у
а1фа
а1фо
ах1р
а2ц1р
ач1л
аш1т
1ба
б1в
б1д
1бе
б1з
1би
2б1ј
б1м
б1н
1бо
б1р2н
1бу
в1г
в1д
в2з
1ви
в2ју
в1ка
в1ки
в1м
2в1н
2вњ
вос1
в1па
вр3ве
вр2з
в1ро
вр4скат
вр4скит
вр2х
2в1с
в1тр
1ву
в1ш
1га
г2б
г1в
1ге
г1з
1ги
г1м
3г4нато
1го
гос3л
г1рв
гр4цит
1гу
1да
да2с
д1б
д1ве
д1вл
д1вр
д1г
д1д
1де
д1з
1ди
4дицио
д1ј
д1к
д1ле
д1ло
д1лу
д1м
д1н
3д2нив
1до
до5з4нае
дос3л
д1п
д1ре
д1ри
д1с2
д1т2
1ду
1ѓ
е1а
еб1л
еб1р
е1ва
е1ве
ев1к
е1во
ев1р
ег1л
ег1р
ед1в
ед4нот
ед1р
е1е
е1жа
е1жи
е1жу
ез1г
е1зу
2е1и
е1ка
ек1в
е1ки
ек1л
е1ко
ек1р
е1ла
е1ле
е1ло
е1лу
е1м
ем1р
е2м1с
е1о
е1па
е1пе
еп1к
еп1л
епос3р
епо4ст
еп1р
е1ра
ер1в
е1ре
ер1з
е1ри
е1ро
ер1п
е1ру
ес1в
ес1к
ес1л
ес1п
ес1р
ес1т
е1та
ет1в
е1те
ет1р
е1ту
е1у
е1фо
еф1р2
ех1р
еш1т
ж1б
ж1д
1же
жи1
ж1ј
ж2л
2ж1н
1жо
ж1т
1за
зб2
збе3с
з1бр
з1в
звр2
з1гл
зд2
з1дн
1зе
1зи
з1ј
з1ле
з1м
1зо
з1ре
з1ри
1ѕ
и1а
иб1р
и1ва
и1ве
ив1к
ив1л
и1во
ив1р
ив1т
иг1л
иг1р
ид1р
и1е
и1ж
из1г
из1д
из1л
из1р
и1зу
и1и
и1ј
и1к
и2кв
и2к1л
и2кн
и2к1р
и2кт
и1ла
и1ле
и1ло
и1лу
им1с
и2нс
и1о
и1па
и1пе
ип1к
ип1л
ип1р
и1р
и2рг
и2рл
и2рн
и2р1т
ис1к
ис1л
ис1п
ис3т2
и1т
и2тн
и2т1р
и1у
и1ф
и1х
и2ш1т
1ја
ј1б2
ј1в
ј1г
ј1д2
1је
ј1ж
ј1з2
2ј1к
ј1л
ј1м2
ј3мн
ј1н2
1јо
ј1п
јпо4с3
ј1р
2ј1с
2ј1т
2јќ
1ју
ј1ф
2јц
ј1ч
2јш2
ј1шт
1кам
кап3к
1кар
к1ве
к1во
1ке
к2ј
кл2
к1ле
к1лс
к1м
к1р2д
кр2с
кр1ш
кр2ше
кр2ши
2к1с2
к1т2
2кт.
1ку
к1ф
л1б
л1в
л1г
л1д
л1ж
л1з
1ли
л1ј
л1к2
л1м
л1н
л1п
л1с2
л1т
л1ф
л1ч2
л1ш
1љ
ља1
1ма
2м1б
2м1в
м1д
1ме
1ми
2м1ј
2м1к
2мн
1мо
2м1п2
2мр
м3рм
мр2т
мр3т2в
м1ст
2м1т2
м3тл
1му
м1ф
м1ч
м1ш
1на
н1б
н1в
н1г2
2н1д2
1не
н1ж2
н1з
1ни
2н1к2
н1л
н1м
1но
н1п2
н1р
н1с2
2н1т2
н3тс
1ну
н1ф2
н1х
2нц
н1ч
1њ
ња1
њас2
ње1
о1а
об1л
об1р2
о1ва
о1ве
ов1л
о1во
ов1р2
ов1т
ог1л
ог1р
од1в
од1л
од1р
о1е
о1жа
о1жи
ож1р
о1жу
оз1д
оз1р
о1зу
о1и
о1ка
ок1в
о1ки
ок1л
о1ко
ок1р
о1ла
о1ле
о1ло
о1лу
ом1р
ом1с
о1о
о1па
о1пе
оп1к
оп1л
оп1р
о1ра
о1ре
о1ри
о1ро
ор3та
о1ру
ос3во
осле3
ослед4
ос3ло
ослу3
ос1п
осре3
осред4
ос1т
ос5тави
оста5пк
о1та
от1в
отвр2
о1те
от1р2
о1ту
о1у
о1ф
о1хе
ох1р
о2ц1р2
ош1т
1пи
п1ко
п1кр
п1н
1по
по3св
по3ск
по3сл
по3с2м
по3сп
по3сти3
постиг4
по3сто
пр2в
пр2к
п1с2
п1т
1пу
п1ф
п1х
п1ч
п1ш2
р1б2
р2биј
р1вј
рв1т
р1г2
рд2
р2да.
р2дил
р2дим
р2ду
рз2
р2зат
р2зин
р3зно
2р1к2
р2кн
р1ло
2р1м2
р3мн
р2мо
р1н
рос3в
р1па
рп2л
р1с2
рт1в
рт4вит
рт2ву
р3теа
р2тин
р2тио
рт2л
рт2ни
р2тов
р1тр
р1ф
р1х
рч2
р2ча
рш2
р2шеш
р2шим
р2шу
1са
свр3зе
1се
1си
с1ј
ск2
с1кн
сма3т
с2мел
с1н
с2наа
1со
с2пок
с1рд
2ст.
3ставт
3стапк
ст2в
3степ
2стеш
с1т2н
с2тт
1су
с1фр2
с1хр
сцр2
с1ч
1та.
2тапк
т1г
2т1д
1теж
2теп
1ти
2т1к
2т1л
2т1м
1то
2тоел
2тоеч
2тоја
2т1п
т2ра.
тр2в
тр1л
тр2п
2т1с2
т1т
ттр2
т1ф
тфр2
т1х
2т1ч
1ќ
ќа1
2ќ1н
2ќ1т
у1а
уб1л
уб1р
у1в
у2в1р
уг1л
уг1р
уд1р
у1е
у1жа
у1жи
у1жу
у1и
у1ка
ук1в
у1ки
ук1л
ук1р
у1ла
у1ле
у1ло
у1лу
ум1р
ум1с
у1н
у1о
у1па
у1пе
уп1к
уп1л
уп1р
у1ра
ур1д
у1ре
у1ри
у1ро
у1ру
ус1к
ус1л
ус1п
ус1т
у1та
ут1в
утвр2
у1те
ут1р
уф1
у1х
у1ч
уш4ниц
уш4но.
уш1т
1фе
1фи
ф1к
фл2
ф1ле
ф2н
ф1ри
ф1ро
2ф1с
ф1т
1ха
1хи
х1м
х1н
1хо
х1т
1ху
1ц
2ц1в
цвр2
2цк
ц1ки
2ц1н
цр2к
цр2на
цр2не
2ц1х
1ча
ч1в
1че
1чи
2ч1к
2ч1н
1чо1
2ч1т
1чу
1џ
џа1
2џ1м
1ша
шап1
1ше
2шел
1ши
ш1к
ш1л
ш1м
ш1н
1шо1
ш1та
ш1тв
ш1ту
1шу
}

