## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Zh_latn_pinyin v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Zh_latn_pinyin::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Zh_latn_pinyin

=head1 NAME

TeX::Hyphen::Pattern::Zh_latn_pinyin - class for hyphenation in locale Zh_latn_pinyin

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
title: Hyphenation patterns for Chinese pinyin (Mandarin), with tone
       markers

notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information.

version: 2018-11-25

authors:
  -
    name:    Werner Lemberg
    contact: wl (at) gnu.org

copyright: Copyright (C) 1994-2018 Werner Lemberg

licence:
    name: MIT
    url:  http://opensource.org/licenses/mit-license.php
    text: >
          Permission is hereby granted, free of charge, to any person
          obtaining a copy of this software and associated documentation
          files (the “Software”), to deal in the Software without
          restriction, including without limitation the rights to use,
          copy, modify, merge, publish, distribute, sublicense, and/or
          sell copies of the Software, and to permit persons to whom the
          Software is furnished to do so, subject to the following
          conditions:

          The above copyright notice and this permission notice shall be
          included in all copies or substantial portions of the Software.

          THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
          EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
          OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
          NONINFRINGEMENT.  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
          HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
          WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
          FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
          OTHER DEALINGS IN THE SOFTWARE.

source: http://git.savannah.gnu.org/gitweb/?p=cjk.git;a=commit;h=e058ceae5561a89e33828f593b094c8b57f6a72e

language:
    name: Mandarin Chinese, pinyin transliteration
    tag:  zh-latn-pinyin

hyphenmins:
    generation:
        left:  1
        right: 2
    typesetting:
        left:  1
        right: 2
texlive:
    encoding: ec
    babelname: pinyin
    legacy_patterns: hyph-zh-latn-pinyin.ec.tex
    message: Pinyin Hyphenation Patterns (with tone markers) 2018-11-25 (WL)
    package: chinese
    use_old_patterns_comment: Legacy file contains patterns for pinyin without tone markers

==========================================

The used patgen parameters are

  1 1 | 2 5 | 1 1 1
  2 2 | 2 5 | 1 2 1
=end text

=cut

__DATA__
\patterns{
a1b ā1b á1b ǎ1b à1b
a1c ā1c á1c ǎ1c à1c
a1d ā1d á1d ǎ1d à1d
a1f ā1f á1f ǎ1f à1f
a1g ā1g á1g ǎ1g à1g
a1h ā1h á1h ǎ1h à1h
a1j ā1j á1j ǎ1j à1j
a1k ā1k á1k ǎ1k à1k
a1l ā1l á1l ǎ1l à1l
a1m ā1m á1m ǎ1m à1m
a1p ā1p á1p ǎ1p à1p
a1q ā1q á1q ǎ1q à1q
a1r ā1r á1r ǎ1r à1r
a1s ā1s á1s ǎ1s à1s
a1t ā1t á1t ǎ1t à1t
a1w ā1w á1w ǎ1w à1w
a1x ā1x á1x ǎ1x à1x
a1y ā1y á1y ǎ1y à1y
a1z ā1z á1z ǎ1z à1z
e1b ē1b é1b ě1b è1b
e1c ē1c é1c ě1c è1c
e1d ē1d é1d ě1d è1d
e1f ē1f é1f ě1f è1f
e1g ē1g é1g ě1g è1g
e1h ē1h é1h ě1h è1h
e1j ē1j é1j ě1j è1j
e1k ē1k é1k ě1k è1k
e1l ē1l é1l ě1l è1l
e1m ē1m é1m ě1m è1m
e1p ē1p é1p ě1p è1p
e1q ē1q é1q ě1q è1q
e1r ē1r é1r ě1r è1r
e1s ē1s é1s ě1s è1s
e1t ē1t é1t ě1t è1t
e1w ē1w é1w ě1w è1w
e1x ē1x é1x ě1x è1x
e1y ē1y é1y ě1y è1y
e1z ē1z é1z ě1z è1z
1ga 1gā 1gá 1gǎ 1gà
g1b
g1c
g1d
1ge 1gē 1gé 1gě 1gè
g1f
g1g
g1h
g1j
g1k
g1l
g1m
g1n
1go 1gō 1gó 1gǒ 1gò
g1p
g1q
g1r
g1s
g1t
1gu 1gū 1gú 1gǔ 1gù
g1w
g1x
g1y
g1z
i1b ī1b í1b ǐ1b ì1b
i1c ī1c í1c ǐ1c ì1c
i1d ī1d í1d ǐ1d ì1d
i1f ī1f í1f ǐ1f ì1f
i1g ī1g í1g ǐ1g ì1g
i1h ī1h í1h ǐ1h ì1h
i1j ī1j í1j ǐ1j ì1j
i1k ī1k í1k ǐ1k ì1k
i1l ī1l í1l ǐ1l ì1l
i1m ī1m í1m ǐ1m ì1m
i1p ī1p í1p ǐ1p ì1p
i1q ī1q í1q ǐ1q ì1q
i1r ī1r í1r ǐ1r ì1r
i1s ī1s í1s ǐ1s ì1s
i1t ī1t í1t ǐ1t ì1t
i1w ī1w í1w ǐ1w ì1w
i1x ī1x í1x ǐ1x ì1x
i1y ī1y í1y ǐ1y ì1y
i1z ī1z í1z ǐ1z ì1z
1na 1nā 1ná 1nǎ 1nà
n1b
n1c
n1d
1ne 1nē 1né 1ně 1nè
n1f
n1h
1ni 1nī 1ní 1nǐ 1nì
n1j
n1k
n1l
n1m
n1n
1no 1nō 1nó 1nǒ 1nò
n1p
n1q
n1r
n1s
n1t
1nu 1nū 1nú 1nǔ 1nù
1nü 1nǖ 1nǘ 1nǚ 1nǜ
n1w
n1x
n1y
n1z
o1b ō1b ó1b ǒ1b ò1b
o1c ō1c ó1c ǒ1c ò1c
o1d ō1d ó1d ǒ1d ò1d
o1f ō1f ó1f ǒ1f ò1f
o1g ō1g ó1g ǒ1g ò1g
o1h ō1h ó1h ǒ1h ò1h
o1j ō1j ó1j ǒ1j ò1j
o1k ō1k ó1k ǒ1k ò1k
o1l ō1l ó1l ǒ1l ò1l
o1m ō1m ó1m ǒ1m ò1m
o1p ō1p ó1p ǒ1p ò1p
o1q ō1q ó1q ǒ1q ò1q
o1r ō1r ó1r ǒ1r ò1r
o1s ō1s ó1s ǒ1s ò1s
o1t ō1t ó1t ǒ1t ò1t
o1w ō1w ó1w ǒ1w ò1w
o1x ō1x ó1x ǒ1x ò1x
o1y ō1y ó1y ǒ1y ò1y
o1z ō1z ó1z ǒ1z ò1z
2r1b
2r1c
2r1d
2r1f
2r1g
2r1h
2r1j
2r1k
2r1l
2r1m
2r1n
2r1p
2r1q
2r1r
2r1s
2r1t
2r1w
2r1x
2r1y
2r1z
u1b ū1b ú1b ǔ1b ù1b
u1c ū1c ú1c ǔ1c ù1c
u1d ū1d ú1d ǔ1d ù1d
u1f ū1f ú1f ǔ1f ù1f
u1g ū1g ú1g ǔ1g ù1g
u1h ū1h ú1h ǔ1h ù1h
u1j ū1j ú1j ǔ1j ù1j
u1k ū1k ú1k ǔ1k ù1k
u1l ū1l ú1l ǔ1l ù1l
u1m ū1m ú1m ǔ1m ù1m
u1p ū1p ú1p ǔ1p ù1p
u1q ū1q ú1q ǔ1q ù1q
u1r ū1r ú1r ǔ1r ù1r
u1s ū1s ú1s ǔ1s ù1s
u1t ū1t ú1t ǔ1t ù1t
u1w ū1w ú1w ǔ1w ù1w
u1x ū1x ú1x ǔ1x ù1x
u1y ū1y ú1y ǔ1y ù1y
u1z ū1z ú1z ǔ1z ù1z
ü1b ǖ1b ǘ1b ǚ1b ǜ1b
ü1c ǖ1c ǘ1c ǚ1c ǜ1c
ü1d ǖ1d ǘ1d ǚ1d ǜ1d
ü1f ǖ1f ǘ1f ǚ1f ǜ1f
ü1g ǖ1g ǘ1g ǚ1g ǜ1g
ü1h ǖ1h ǘ1h ǚ1h ǜ1h
ü1j ǖ1j ǘ1j ǚ1j ǜ1j
ü1k ǖ1k ǘ1k ǚ1k ǜ1k
ü1l ǖ1l ǘ1l ǚ1l ǜ1l
ü1m ǖ1m ǘ1m ǚ1m ǜ1m
ü1n ǖ1n ǘ1n ǚ1n ǜ1n
ü1p ǖ1p ǘ1p ǚ1p ǜ1p
ü1q ǖ1q ǘ1q ǚ1q ǜ1q
ü1r ǖ1r ǘ1r ǚ1r ǜ1r
ü1s ǖ1s ǘ1s ǚ1s ǜ1s
ü1t ǖ1t ǘ1t ǚ1t ǜ1t
ü1w ǖ1w ǘ1w ǚ1w ǜ1w
ü1x ǖ1x ǘ1x ǚ1x ǜ1x
ü1y ǖ1y ǘ1y ǚ1y ǜ1y
ü1z ǖ1z ǘ1z ǚ1z ǜ1z
}

