## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Quote_fur v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Quote_fur::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Quote_fur

=head1 NAME

TeX::Hyphen::Pattern::Quote_fur - class for hyphenation in locale Quote_fur

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
\bgroup
\lccode`\’=`\’
=end text

=cut

__DATA__
\patterns{
.’2s2
.’sj2
2’2
2’.
2b’
2c’
2cj’
2cj’.
2ç’
2d’
2f’
2g’
2h’
2j’
2k’
2l’.
2l’’
2m’
2n’
.’n2
2p’
2q’
2r’
4s’.
4s’’
2st’
2t’.
2t’’
2v’.
2v’’
2w’
2x’
2z’.
2z’’
}

