## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Quote_be v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Quote_be::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Quote_be

=head1 NAME

TeX::Hyphen::Pattern::Quote_be - class for hyphenation in locale Quote_be

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
\bgroup
\lccode`\’=`\’
=end text

=cut

__DATA__
\patterns{
6б’1
6в’1
6г’1
6ґ’1
6д’1
6ж’1
6з’1
6к’1
6л’1
6м’1
6н’1
6п’1
6р’1
6с’1
6т’1
6ф’1
6х’1
6ц’1
6ч’1
6ш’1
.б’8
-б’8
.в’8
-в’8
.г’8
-г’8
.ґ’8
-ґ’8
.д’8
-д’8
.ж’8
-ж’8
.з’8
-з’8
.к’8
-к’8
.л’8
-л’8
.м’8
-м’8
.н’8
-н’8
.п’8
-п’8
.р’8
-р’8
.с’8
-с’8
.т’8
-т’8
.ф’8
-ф’8
.х’8
-х’8
.ц’8
-ц’8
.ч’8
-ч’8
.ш’8
-ш’8
.сп’8
-сп’8
}

