## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Eu v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Eu::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Eu

=head1 NAME

TeX::Hyphen::Pattern::Eu - class for hyphenation in locale Eu

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
copyright: Copyright (C) 1997, 2008 Juan M. Aguirregabiria
title: Hyphenation patterns for Basque
notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information on the package,
    and http://tp.lc.ehu.es/jma/basque.html for details on Basque hyphenation.
language:
    name: Basque
    tag: eu
version: June 2008
authors:
  -
    name: Juan M. Aguirregabiria
    contact: juanmari.aguirregabiria (at) ehu.es
licence:
    text: >
        Permission is hereby granted, free of charge, to any person obtaining
        a copy of this file and any associated documentation
        (the "Data Files") to deal in the Data Files
        without restriction, including without limitation the rights to use,
        copy, modify, merge, publish, distribute, and/or sell copies of
        the Data Files, and to permit persons to whom the Data Files
        are furnished to do so, provided that
        (a) this copyright and permission notice appear with all copies
        of the Data Files,
        (b) this copyright and permission notice appear in associated
        documentation, and
        (c) there is clear notice in each modified Data File
        as well as in the documentation associated with the Data File(s)
        that the data has been modified.

        THE DATA FILES ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
        ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
        WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
        NONINFRINGEMENT OF THIRD PARTY RIGHTS.
        IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
        NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
        DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
        DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
        TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
        PERFORMANCE OF THE DATA FILES.

        Except as contained in this notice, the name of a copyright holder
        shall not be used in advertising or otherwise to promote the sale,
        use or other dealings in these Data Files without prior
        written authorization of the copyright holder.
hyphenmins:
    typesetting:
         left: 2
         right: 2
changes:
    - >
        February 1997 Patterns created by Juan M. Aguirregabiria, based on the
        shyphen.sh script for Spanish by Julio Sanchez, September 1991.
    - >
        26 June 2008 Generating script rewritten in Ruby and adapted for native
        UTF-8 TeX engines, patterns renamed from bahyph.tex to
        hyph-eu.tex and added to the hyph-utf8 package.  Functionality should
        not change apart from adding ñ by default.
texlive:
    encoding: ec
    babelname: basque
    legacy_patterns: bahyph.tex
    message: Basque hyphenation patterns
    description: Hyphenation patterns for Basque in T1/EC and UTF-8 encodings.
==========================================

Open vowels: a e o
Closed vowels: i u
Consonants: b c d f g j k l m n ñ p q r s t v w x y z

Some of the patterns below represent combinations that never
happen in Basque. Would they happen, they would be hyphenated
according to the rules.
=end text

=cut

__DATA__
\patterns{
% Rule SR1
% Vowels are kept together by the defaults
% Rule SR2
% Attach vowel groups to left consonant
1ba 1be 1bo 1bi 1bu
1ca 1ce 1co 1ci 1cu
1da 1de 1do 1di 1du
1fa 1fe 1fo 1fi 1fu
1ga 1ge 1go 1gi 1gu
1ja 1je 1jo 1ji 1ju
1ka 1ke 1ko 1ki 1ku
1la 1le 1lo 1li 1lu
1ma 1me 1mo 1mi 1mu
1na 1ne 1no 1ni 1nu
1ña 1ñe 1ño 1ñi 1ñu
1pa 1pe 1po 1pi 1pu
1qa 1qe 1qo 1qi 1qu
1ra 1re 1ro 1ri 1ru
1sa 1se 1so 1si 1su
1ta 1te 1to 1ti 1tu
1va 1ve 1vo 1vi 1vu
1wa 1we 1wo 1wi 1wu
1xa 1xe 1xo 1xi 1xu
1ya 1ye 1yo 1yi 1yu
1za 1ze 1zo 1zi 1zu
% Rule SR3
% Build legal consonant groups, leave other consonants bound to
% the previous group. This overrides part of the SR2 pattern group.
1l2la 1l2le 1l2lo 1l2li 1l2lu
1r2ra 1r2re 1r2ro 1r2ri 1r2ru
1t2sa 1t2se 1t2so 1t2si 1t2su
1t2xa 1t2xe 1t2xo 1t2xi 1t2xu
1t2za 1t2ze 1t2zo 1t2zi 1t2zu
1b2la 1b2le 1b2lo 1b2li 1b2lu
1b2ra 1b2re 1b2ro 1b2ri 1b2ru
1d2ra 1d2re 1d2ro 1d2ri 1d2ru
1f2la 1f2le 1f2lo 1f2li 1f2lu
1f2ra 1f2re 1f2ro 1f2ri 1f2ru
1g2la 1g2le 1g2lo 1g2li 1g2lu
1g2ra 1g2re 1g2ro 1g2ri 1g2ru
1k2la 1k2le 1k2lo 1k2li 1k2lu
1k2ra 1k2re 1k2ro 1k2ri 1k2ru
1p2la 1p2le 1p2lo 1p2li 1p2lu
1p2ra 1p2re 1p2ro 1p2ri 1p2ru
1t2ra 1t2re 1t2ro 1t2ri 1t2ru
% We now avoid some problematic breaks.
su2b2r su2b2l
}

