## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Cu v1.1.4;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Cu::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Cu

=head1 NAME

TeX::Hyphen::Pattern::Cu - class for hyphenation in locale Cu

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text
title: Hyphenation patterns for Church Slavonic
copyright: Copyright (C) 2016 Aleksandr Andreev, Mike Kroutikov
notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information.
language:
    name: Church Slavonic
    tag: cu
version: 1.1
authors:
  -
    name: Aleksandr Andreev
    contact: aleksandr.andreev (at) gmail.com
  -
    name: Mike Kroutikov
    contact: pgmmpk (at) gmail.com
licence:
    name: MIT
    url: https://opensource.org/licenses/MIT
    text: >
        Permission is hereby granted, free of charge, to any person obtaining
        a copy of this software and associated documentation files (the
        "Software"), to deal in the Software without restriction, including
        without limitation the rights to use, copy, modify, merge, publish,
        distribute, sublicense, and/or sell copies of the Software, and to
        permit persons to whom the Software is furnished to do so, subject to
        the following conditions:

        The above copyright notice and this permission notice shall be
        included in all copies or substantial portions of the Software.

        THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
        EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
        MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
        NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
        BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
        ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
        CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
        SOFTWARE.
changes:
    - 2016-04-16 Latest change
hyphenmins:
    typesetting:
        left: 1
        right: 2
texlive:
    babelname: churchslavonic
    message: Church Slavonic hyphenation patterns
    description: Hyphenation patterns for Church Slavonic in UTF-8 encoding
=end text

=cut

__DATA__
\patterns{
.а8
.а̀8
.а́8
.а̑8
.а҆8
.а҆̀8
.а҆́8
.а҆̈8
.а҆̑8
.а҆вес7салѡ́м
.а҆кта́7ꙋ
.а҆рїа́7д8н
.а҆рїа́7д8н
.а҆с7сѷр
.а҆с7сѷр
.аⷠ8
.аⷠ҇8
.аⷡ8
.аⷡ҇8
.аⷢ8
.аⷢ҇8
.аⷣ8
.аⷣ҇8
.аⷤ8
.аⷤ҇8
.аⷥ8
.аⷥ҇8
.аⷦ8
.аⷦ҇8
.аⷧ8
.аⷧ҇8
.аⷨ8
.аⷨ҇8
.аⷩ8
.аⷩ҇8
.аⷪ8
.аⷪ҇8
.аⷫ8
.аⷫ҇8
.аⷬ8
.аⷬ҇8
.аⷭ8
.аⷭ҇8
.аⷮ8
.аⷮ҇8
.аⷯ8
.аⷯ҇8
.аⷰ8
.аⷰ҇8
.аⷱ8
.аⷱ҇8
.аⷲ8
.аⷲ҇8
.аⷳ8
.аⷳ҇8
.аⷴ8
.аⷴ҇8
.аⷵ8
.аⷵ҇8
.аⷶ8
.аⷶ҇8
.аⷷ8
.аⷷ҇8
.аⷸ8
.аⷸ҇8
.аⷹ8
.аⷹ҇8
.аⷺ8
.аⷺ҇8
.аⷻ8
.аⷻ҇8
.аⷼ8
.аⷼ҇8
.аⷽ8
.аⷽ҇8
.аⷾ8
.аⷾ҇8
.аⷿ8
.аⷿ҇8
.аꙴ8
.аꙴ҇8
.аꙵ8
.аꙵ҇8
.аꙶ8
.аꙶ҇8
.аꙷ8
.аꙷ҇8
.аꙸ8
.аꙸ҇8
.аꙹ8
.аꙹ҇8
.аꙺ8
.аꙺ҇8
.аꙻ8
.аꙻ҇8
.а꙼8
.а꙼҇8
.а꙽8
.а꙽҇8
.б2
.ба́1
.би2
.би́1
.биш1
.бле1
.бро1
.брѧ1
.бѧ́1
.в2
.ва̑1
.ва1в
.ва1л
.ва1н
.ва1х
.вдо1
.ве1д
.ве1н
.ви́1
.ви̑1
.вис1
.ви1т
.вле1
.вн2
.вое1
.во7с8прѧ́н
.во7с8прѧн
.вос7пѣ́в
.вос7пѣв
.вос7тре́пет
.вос7трепет
.вос7трꙋ́б
.вос7трꙋб
.врї1
.врї1
.вче1
.вє́1
.вї1
.вїа1
.вї1
.вїа1
.вѣ1р
.вѣ1т
.вꙋ1
.г2
.ге1л
.глꙋ1
.гри́7в8на
.гри́7в8ны
.гри̑7в8ны
.гри̑7в8нѣ
.грѧ1
.гї1
.гї1
.гꙋ1б
.д2
.да1в
.да1л
.ди1м
.ди1с
.дол1
.до1с
.дох1
.др2
.дро1
.ды1х
.дї1
.дї1
.дѡ1р
.дѣ1в
.дѣ1л
.дꙋ1х
.е8
.ѐ8
.е́8
.ё8
.е̑8
.е҆8
.е҆̀8
.е҆́8
.е҆̈8
.е҆̑8
.еⷠ8
.еⷠ҇8
.еⷡ8
.еⷡ҇8
.еⷢ8
.еⷢ҇8
.еⷣ8
.еⷣ҇8
.еⷤ8
.еⷤ҇8
.еⷥ8
.еⷥ҇8
.еⷦ8
.еⷦ҇8
.еⷧ8
.еⷧ҇8
.еⷨ8
.еⷨ҇8
.еⷩ8
.еⷩ҇8
.еⷪ8
.еⷪ҇8
.еⷫ8
.еⷫ҇8
.еⷬ8
.еⷬ҇8
.еⷭ8
.еⷭ҇8
.еⷮ8
.еⷮ҇8
.еⷯ8
.еⷯ҇8
.еⷰ8
.еⷰ҇8
.еⷱ8
.еⷱ҇8
.еⷲ8
.еⷲ҇8
.еⷳ8
.еⷳ҇8
.еⷴ8
.еⷴ҇8
.еⷵ8
.еⷵ҇8
.еⷶ8
.еⷶ҇8
.еⷷ8
.еⷷ҇8
.еⷸ8
.еⷸ҇8
.еⷹ8
.еⷹ҇8
.еⷺ8
.еⷺ҇8
.еⷻ8
.еⷻ҇8
.еⷼ8
.еⷼ҇8
.еⷽ8
.еⷽ҇8
.еⷾ8
.еⷾ҇8
.еⷿ8
.еⷿ҇8
.еꙴ8
.еꙴ҇8
.еꙵ8
.еꙵ҇8
.еꙶ8
.еꙶ҇8
.еꙷ8
.еꙷ҇8
.еꙸ8
.еꙸ҇8
.еꙹ8
.еꙹ҇8
.еꙺ8
.еꙺ҇8
.еꙻ8
.еꙻ҇8
.е꙼8
.е꙼҇8
.е꙽8
.е꙽҇8
.ж2
.же1н
.же1с
.жи1л
.жи1т
.жє1н
.з2
.за1н
.за1х
.зе́7мле
.зе́7млю
.зер1
.зо1
.зꙋ1
.и8
.ѝ8
.и́8
.й8
.й̀8
.й́8
.й̈8
.й̑8
.й҆8
.й҆̀8
.й҆́8
.й҆̈8
.й҆̑8
.йⷠ8
.йⷠ҇8
.йⷡ8
.йⷡ҇8
.йⷢ8
.йⷢ҇8
.йⷣ8
.йⷣ҇8
.йⷤ8
.йⷤ҇8
.йⷥ8
.йⷥ҇8
.йⷦ8
.йⷦ҇8
.йⷧ8
.йⷧ҇8
.йⷨ8
.йⷨ҇8
.йⷩ8
.йⷩ҇8
.йⷪ8
.йⷪ҇8
.йⷫ8
.йⷫ҇8
.йⷬ8
.йⷬ҇8
.йⷭ8
.йⷭ҇8
.йⷮ8
.йⷮ҇8
.йⷯ8
.йⷯ҇8
.йⷰ8
.йⷰ҇8
.йⷱ8
.йⷱ҇8
.йⷲ8
.йⷲ҇8
.йⷳ8
.йⷳ҇8
.йⷴ8
.йⷴ҇8
.йⷵ8
.йⷵ҇8
.йⷶ8
.йⷶ҇8
.йⷷ8
.йⷷ҇8
.йⷸ8
.йⷸ҇8
.йⷹ8
.йⷹ҇8
.йⷺ8
.йⷺ҇8
.йⷻ8
.йⷻ҇8
.йⷼ8
.йⷼ҇8
.йⷽ8
.йⷽ҇8
.йⷾ8
.йⷾ҇8
.йⷿ8
.йⷿ҇8
.йꙴ8
.йꙴ҇8
.йꙵ8
.йꙵ҇8
.йꙶ8
.йꙶ҇8
.йꙷ8
.йꙷ҇8
.йꙸ8
.йꙸ҇8
.йꙹ8
.йꙹ҇8
.йꙺ8
.йꙺ҇8
.йꙻ8
.йꙻ҇8
.й꙼8
.й꙼҇8
.й꙽8
.й꙽҇8
.и̑8
.и҆8
.и҆̀8
.и҆́8
.и҆̈8
.и҆̑8
.и҆зба́7вле
.и҆зба́7влю
.и҆са́7їе
.и҆са́7їѧ
.и҆са́7їе
.и҆са́7їѧ
.и҆с7ка́пав
.и҆с7корен
.и҆с7кꙋ́с
.и҆с7кꙋс
.и҆с7те́к
.и҆с7тек
.и҆с8то́тн
.иⷠ8
.иⷠ҇8
.иⷡ8
.иⷡ҇8
.иⷢ8
.иⷢ҇8
.иⷣ8
.иⷣ҇8
.иⷤ8
.иⷤ҇8
.иⷥ8
.иⷥ҇8
.иⷦ8
.иⷦ҇8
.иⷧ8
.иⷧ҇8
.иⷨ8
.иⷨ҇8
.иⷩ8
.иⷩ҇8
.иⷪ8
.иⷪ҇8
.иⷫ8
.иⷫ҇8
.иⷬ8
.иⷬ҇8
.иⷭ8
.иⷭ҇8
.иⷮ8
.иⷮ҇8
.иⷯ8
.иⷯ҇8
.иⷰ8
.иⷰ҇8
.иⷱ8
.иⷱ҇8
.иⷲ8
.иⷲ҇8
.иⷳ8
.иⷳ҇8
.иⷴ8
.иⷴ҇8
.иⷵ8
.иⷵ҇8
.иⷶ8
.иⷶ҇8
.иⷷ8
.иⷷ҇8
.иⷸ8
.иⷸ҇8
.иⷹ8
.иⷹ҇8
.иⷺ8
.иⷺ҇8
.иⷻ8
.иⷻ҇8
.иⷼ8
.иⷼ҇8
.иⷽ8
.иⷽ҇8
.иⷾ8
.иⷾ҇8
.иⷿ8
.иⷿ҇8
.иꙴ8
.иꙴ҇8
.иꙵ8
.иꙵ҇8
.иꙶ8
.иꙶ҇8
.иꙷ8
.иꙷ҇8
.иꙸ8
.иꙸ҇8
.иꙹ8
.иꙹ҇8
.иꙺ8
.иꙺ҇8
.иꙻ8
.иꙻ҇8
.и꙼8
.и꙼҇8
.и꙽8
.и꙽҇8
.й8
.й̀8
.й́8
.й̈8
.й̑8
.й҆8
.й҆̀8
.й҆́8
.й҆̈8
.й҆̑8
.йⷠ8
.йⷠ҇8
.йⷡ8
.йⷡ҇8
.йⷢ8
.йⷢ҇8
.йⷣ8
.йⷣ҇8
.йⷤ8
.йⷤ҇8
.йⷥ8
.йⷥ҇8
.йⷦ8
.йⷦ҇8
.йⷧ8
.йⷧ҇8
.йⷨ8
.йⷨ҇8
.йⷩ8
.йⷩ҇8
.йⷪ8
.йⷪ҇8
.йⷫ8
.йⷫ҇8
.йⷬ8
.йⷬ҇8
.йⷭ8
.йⷭ҇8
.йⷮ8
.йⷮ҇8
.йⷯ8
.йⷯ҇8
.йⷰ8
.йⷰ҇8
.йⷱ8
.йⷱ҇8
.йⷲ8
.йⷲ҇8
.йⷳ8
.йⷳ҇8
.йⷴ8
.йⷴ҇8
.йⷵ8
.йⷵ҇8
.йⷶ8
.йⷶ҇8
.йⷷ8
.йⷷ҇8
.йⷸ8
.йⷸ҇8
.йⷹ8
.йⷹ҇8
.йⷺ8
.йⷺ҇8
.йⷻ8
.йⷻ҇8
.йⷼ8
.йⷼ҇8
.йⷽ8
.йⷽ҇8
.йⷾ8
.йⷾ҇8
.йⷿ8
.йⷿ҇8
.йꙴ8
.йꙴ҇8
.йꙵ8
.йꙵ҇8
.йꙶ8
.йꙶ҇8
.йꙷ8
.йꙷ҇8
.йꙸ8
.йꙸ҇8
.йꙹ8
.йꙹ҇8
.йꙺ8
.йꙺ҇8
.йꙻ8
.йꙻ҇8
.й꙼8
.й꙼҇8
.й꙽8
.й꙽҇8
.к2
.ка̑1
.ки2
.кл2
.ко1в
.кое1
.ко1м
.кѡн1
.л2
.ла1в
.ли̑1
.ль2
.лї1
.лї1
.лѷ1
.лѷ1
.м2
.мам1
.ма1н
.ма1т
.мел7хїседе́к
.мел7хїседе́к
.ме1н
.мер1
.мес7сі́
.ме1т
.ме7т8не́н
.мле1
.мо1н
.мор1
.мо1с
.мо1щ
.мы̑1
.мѧ1т
.н2
.наза7ре́т
.на1м
.на1х
.не1
.неѡ1
.ни1в
.ни1к
.ны́1
.ню2
.ню́1
.нї1
.нї1
.нѡ́1
.нѣ1м
.нѧ́1
.нꙋ2
.о8
.о̀8
.о́8
.о̑8
.о҆8
.о҆̀8
.о҆́8
.о҆̈8
.о҆̑8
.оⷠ8
.оⷠ҇8
.оⷡ8
.оⷡ҇8
.оⷢ8
.оⷢ҇8
.оⷣ8
.оⷣ҇8
.оⷤ8
.оⷤ҇8
.оⷥ8
.оⷥ҇8
.оⷦ8
.оⷦ҇8
.оⷧ8
.оⷧ҇8
.оⷨ8
.оⷨ҇8
.оⷩ8
.оⷩ҇8
.оⷪ8
.оⷪ҇8
.оⷫ8
.оⷫ҇8
.оⷬ8
.оⷬ҇8
.оⷭ8
.оⷭ҇8
.оⷮ8
.оⷮ҇8
.оⷯ8
.оⷯ҇8
.оⷰ8
.оⷰ҇8
.оⷱ8
.оⷱ҇8
.оⷲ8
.оⷲ҇8
.оⷳ8
.оⷳ҇8
.оⷴ8
.оⷴ҇8
.оⷵ8
.оⷵ҇8
.оⷶ8
.оⷶ҇8
.оⷷ8
.оⷷ҇8
.оⷸ8
.оⷸ҇8
.оⷹ8
.оⷹ҇8
.оⷺ8
.оⷺ҇8
.оⷻ8
.оⷻ҇8
.оⷼ8
.оⷼ҇8
.оⷽ8
.оⷽ҇8
.оⷾ8
.оⷾ҇8
.оⷿ8
.оⷿ҇8
.оꙴ8
.оꙴ҇8
.оꙵ8
.оꙵ҇8
.оꙶ8
.оꙶ҇8
.оꙷ8
.оꙷ҇8
.оꙸ8
.оꙸ҇8
.оꙹ8
.оꙹ҇8
.оꙺ8
.оꙺ҇8
.оꙻ8
.оꙻ҇8
.о꙼8
.о꙼҇8
.о꙽8
.о꙽҇8
.п2
.па1д
.па1с
.пе1л
.пер1
.пе1т
.пе1ц
.пи1т
.по́7ж8нет
.по́7ж8нꙋт
.по́7м8нит
.по7всю́д
.по8д7но́г
.по8д7но́ж
.по7злащ
.полꙋ́7д8не
.полꙋ́7д8ни
.пото8п7ле́н
.пото8п7лѧ́
.по7чне́т
.пре7ль8сти́
.пре7ль8ща́
.при́7т8ча
.при́7т8че
.при́7т8чи
.при7льп
.про́7стрꙋ
.про7з8ва̀
.прїе́м7ле
.прїе́м7ли
.прїе́м7лю
.прїе́м7лѣ
.прїе́м7лѧ
.прїе́м7ле
.прїе́м7ли
.прїе́м7лю
.прїе́м7лѣ
.прїе́м7лѧ
.пї1
.пї1
.пѣ́7с8не
.пѣ́7с8ни
.пѣ́7с8ню
.пѣ́7с8нѣ
.пѣв1
.р2
.раз7ꙋ́м
.раз7ꙋм
.рас1
.ра8с7тлѝ
.ра8с7тлѝ
.ра8с7тлѣ́
.ра8с7тлѧ
.ра8с7точ
.ра1х
.ри2
.ро1в
.роз1
.рѡ1м
.рѡс1
.рѣ̑1
.рꙋ̑1
.с2
.сен1
.сла7сте́
.слѧ1
.сма1
.смо1
.со7з8ва́
.спо1
.сподо8б7лѧ́
.ст2
.стра7сте́
.сты1
.стѡ1
.сє1
.сї1м
.сї1м
.сѣ̑1
.сѣн1
.сѧ́1
.т2
.та̑1
.те1ц
.ти1м
.тл2
.то1м
.тор1
.трї1
.трї1
.трѧ1
.ты́1
.ть2
.тї1
.тї1
.тѵ́1
.тѷ2
.тѷ2
.у8
.у̀8
.у́8
.у̑8
.у҆8
.у҆̀8
.у҆́8
.у҆̈8
.у҆̑8
.уⷠ8
.уⷠ҇8
.уⷡ8
.уⷡ҇8
.уⷢ8
.уⷢ҇8
.уⷣ8
.уⷣ҇8
.уⷤ8
.уⷤ҇8
.уⷥ8
.уⷥ҇8
.уⷦ8
.уⷦ҇8
.уⷧ8
.уⷧ҇8
.уⷨ8
.уⷨ҇8
.уⷩ8
.уⷩ҇8
.уⷪ8
.уⷪ҇8
.уⷫ8
.уⷫ҇8
.уⷬ8
.уⷬ҇8
.уⷭ8
.уⷭ҇8
.уⷮ8
.уⷮ҇8
.уⷯ8
.уⷯ҇8
.уⷰ8
.уⷰ҇8
.уⷱ8
.уⷱ҇8
.уⷲ8
.уⷲ҇8
.уⷳ8
.уⷳ҇8
.уⷴ8
.уⷴ҇8
.уⷵ8
.уⷵ҇8
.уⷶ8
.уⷶ҇8
.уⷷ8
.уⷷ҇8
.уⷸ8
.уⷸ҇8
.уⷹ8
.уⷹ҇8
.уⷺ8
.уⷺ҇8
.уⷻ8
.уⷻ҇8
.уⷼ8
.уⷼ҇8
.уⷽ8
.уⷽ҇8
.уⷾ8
.уⷾ҇8
.уⷿ8
.уⷿ҇8
.уꙴ8
.уꙴ҇8
.уꙵ8
.уꙵ҇8
.уꙶ8
.уꙶ҇8
.уꙷ8
.уꙷ҇8
.уꙸ8
.уꙸ҇8
.уꙹ8
.уꙹ҇8
.уꙺ8
.уꙺ҇8
.уꙻ8
.уꙻ҇8
.у꙼8
.у꙼҇8
.у꙽8
.у꙽҇8
.ф2
.фо2
.фор1
.фї1
.фї1
.фѡ́1
.х2
.хал1
.хе1
.хѡ1
.ц2
.ч2
.че8ст7вов
.че8ст7вꙋ́
.че1т
.чє́1
.ш2
.ша1
.шє́1
.щꙋ1
.ы8
.ы̀8
.ы́8
.ы̑8
.ы҆8
.ы҆̀8
.ы҆́8
.ы҆̈8
.ы҆̑8
.ыⷠ8
.ыⷠ҇8
.ыⷡ8
.ыⷡ҇8
.ыⷢ8
.ыⷢ҇8
.ыⷣ8
.ыⷣ҇8
.ыⷤ8
.ыⷤ҇8
.ыⷥ8
.ыⷥ҇8
.ыⷦ8
.ыⷦ҇8
.ыⷧ8
.ыⷧ҇8
.ыⷨ8
.ыⷨ҇8
.ыⷩ8
.ыⷩ҇8
.ыⷪ8
.ыⷪ҇8
.ыⷫ8
.ыⷫ҇8
.ыⷬ8
.ыⷬ҇8
.ыⷭ8
.ыⷭ҇8
.ыⷮ8
.ыⷮ҇8
.ыⷯ8
.ыⷯ҇8
.ыⷰ8
.ыⷰ҇8
.ыⷱ8
.ыⷱ҇8
.ыⷲ8
.ыⷲ҇8
.ыⷳ8
.ыⷳ҇8
.ыⷴ8
.ыⷴ҇8
.ыⷵ8
.ыⷵ҇8
.ыⷶ8
.ыⷶ҇8
.ыⷷ8
.ыⷷ҇8
.ыⷸ8
.ыⷸ҇8
.ыⷹ8
.ыⷹ҇8
.ыⷺ8
.ыⷺ҇8
.ыⷻ8
.ыⷻ҇8
.ыⷼ8
.ыⷼ҇8
.ыⷽ8
.ыⷽ҇8
.ыⷾ8
.ыⷾ҇8
.ыⷿ8
.ыⷿ҇8
.ыꙴ8
.ыꙴ҇8
.ыꙵ8
.ыꙵ҇8
.ыꙶ8
.ыꙶ҇8
.ыꙷ8
.ыꙷ҇8
.ыꙸ8
.ыꙸ҇8
.ыꙹ8
.ыꙹ҇8
.ыꙺ8
.ыꙺ҇8
.ыꙻ8
.ыꙻ҇8
.ы꙼8
.ы꙼҇8
.ы꙽8
.ы꙽҇8
.э8
.э̀8
.э́8
.э̑8
.э҆8
.э҆̀8
.э҆́8
.э҆̈8
.э҆̑8
.эⷠ8
.эⷠ҇8
.эⷡ8
.эⷡ҇8
.эⷢ8
.эⷢ҇8
.эⷣ8
.эⷣ҇8
.эⷤ8
.эⷤ҇8
.эⷥ8
.эⷥ҇8
.эⷦ8
.эⷦ҇8
.эⷧ8
.эⷧ҇8
.эⷨ8
.эⷨ҇8
.эⷩ8
.эⷩ҇8
.эⷪ8
.эⷪ҇8
.эⷫ8
.эⷫ҇8
.эⷬ8
.эⷬ҇8
.эⷭ8
.эⷭ҇8
.эⷮ8
.эⷮ҇8
.эⷯ8
.эⷯ҇8
.эⷰ8
.эⷰ҇8
.эⷱ8
.эⷱ҇8
.эⷲ8
.эⷲ҇8
.эⷳ8
.эⷳ҇8
.эⷴ8
.эⷴ҇8
.эⷵ8
.эⷵ҇8
.эⷶ8
.эⷶ҇8
.эⷷ8
.эⷷ҇8
.эⷸ8
.эⷸ҇8
.эⷹ8
.эⷹ҇8
.эⷺ8
.эⷺ҇8
.эⷻ8
.эⷻ҇8
.эⷼ8
.эⷼ҇8
.эⷽ8
.эⷽ҇8
.эⷾ8
.эⷾ҇8
.эⷿ8
.эⷿ҇8
.эꙴ8
.эꙴ҇8
.эꙵ8
.эꙵ҇8
.эꙶ8
.эꙶ҇8
.эꙷ8
.эꙷ҇8
.эꙸ8
.эꙸ҇8
.эꙹ8
.эꙹ҇8
.эꙺ8
.эꙺ҇8
.эꙻ8
.эꙻ҇8
.э꙼8
.э꙼҇8
.э꙽8
.э꙽҇8
.ю8
.ю̀8
.ю́8
.ю̈8
.ю̑8
.ю҆8
.ю҆̀8
.ю҆́8
.ю҆̈8
.ю҆̑8
.юⷠ8
.юⷠ҇8
.юⷡ8
.юⷡ҇8
.юⷢ8
.юⷢ҇8
.юⷣ8
.юⷣ҇8
.юⷤ8
.юⷤ҇8
.юⷥ8
.юⷥ҇8
.юⷦ8
.юⷦ҇8
.юⷧ8
.юⷧ҇8
.юⷨ8
.юⷨ҇8
.юⷩ8
.юⷩ҇8
.юⷪ8
.юⷪ҇8
.юⷫ8
.юⷫ҇8
.юⷬ8
.юⷬ҇8
.юⷭ8
.юⷭ҇8
.юⷮ8
.юⷮ҇8
.юⷯ8
.юⷯ҇8
.юⷰ8
.юⷰ҇8
.юⷱ8
.юⷱ҇8
.юⷲ8
.юⷲ҇8
.юⷳ8
.юⷳ҇8
.юⷴ8
.юⷴ҇8
.юⷵ8
.юⷵ҇8
.юⷶ8
.юⷶ҇8
.юⷷ8
.юⷷ҇8
.юⷸ8
.юⷸ҇8
.юⷹ8
.юⷹ҇8
.юⷺ8
.юⷺ҇8
.юⷻ8
.юⷻ҇8
.юⷼ8
.юⷼ҇8
.юⷽ8
.юⷽ҇8
.юⷾ8
.юⷾ҇8
.юⷿ8
.юⷿ҇8
.юꙴ8
.юꙴ҇8
.юꙵ8
.юꙵ҇8
.юꙶ8
.юꙶ҇8
.юꙷ8
.юꙷ҇8
.юꙸ8
.юꙸ҇8
.юꙹ8
.юꙹ҇8
.юꙺ8
.юꙺ҇8
.юꙻ8
.юꙻ҇8
.ю꙼8
.ю꙼҇8
.ю꙽8
.ю꙽҇8
.ѐ8
.ё8
.є8
.є̀8
.є́8
.є̈8
.є̑8
.є҆8
.є҆̀8
.є҆́8
.є҆̈8
.є҆̑8
.єⷠ8
.єⷠ҇8
.єⷡ8
.єⷡ҇8
.єⷢ8
.єⷢ҇8
.єⷣ8
.єⷣ҇8
.єⷤ8
.єⷤ҇8
.єⷥ8
.єⷥ҇8
.єⷦ8
.єⷦ҇8
.єⷧ8
.єⷧ҇8
.єⷨ8
.єⷨ҇8
.єⷩ8
.єⷩ҇8
.єⷪ8
.єⷪ҇8
.єⷫ8
.єⷫ҇8
.єⷬ8
.єⷬ҇8
.єⷭ8
.єⷭ҇8
.єⷮ8
.єⷮ҇8
.єⷯ8
.єⷯ҇8
.єⷰ8
.єⷰ҇8
.єⷱ8
.єⷱ҇8
.єⷲ8
.єⷲ҇8
.єⷳ8
.єⷳ҇8
.єⷴ8
.єⷴ҇8
.єⷵ8
.єⷵ҇8
.єⷶ8
.єⷶ҇8
.єⷷ8
.єⷷ҇8
.єⷸ8
.єⷸ҇8
.єⷹ8
.єⷹ҇8
.єⷺ8
.єⷺ҇8
.єⷻ8
.єⷻ҇8
.єⷼ8
.єⷼ҇8
.єⷽ8
.єⷽ҇8
.єⷾ8
.єⷾ҇8
.єⷿ8
.єⷿ҇8
.єꙴ8
.єꙴ҇8
.єꙵ8
.єꙵ҇8
.єꙶ8
.єꙶ҇8
.єꙷ8
.єꙷ҇8
.єꙸ8
.єꙸ҇8
.єꙹ8
.єꙹ҇8
.єꙺ8
.єꙺ҇8
.єꙻ8
.єꙻ҇8
.є꙼8
.є꙼҇8
.є꙽8
.є꙽҇8
.ѕ2
.і8
.і̀8
.і́8
.ї8
.і̑8
.і҆8
.і҆̀8
.і҆́8
.і҆̈8
.і҆̑8
.і҆ес7се́
.іⷠ8
.іⷠ҇8
.іⷡ8
.іⷡ҇8
.іⷢ8
.іⷢ҇8
.іⷣ8
.іⷣ҇8
.іⷤ8
.іⷤ҇8
.іⷥ8
.іⷥ҇8
.іⷦ8
.іⷦ҇8
.іⷧ8
.іⷧ҇8
.іⷨ8
.іⷨ҇8
.іⷩ8
.іⷩ҇8
.іⷪ8
.іⷪ҇8
.іⷫ8
.іⷫ҇8
.іⷬ8
.іⷬ҇8
.іⷭ8
.іⷭ҇8
.іⷮ8
.іⷮ҇8
.іⷯ8
.іⷯ҇8
.іⷰ8
.іⷰ҇8
.іⷱ8
.іⷱ҇8
.іⷲ8
.іⷲ҇8
.іⷳ8
.іⷳ҇8
.іⷴ8
.іⷴ҇8
.іⷵ8
.іⷵ҇8
.іⷶ8
.іⷶ҇8
.іⷷ8
.іⷷ҇8
.іⷸ8
.іⷸ҇8
.іⷹ8
.іⷹ҇8
.іⷺ8
.іⷺ҇8
.іⷻ8
.іⷻ҇8
.іⷼ8
.іⷼ҇8
.іⷽ8
.іⷽ҇8
.іⷾ8
.іⷾ҇8
.іⷿ8
.іⷿ҇8
.іꙴ8
.іꙴ҇8
.іꙵ8
.іꙵ҇8
.іꙶ8
.іꙶ҇8
.іꙷ8
.іꙷ҇8
.іꙸ8
.іꙸ҇8
.іꙹ8
.іꙹ҇8
.іꙺ8
.іꙺ҇8
.іꙻ8
.іꙻ҇8
.і꙼8
.і꙼҇8
.і꙽8
.і꙽҇8
.ї8
.ѝ8
.ѡби1
.ѡ1с
.ѡ҆б7ле́к
.ѡ҆б7лещ
.ѡ҆8б7ра́дов
.ѡ҆7бра́з
.ѡ҆б7ра́т
.ѡ҆б7ра́щ
.ѡ҆бра7зꙋ́
.ѡ҆б7ращ
.ѡ҆б7рѣ́з
.ѡ҆7брѣ́л
.ѡ҆7брѣ́т
.ѡ҆8т7ве́рг
.ѡ҆8т7ве́рж
.ѡ҆8т7ры́гн
.ѣ8
.ѣ̀8
.ѣ́8
.ѣ̈8
.ѣ̑8
.ѣ҆8
.ѣ҆̀8
.ѣ҆́8
.ѣ҆̈8
.ѣ҆̑8
.ѣⷠ8
.ѣⷠ҇8
.ѣⷡ8
.ѣⷡ҇8
.ѣⷢ8
.ѣⷢ҇8
.ѣⷣ8
.ѣⷣ҇8
.ѣⷤ8
.ѣⷤ҇8
.ѣⷥ8
.ѣⷥ҇8
.ѣⷦ8
.ѣⷦ҇8
.ѣⷧ8
.ѣⷧ҇8
.ѣⷨ8
.ѣⷨ҇8
.ѣⷩ8
.ѣⷩ҇8
.ѣⷪ8
.ѣⷪ҇8
.ѣⷫ8
.ѣⷫ҇8
.ѣⷬ8
.ѣⷬ҇8
.ѣⷭ8
.ѣⷭ҇8
.ѣⷮ8
.ѣⷮ҇8
.ѣⷯ8
.ѣⷯ҇8
.ѣⷰ8
.ѣⷰ҇8
.ѣⷱ8
.ѣⷱ҇8
.ѣⷲ8
.ѣⷲ҇8
.ѣⷳ8
.ѣⷳ҇8
.ѣⷴ8
.ѣⷴ҇8
.ѣⷵ8
.ѣⷵ҇8
.ѣⷶ8
.ѣⷶ҇8
.ѣⷷ8
.ѣⷷ҇8
.ѣⷸ8
.ѣⷸ҇8
.ѣⷹ8
.ѣⷹ҇8
.ѣⷺ8
.ѣⷺ҇8
.ѣⷻ8
.ѣⷻ҇8
.ѣⷼ8
.ѣⷼ҇8
.ѣⷽ8
.ѣⷽ҇8
.ѣⷾ8
.ѣⷾ҇8
.ѣⷿ8
.ѣⷿ҇8
.ѣꙴ8
.ѣꙴ҇8
.ѣꙵ8
.ѣꙵ҇8
.ѣꙶ8
.ѣꙶ҇8
.ѣꙷ8
.ѣꙷ҇8
.ѣꙸ8
.ѣꙸ҇8
.ѣꙹ8
.ѣꙹ҇8
.ѣꙺ8
.ѣꙺ҇8
.ѣꙻ8
.ѣꙻ҇8
.ѣ꙼8
.ѣ꙼҇8
.ѣ꙽8
.ѣ꙽҇8
.ѧ8
.ѧ̀8
.ѧ́8
.ѧ̈8
.ѧ̑8
.ѧ҆8
.ѧ҆̀8
.ѧ҆́8
.ѧ҆̈8
.ѧ҆̑8
.ѧⷠ8
.ѧⷠ҇8
.ѧⷡ8
.ѧⷡ҇8
.ѧⷢ8
.ѧⷢ҇8
.ѧⷣ8
.ѧⷣ҇8
.ѧⷤ8
.ѧⷤ҇8
.ѧⷥ8
.ѧⷥ҇8
.ѧⷦ8
.ѧⷦ҇8
.ѧⷧ8
.ѧⷧ҇8
.ѧⷨ8
.ѧⷨ҇8
.ѧⷩ8
.ѧⷩ҇8
.ѧⷪ8
.ѧⷪ҇8
.ѧⷫ8
.ѧⷫ҇8
.ѧⷬ8
.ѧⷬ҇8
.ѧⷭ8
.ѧⷭ҇8
.ѧⷮ8
.ѧⷮ҇8
.ѧⷯ8
.ѧⷯ҇8
.ѧⷰ8
.ѧⷰ҇8
.ѧⷱ8
.ѧⷱ҇8
.ѧⷲ8
.ѧⷲ҇8
.ѧⷳ8
.ѧⷳ҇8
.ѧⷴ8
.ѧⷴ҇8
.ѧⷵ8
.ѧⷵ҇8
.ѧⷶ8
.ѧⷶ҇8
.ѧⷷ8
.ѧⷷ҇8
.ѧⷸ8
.ѧⷸ҇8
.ѧⷹ8
.ѧⷹ҇8
.ѧⷺ8
.ѧⷺ҇8
.ѧⷻ8
.ѧⷻ҇8
.ѧⷼ8
.ѧⷼ҇8
.ѧⷽ8
.ѧⷽ҇8
.ѧⷾ8
.ѧⷾ҇8
.ѧⷿ8
.ѧⷿ҇8
.ѧꙴ8
.ѧꙴ҇8
.ѧꙵ8
.ѧꙵ҇8
.ѧꙶ8
.ѧꙶ҇8
.ѧꙷ8
.ѧꙷ҇8
.ѧꙸ8
.ѧꙸ҇8
.ѧꙹ8
.ѧꙹ҇8
.ѧꙺ8
.ѧꙺ҇8
.ѧꙻ8
.ѧꙻ҇8
.ѧ꙼8
.ѧ꙼҇8
.ѧ꙽8
.ѧ꙽҇8
.ѯе́1
.ѳ2
.ѳес7салон
.ѳї1
.ѳї1
.ѵ8
.ѵ̀8
.ѵ́8
.ѵ̈8
.ѵ̑8
.ѵ҆8
.ѵ҆̀8
.ѵ҆́8
.ѵ҆̈8
.ѵ҆̑8
.ѵ҆с7сѡ́п
.ѵⷠ8
.ѵⷠ҇8
.ѵⷡ8
.ѵⷡ҇8
.ѵⷢ8
.ѵⷢ҇8
.ѵⷣ8
.ѵⷣ҇8
.ѵⷤ8
.ѵⷤ҇8
.ѵⷥ8
.ѵⷥ҇8
.ѵⷦ8
.ѵⷦ҇8
.ѵⷧ8
.ѵⷧ҇8
.ѵⷨ8
.ѵⷨ҇8
.ѵⷩ8
.ѵⷩ҇8
.ѵⷪ8
.ѵⷪ҇8
.ѵⷫ8
.ѵⷫ҇8
.ѵⷬ8
.ѵⷬ҇8
.ѵⷭ8
.ѵⷭ҇8
.ѵⷮ8
.ѵⷮ҇8
.ѵⷯ8
.ѵⷯ҇8
.ѵⷰ8
.ѵⷰ҇8
.ѵⷱ8
.ѵⷱ҇8
.ѵⷲ8
.ѵⷲ҇8
.ѵⷳ8
.ѵⷳ҇8
.ѵⷴ8
.ѵⷴ҇8
.ѵⷵ8
.ѵⷵ҇8
.ѵⷶ8
.ѵⷶ҇8
.ѵⷷ8
.ѵⷷ҇8
.ѵⷸ8
.ѵⷸ҇8
.ѵⷹ8
.ѵⷹ҇8
.ѵⷺ8
.ѵⷺ҇8
.ѵⷻ8
.ѵⷻ҇8
.ѵⷼ8
.ѵⷼ҇8
.ѵⷽ8
.ѵⷽ҇8
.ѵⷾ8
.ѵⷾ҇8
.ѵⷿ8
.ѵⷿ҇8
.ѵꙴ8
.ѵꙴ҇8
.ѵꙵ8
.ѵꙵ҇8
.ѵꙶ8
.ѵꙶ҇8
.ѵꙷ8
.ѵꙷ҇8
.ѵꙸ8
.ѵꙸ҇8
.ѵꙹ8
.ѵꙹ҇8
.ѵꙺ8
.ѵꙺ҇8
.ѵꙻ8
.ѵꙻ҇8
.ѵ꙼8
.ѵ꙼҇8
.ѵ꙽8
.ѵ꙽҇8
.ѹ҆7стрем
.ѻ8
.ѻ̀8
.ѻ́8
.ѻ̈8
.ѻ̑8
.ѻ҆8
.ѻ҆̀8
.ѻ҆́8
.ѻ҆́т7расл
.ѻ҆́т8ча
.ѻ҆́т8че
.ѻ҆̈8
.ѻ҆̑8
.ѻ҆б7ра́дов
.ѻⷠ8
.ѻⷠ҇8
.ѻⷡ8
.ѻⷡ҇8
.ѻⷢ8
.ѻⷢ҇8
.ѻⷣ8
.ѻⷣ҇8
.ѻⷤ8
.ѻⷤ҇8
.ѻⷥ8
.ѻⷥ҇8
.ѻⷦ8
.ѻⷦ҇8
.ѻⷧ8
.ѻⷧ҇8
.ѻⷨ8
.ѻⷨ҇8
.ѻⷩ8
.ѻⷩ҇8
.ѻⷪ8
.ѻⷪ҇8
.ѻⷫ8
.ѻⷫ҇8
.ѻⷬ8
.ѻⷬ҇8
.ѻⷭ8
.ѻⷭ҇8
.ѻⷮ8
.ѻⷮ҇8
.ѻⷯ8
.ѻⷯ҇8
.ѻⷰ8
.ѻⷰ҇8
.ѻⷱ8
.ѻⷱ҇8
.ѻⷲ8
.ѻⷲ҇8
.ѻⷳ8
.ѻⷳ҇8
.ѻⷴ8
.ѻⷴ҇8
.ѻⷵ8
.ѻⷵ҇8
.ѻⷶ8
.ѻⷶ҇8
.ѻⷷ8
.ѻⷷ҇8
.ѻⷸ8
.ѻⷸ҇8
.ѻⷹ8
.ѻⷹ҇8
.ѻⷺ8
.ѻⷺ҇8
.ѻⷻ8
.ѻⷻ҇8
.ѻⷼ8
.ѻⷼ҇8
.ѻⷽ8
.ѻⷽ҇8
.ѻⷾ8
.ѻⷾ҇8
.ѻⷿ8
.ѻⷿ҇8
.ѻꙴ8
.ѻꙴ҇8
.ѻꙵ8
.ѻꙵ҇8
.ѻꙶ8
.ѻꙶ҇8
.ѻꙷ8
.ѻꙷ҇8
.ѻꙸ8
.ѻꙸ҇8
.ѻꙹ8
.ѻꙹ҇8
.ѻꙺ8
.ѻꙺ҇8
.ѻꙻ8
.ѻꙻ҇8
.ѻ꙼8
.ѻ꙼҇8
.ѻ꙽8
.ѻ꙽҇8
.ѽ8
.ѽ̀8
.ѽ́8
.ѽ̈8
.ѽ̑8
.ѽ҆8
.ѽ҆̀8
.ѽ҆́8
.ѽ҆̈8
.ѽ҆̑8
.ѽⷠ8
.ѽⷠ҇8
.ѽⷡ8
.ѽⷡ҇8
.ѽⷢ8
.ѽⷢ҇8
.ѽⷣ8
.ѽⷣ҇8
.ѽⷤ8
.ѽⷤ҇8
.ѽⷥ8
.ѽⷥ҇8
.ѽⷦ8
.ѽⷦ҇8
.ѽⷧ8
.ѽⷧ҇8
.ѽⷨ8
.ѽⷨ҇8
.ѽⷩ8
.ѽⷩ҇8
.ѽⷪ8
.ѽⷪ҇8
.ѽⷫ8
.ѽⷫ҇8
.ѽⷬ8
.ѽⷬ҇8
.ѽⷭ8
.ѽⷭ҇8
.ѽⷮ8
.ѽⷮ҇8
.ѽⷯ8
.ѽⷯ҇8
.ѽⷰ8
.ѽⷰ҇8
.ѽⷱ8
.ѽⷱ҇8
.ѽⷲ8
.ѽⷲ҇8
.ѽⷳ8
.ѽⷳ҇8
.ѽⷴ8
.ѽⷴ҇8
.ѽⷵ8
.ѽⷵ҇8
.ѽⷶ8
.ѽⷶ҇8
.ѽⷷ8
.ѽⷷ҇8
.ѽⷸ8
.ѽⷸ҇8
.ѽⷹ8
.ѽⷹ҇8
.ѽⷺ8
.ѽⷺ҇8
.ѽⷻ8
.ѽⷻ҇8
.ѽⷼ8
.ѽⷼ҇8
.ѽⷽ8
.ѽⷽ҇8
.ѽⷾ8
.ѽⷾ҇8
.ѽⷿ8
.ѽⷿ҇8
.ѽꙴ8
.ѽꙴ҇8
.ѽꙵ8
.ѽꙵ҇8
.ѽꙶ8
.ѽꙶ҇8
.ѽꙷ8
.ѽꙷ҇8
.ѽꙸ8
.ѽꙸ҇8
.ѽꙹ8
.ѽꙹ҇8
.ѽꙺ8
.ѽꙺ҇8
.ѽꙻ8
.ѽꙻ҇8
.ѽ꙼8
.ѽ꙼҇8
.ѽ꙽8
.ѽ꙽҇8
.ѿ1
.ѿ7всю́д
.ӓ8
.ӥ8
.ӧ8
.ӭ8
.ӱ8
.ӹ8
.ᲂ8
.ᲂ̀8
.ᲂ́8
.ᲂ̈8
.ᲂ̑8
.ᲂу҆7стрем
.ᲂ҆8
.ᲂ҆̀8
.ᲂ҆́8
.ᲂ҆̈8
.ᲂ҆̑8
.ᲂⷠ8
.ᲂⷠ҇8
.ᲂⷡ8
.ᲂⷡ҇8
.ᲂⷢ8
.ᲂⷢ҇8
.ᲂⷣ8
.ᲂⷣ҇8
.ᲂⷤ8
.ᲂⷤ҇8
.ᲂⷥ8
.ᲂⷥ҇8
.ᲂⷦ8
.ᲂⷦ҇8
.ᲂⷧ8
.ᲂⷧ҇8
.ᲂⷨ8
.ᲂⷨ҇8
.ᲂⷩ8
.ᲂⷩ҇8
.ᲂⷪ8
.ᲂⷪ҇8
.ᲂⷫ8
.ᲂⷫ҇8
.ᲂⷬ8
.ᲂⷬ҇8
.ᲂⷭ8
.ᲂⷭ҇8
.ᲂⷮ8
.ᲂⷮ҇8
.ᲂⷯ8
.ᲂⷯ҇8
.ᲂⷰ8
.ᲂⷰ҇8
.ᲂⷱ8
.ᲂⷱ҇8
.ᲂⷲ8
.ᲂⷲ҇8
.ᲂⷳ8
.ᲂⷳ҇8
.ᲂⷴ8
.ᲂⷴ҇8
.ᲂⷵ8
.ᲂⷵ҇8
.ᲂⷶ8
.ᲂⷶ҇8
.ᲂⷷ8
.ᲂⷷ҇8
.ᲂⷸ8
.ᲂⷸ҇8
.ᲂⷹ8
.ᲂⷹ҇8
.ᲂⷺ8
.ᲂⷺ҇8
.ᲂⷻ8
.ᲂⷻ҇8
.ᲂⷼ8
.ᲂⷼ҇8
.ᲂⷽ8
.ᲂⷽ҇8
.ᲂⷾ8
.ᲂⷾ҇8
.ᲂⷿ8
.ᲂⷿ҇8
.ᲂꙴ8
.ᲂꙴ҇8
.ᲂꙵ8
.ᲂꙵ҇8
.ᲂꙶ8
.ᲂꙶ҇8
.ᲂꙷ8
.ᲂꙷ҇8
.ᲂꙸ8
.ᲂꙸ҇8
.ᲂꙹ8
.ᲂꙹ҇8
.ᲂꙺ8
.ᲂꙺ҇8
.ᲂꙻ8
.ᲂꙻ҇8
.ᲂ꙼8
.ᲂ꙼҇8
.ᲂ꙽8
.ᲂ꙽҇8
.ꙋ8
.ꙋ̀8
.ꙋ́8
.ꙋ̈8
.ꙋ̑8
.ꙋ҆8
.ꙋ҆̀8
.ꙋ҆́8
.ꙋ҆̈8
.ꙋ҆̑8
.ꙋⷠ8
.ꙋⷠ҇8
.ꙋⷡ8
.ꙋⷡ҇8
.ꙋⷢ8
.ꙋⷢ҇8
.ꙋⷣ8
.ꙋⷣ҇8
.ꙋⷤ8
.ꙋⷤ҇8
.ꙋⷥ8
.ꙋⷥ҇8
.ꙋⷦ8
.ꙋⷦ҇8
.ꙋⷧ8
.ꙋⷧ҇8
.ꙋⷨ8
.ꙋⷨ҇8
.ꙋⷩ8
.ꙋⷩ҇8
.ꙋⷪ8
.ꙋⷪ҇8
.ꙋⷫ8
.ꙋⷫ҇8
.ꙋⷬ8
.ꙋⷬ҇8
.ꙋⷭ8
.ꙋⷭ҇8
.ꙋⷮ8
.ꙋⷮ҇8
.ꙋⷯ8
.ꙋⷯ҇8
.ꙋⷰ8
.ꙋⷰ҇8
.ꙋⷱ8
.ꙋⷱ҇8
.ꙋⷲ8
.ꙋⷲ҇8
.ꙋⷳ8
.ꙋⷳ҇8
.ꙋⷴ8
.ꙋⷴ҇8
.ꙋⷵ8
.ꙋⷵ҇8
.ꙋⷶ8
.ꙋⷶ҇8
.ꙋⷷ8
.ꙋⷷ҇8
.ꙋⷸ8
.ꙋⷸ҇8
.ꙋⷹ8
.ꙋⷹ҇8
.ꙋⷺ8
.ꙋⷺ҇8
.ꙋⷻ8
.ꙋⷻ҇8
.ꙋⷼ8
.ꙋⷼ҇8
.ꙋⷽ8
.ꙋⷽ҇8
.ꙋⷾ8
.ꙋⷾ҇8
.ꙋⷿ8
.ꙋⷿ҇8
.ꙋꙴ8
.ꙋꙴ҇8
.ꙋꙵ8
.ꙋꙵ҇8
.ꙋꙶ8
.ꙋꙶ҇8
.ꙋꙷ8
.ꙋꙷ҇8
.ꙋꙸ8
.ꙋꙸ҇8
.ꙋꙹ8
.ꙋꙹ҇8
.ꙋꙺ8
.ꙋꙺ҇8
.ꙋꙻ8
.ꙋꙻ҇8
.ꙋ꙼8
.ꙋ꙼҇8
.ꙋ꙽8
.ꙋ꙽҇8
.ꙍ8
.ꙍ̀8
.ꙍ́8
.ꙍ̈8
.ꙍ̑8
.ꙍ҆8
.ꙍ҆̀8
.ꙍ҆́8
.ꙍ҆̈8
.ꙍ҆̑8
.ꙍ҆̑̀8
.ꙍ҆̑́8
.ꙍ҆̑̈8
.ꙍ҆̑̑8
.ꙍ҆̑҆8
.ꙍ҆̑҆̀8
.ꙍ҆̑҆́8
.ꙍ҆̑҆̈8
.ꙍ҆̑҆̑8
.ꙍ҆̑ⷠ8
.ꙍ҆̑ⷠ҇8
.ꙍ҆̑ⷡ8
.ꙍ҆̑ⷡ҇8
.ꙍ҆̑ⷢ8
.ꙍ҆̑ⷢ҇8
.ꙍ҆̑ⷣ8
.ꙍ҆̑ⷣ҇8
.ꙍ҆̑ⷤ8
.ꙍ҆̑ⷤ҇8
.ꙍ҆̑ⷥ8
.ꙍ҆̑ⷥ҇8
.ꙍ҆̑ⷦ8
.ꙍ҆̑ⷦ҇8
.ꙍ҆̑ⷧ8
.ꙍ҆̑ⷧ҇8
.ꙍ҆̑ⷨ8
.ꙍ҆̑ⷨ҇8
.ꙍ҆̑ⷩ8
.ꙍ҆̑ⷩ҇8
.ꙍ҆̑ⷪ8
.ꙍ҆̑ⷪ҇8
.ꙍ҆̑ⷫ8
.ꙍ҆̑ⷫ҇8
.ꙍ҆̑ⷬ8
.ꙍ҆̑ⷬ҇8
.ꙍ҆̑ⷭ8
.ꙍ҆̑ⷭ҇8
.ꙍ҆̑ⷮ8
.ꙍ҆̑ⷮ҇8
.ꙍ҆̑ⷯ8
.ꙍ҆̑ⷯ҇8
.ꙍ҆̑ⷰ8
.ꙍ҆̑ⷰ҇8
.ꙍ҆̑ⷱ8
.ꙍ҆̑ⷱ҇8
.ꙍ҆̑ⷲ8
.ꙍ҆̑ⷲ҇8
.ꙍ҆̑ⷳ8
.ꙍ҆̑ⷳ҇8
.ꙍ҆̑ⷴ8
.ꙍ҆̑ⷴ҇8
.ꙍ҆̑ⷵ8
.ꙍ҆̑ⷵ҇8
.ꙍ҆̑ⷶ8
.ꙍ҆̑ⷶ҇8
.ꙍ҆̑ⷷ8
.ꙍ҆̑ⷷ҇8
.ꙍ҆̑ⷸ8
.ꙍ҆̑ⷸ҇8
.ꙍ҆̑ⷹ8
.ꙍ҆̑ⷹ҇8
.ꙍ҆̑ⷺ8
.ꙍ҆̑ⷺ҇8
.ꙍ҆̑ⷻ8
.ꙍ҆̑ⷻ҇8
.ꙍ҆̑ⷼ8
.ꙍ҆̑ⷼ҇8
.ꙍ҆̑ⷽ8
.ꙍ҆̑ⷽ҇8
.ꙍ҆̑ⷾ8
.ꙍ҆̑ⷾ҇8
.ꙍ҆̑ⷿ8
.ꙍ҆̑ⷿ҇8
.ꙍ҆̑ꙴ8
.ꙍ҆̑ꙴ҇8
.ꙍ҆̑ꙵ8
.ꙍ҆̑ꙵ҇8
.ꙍ҆̑ꙶ8
.ꙍ҆̑ꙶ҇8
.ꙍ҆̑ꙷ8
.ꙍ҆̑ꙷ҇8
.ꙍ҆̑ꙸ8
.ꙍ҆̑ꙸ҇8
.ꙍ҆̑ꙹ8
.ꙍ҆̑ꙹ҇8
.ꙍ҆̑ꙺ8
.ꙍ҆̑ꙺ҇8
.ꙍ҆̑ꙻ8
.ꙍ҆̑ꙻ҇8
.ꙍ҆̑꙼8
.ꙍ҆̑꙼҇8
.ꙍ҆̑꙽8
.ꙍ҆̑꙽҇8
.ꙍⷠ8
.ꙍⷠ҇8
.ꙍⷡ8
.ꙍⷡ҇8
.ꙍⷢ8
.ꙍⷢ҇8
.ꙍⷣ8
.ꙍⷣ҇8
.ꙍⷤ8
.ꙍⷤ҇8
.ꙍⷥ8
.ꙍⷥ҇8
.ꙍⷦ8
.ꙍⷦ҇8
.ꙍⷧ8
.ꙍⷧ҇8
.ꙍⷨ8
.ꙍⷨ҇8
.ꙍⷩ8
.ꙍⷩ҇8
.ꙍⷪ8
.ꙍⷪ҇8
.ꙍⷫ8
.ꙍⷫ҇8
.ꙍⷬ8
.ꙍⷬ҇8
.ꙍⷭ8
.ꙍⷭ҇8
.ꙍⷮ8
.ꙍⷮ҇8
.ꙍⷯ8
.ꙍⷯ҇8
.ꙍⷰ8
.ꙍⷰ҇8
.ꙍⷱ8
.ꙍⷱ҇8
.ꙍⷲ8
.ꙍⷲ҇8
.ꙍⷳ8
.ꙍⷳ҇8
.ꙍⷴ8
.ꙍⷴ҇8
.ꙍⷵ8
.ꙍⷵ҇8
.ꙍⷶ8
.ꙍⷶ҇8
.ꙍⷷ8
.ꙍⷷ҇8
.ꙍⷸ8
.ꙍⷸ҇8
.ꙍⷹ8
.ꙍⷹ҇8
.ꙍⷺ8
.ꙍⷺ҇8
.ꙍⷻ8
.ꙍⷻ҇8
.ꙍⷼ8
.ꙍⷼ҇8
.ꙍⷽ8
.ꙍⷽ҇8
.ꙍⷾ8
.ꙍⷾ҇8
.ꙍⷿ8
.ꙍⷿ҇8
.ꙍꙴ8
.ꙍꙴ҇8
.ꙍꙵ8
.ꙍꙵ҇8
.ꙍꙶ8
.ꙍꙶ҇8
.ꙍꙷ8
.ꙍꙷ҇8
.ꙍꙸ8
.ꙍꙸ҇8
.ꙍꙹ8
.ꙍꙹ҇8
.ꙍꙺ8
.ꙍꙺ҇8
.ꙍꙻ8
.ꙍꙻ҇8
.ꙍ꙼8
.ꙍ꙼҇8
.ꙍ꙽8
.ꙍ꙽҇8
.ꙗ8
.ꙗ̀8
.ꙗ́8
.ꙗ̈8
.ꙗ̑8
.ꙗ҆8
.ꙗ҆̀8
.ꙗ҆́8
.ꙗ҆̈8
.ꙗ҆̑8
.ꙗⷠ8
.ꙗⷠ҇8
.ꙗⷡ8
.ꙗⷡ҇8
.ꙗⷢ8
.ꙗⷢ҇8
.ꙗⷣ8
.ꙗⷣ҇8
.ꙗⷤ8
.ꙗⷤ҇8
.ꙗⷥ8
.ꙗⷥ҇8
.ꙗⷦ8
.ꙗⷦ҇8
.ꙗⷧ8
.ꙗⷧ҇8
.ꙗⷨ8
.ꙗⷨ҇8
.ꙗⷩ8
.ꙗⷩ҇8
.ꙗⷪ8
.ꙗⷪ҇8
.ꙗⷫ8
.ꙗⷫ҇8
.ꙗⷬ8
.ꙗⷬ҇8
.ꙗⷭ8
.ꙗⷭ҇8
.ꙗⷮ8
.ꙗⷮ҇8
.ꙗⷯ8
.ꙗⷯ҇8
.ꙗⷰ8
.ꙗⷰ҇8
.ꙗⷱ8
.ꙗⷱ҇8
.ꙗⷲ8
.ꙗⷲ҇8
.ꙗⷳ8
.ꙗⷳ҇8
.ꙗⷴ8
.ꙗⷴ҇8
.ꙗⷵ8
.ꙗⷵ҇8
.ꙗⷶ8
.ꙗⷶ҇8
.ꙗⷷ8
.ꙗⷷ҇8
.ꙗⷸ8
.ꙗⷸ҇8
.ꙗⷹ8
.ꙗⷹ҇8
.ꙗⷺ8
.ꙗⷺ҇8
.ꙗⷻ8
.ꙗⷻ҇8
.ꙗⷼ8
.ꙗⷼ҇8
.ꙗⷽ8
.ꙗⷽ҇8
.ꙗⷾ8
.ꙗⷾ҇8
.ꙗⷿ8
.ꙗⷿ҇8
.ꙗꙴ8
.ꙗꙴ҇8
.ꙗꙵ8
.ꙗꙵ҇8
.ꙗꙶ8
.ꙗꙶ҇8
.ꙗꙷ8
.ꙗꙷ҇8
.ꙗꙸ8
.ꙗꙸ҇8
.ꙗꙹ8
.ꙗꙹ҇8
.ꙗꙺ8
.ꙗꙺ҇8
.ꙗꙻ8
.ꙗꙻ҇8
.ꙗ꙼8
.ꙗ꙼҇8
.ꙗ꙽8
.ꙗ꙽҇8
8̀
̀1б
̀1ж
̀1ми1
̀2х
8́
́1а
́ба1
́1бли
́б1лю1
́1блѧ1
́б1н
́бно1
́б2р
́1бра
́бро1
́1брѣ
́брѧ1
́1брꙋ1
́б1ц
́б1ч
́бща1
́бы1
́бѣ1
́бꙋ1
́1ва
́вае1
́ва1с
́в1в
́1в2д
́вдо1
́1ве
́вед1
́1ви
́влю1
́в1лє
́2в1н
́вне1
́внѧ1
́внꙋ1
́1во
́во1с
́в1с
́в1ца
́2в1ч
́вше1
́1вы
́1вє
́1вї
́1вѡ
́1вѣ
́1вѧ
́1вꙋ1
́1га
́2гг
́1ги
́гл2
́г1ло
́гни1
́г1нꙋ
́1го
́гра1
́1да
́1д2в
́1де
́ди1в
́2дм
́2д1н2
́дно1
́1до
́д2р
́1дра1
́1дре
́д1с
́1ды2
́1дї
́1дї
́дѡ1в
́1дѣ
́1дꙋ
́1е
́еж2
́ема1
́емо1
́емꙋ1
́е2с
́ете1
́ет1н
́е2х
́1же
́жнꙋ1
́1жє1
́1жꙋ
́зво1
́з1вѣ
́зд2
́1зда
́з1др
́1здѣ
́1зе
́зе1р
́1зи
́2зл
́з1на1
́зни1
́з1но1
́з1нꙋ
́з1ра
́1зри
́1зрѧ
́1зы
́1зѣ
́1зѧ
́з1ꙋм
́1и
́й1
́и1в
́ил2
́иче1
́иша1
́2й1
́1ка
́1ки
́1клї
́кни1
́1ко
́1кр
́кры1
́крꙋ1
́2кх
́1кї
́1кї
́1кѡ
́1кꙋ1
́1ла
́ла1с
́л2д
́1ле
́1ли
́ли1н
́1ло
́л2х
́1лы
́1лю
́1лє
́лє1м
́1лї
́1лї
́1лѡ
́1лѣ
́1лѧ
́1лꙋ
́1ма
́1ме
́1ми1
́м1ли
́м1лѧ
́2м1н
́мна1
́мно1
́мнꙋ1
́1мо
́2м1п
́2мт
́1мы
́1мє
́1мі
́1мї
́мѡ1щ
́1мѣ
́1мѧ
́1на
́1не
́1ни
́н1к
́нми1
́ннї1
́ннї1
́1но
́н1ц
́н1ч
́1ны
́1ню
́1нѣ
́1нѧ
́1нꙋ
́нꙋи1
́1о
́ово1
́о2м
́1па
́1пе
́1пи2
́п2л
́пла1
́1пле
́пло1
́1плю
́1плѧ1
́2п1н
́1по
́п1с
́п1ш
́1пѡ1
́1пѣ1
́1пꙋ
́1ра
́р1ве
́рда1
́рди1
́р1дї
́1ре
́ре1д
́1ри
́рма1
́рна1
́рне1
́1ро
́ро1в
́р1р
́рта1
́2р1ц
́рша1
́рше1
́1ры
́1рю
́1рє1
́1рї
́1рї
́1рѡ
́1рѣ2
́1рѧ
́1рѷ2
́1рѷ2
́1рꙋ
́рꙋю1
́1са
́сав1
́1се
́1си
́с2к
́с2л
́сли1
́слѣ1
́смо1
́с1на1
́сни1
́с1но
́с1нꙋ
́1со
́1спе
́1спо1
́с1пѧ
́с1са
́с2т
́1ств
́1сте
́1сто
́стꙋ1
́1с2х
́с1цы
́с1ш
́сше1
́1сы
́1сѣ
́1та
́таи1
́тво1
́1твє
́1твѣ
́1те
́1ти
́ти1м
́2т1к
́2т1л
́тла1
́тли1
́т1н
́тна1
́тне1
́тнꙋ1
́1то
́то1р
́1тре
́1три1
́1тро
́1тры
́1трѣ
́1трꙋ
́2т1ц
́тцы1
́1тча
́1ты
́ть1
́1тє
́1тї
́1тї
́1тѡ
́1тѣ2
́1тѧ
́тѧ1н
́1тꙋ1
́1ха
́1хи2
́1х2м
́1хо
́хї2
́хї2
́хꙋ1
́1ца
́1це1
́1цы1
́1цѣ2
́1цꙋ
́чат1
́че1в
́че1с
́чи1с
́ч1н
́2ч1т
́чє1
́чї1
́чї1
́1чꙋ1
́шне1
́шꙋ1
́1ща1
́щна1
́щно1
́1щє1
́щѧ1
́1ю
́1є
́1ї
́їа1
́їи1
́ї2к
́ї1л2
́1ї
́їа1
́їи1
́ї2к
́ї1л2
́1ѡ
́1ѣ
́1ѧ
́ѧв1
́ѧ1т
́ѧти1
́ѳ2
́1ѳе1
́ѳо2
́ѵи1
́ѵ2к
́ѵ2с
́1ѻ
́1ꙋ
8̆
8̇
8̈
̈1е
8̏
8̑
̑1ва1
̑в1ни1
̑1внѣ
̑в1с
̑1вы
̑2гг
̑1ги
̑гꙋ2
̑гꙋб1
̑1да1
̑даю1
̑ди1
̑2д1н
̑дни1
̑дны1
̑днї1
̑днї1
̑1до1
̑1др
̑1ды
̑1дї1
̑1дї1
̑1дѣ2
̑дѣн1
̑1дꙋ1
̑2жд1
̑жны1
̑жї1
̑жї1
̑за2
̑зан1
̑з1на1
̑1зни
̑зны1
̑1зы
̑1и2
̑й1
̑йши1
̑ин1
̑2й1
̑йши1
̑1ка1
̑1ки
̑2кл
̑1кї1
̑1кї1
̑1ла
̑1ли
̑лла1
̑1ло1
̑1лы1
̑1лї1
̑1лї1
̑1ма1
̑м1н
̑мны1
̑1мы1
̑1ни1
̑1ны
̑нї1
̑нї1
̑1нѧ
̑1па2
̑1пи1
̑пкї1
̑пкї1
̑1п2л
̑2п1н
̑пни1
̑пны1
̑пї1
̑пї1
̑1ра
̑1ри
̑рна1
̑р1с
̑1ры
̑1са
̑с2л
̑1см
̑с1на1
̑1сни
̑с1с
̑с2т
̑1та1
̑1тв
̑1ти
̑т1н
̑тна1
̑тны1
̑1ты1
̑1тї1
̑1тї1
̑2х
̑1ц
̑че1
̑чи1
̑ч1н
̑чна1
̑чї1
̑чї1
̑1щ
̑ща1
̑1ю1
̑1ѧ2
̑ѧн1
̑ѵ1
8̾
̾1е
̾1и
̾и́1
̾и1м
̾1н
̾не1
̾2с2
̾1ѡ1
̾1ѧ
̾1ѻ1
̾1ꙋ
̾ꙋ́2
̾ꙋ́м1
̾ꙋ1в
̾ꙋго1
̾ꙋмѣ1
8а.
а2̀
8а̀8.
8а́8.
а́ва1
а́в1ц
а́г2
а́1гл
а́да1
2а́е
2а́ж
2а́з
а́з1в
а́1зр
а́з1ꙋ
а́к2
а́ка1
а́1кл
а́ла1
а́л1м
а́лꙋ1
а́м1в
а́м1л
1а́мь
а́мє1
а́мꙋ1
а́н1м
а́н1т
1а́ню
а́нѧ1
2а́1п
а́по1
а́р1в
а́р1г
а́с1н
а́с1п
2а́т
а́ти1
2а́х
а́1ц
а́чи1
2а́ш
а́ша1
а́щꙋ1
2а́ю
2а́ї
2а́ї
а́7ѣ
2а́ѧ
2а́2ѯ
а́1ѳ
2а́ѵ
а́ѵ1р
а2̑
8а̑8.
а̑2б
а̑в1н
а̑ж2
1а̑2м1
1а̑нѧ
а̑1п2
а̑2р1
а̑с1н
2а̑х1
а̑2ч1
а1а
аа́1н
аа̑2
а1б2
або1л
абы̑1
абѣ2
абꙋ́1
2ав
а1ва
ав1в
а2в1д
а1ве
а1ви
ав1лє
а2в1н
а1во1
аво́1
аврї1
аврї1
авше1
а1вы
авї1
а1вї1
а1вѡ
а1вѣ
а1вѵ
авѵ́1
авѷ1
авѷ1
а1вꙋ
авꙋ́1
а1г
а2г1г
агда1
1аге
2аго
аго́1
аго1р
агра1
агрѧ1
а1да
ада̑1
2а1де
2адѝ
ади1в
а2д1н
адно1
а1до
адо1с
а1ды
2адѐ
а1ді
адї1
а1дї1
2адѝ
2а1дѣ
2адѧ
а1дꙋ2
2а1е
ае́1ш
ае1д
аеди1
ае2к1
ае1с
аесѣ1
2а1ж2
аза2
азах1
аз1в
2азд
азди1
аз1др
аз1ды
аз1дѣ
а1зе
а1зи
2аз1л
а1зна
азо1р
2а2з1р
а1зы
азѡ1
а1зѣ
2азꙋ
2а1и
аи́1т
ай1
айшї1
айшї1
аи̑2
аи̑н1
аи1л
аи1м
аимо1
2а2й1
айшї1
айшї1
а1к
ака́1
ака̑1
аке1
аки1
акл2
ако1в
ако1н
ако1р
акос1
1акі
акѡ1в
а1ла
ала1л
ала1м
ала1х
ал1д
а1ле
1ален1
а1ли
али̑1
али1н
1алле
аллї1
аллї1
ал1м
а1ло
а1лы
а1лю
алю́1
а1лі
алї1
а1лї1
а1лѝ
а1лѡ
а1лѣ
а1лѧ
а1лꙋ2
а1ма
ама1р
1ам1в
а1ме1
1амер
а1ми
а1мо
амо1в
амо1м
а2м1п
а2м1ч
2амъ
а1мы
а1мі
амї1
а1мї1
а1мѝ
а1мѣ
амꙋ́1
2а1на
анас1
ан1д
а1не2
2а1ни
1анні
аннї1
аннї1
а1но
ано́1
ано1в
ан1ц
2анъ
а1ны
а1ню2
а1нѐ
1а1ні
ані́1
2анї1
2анї1
а1нѝ
анѡ1н
а1нѣ
а1нѧ
а1нꙋ
анꙋ́1
1анꙋа
2а1п2
апе́1
апер1
апе1т
апи́1
апре1
апі́1
апї1
апї1
а1ра
ара1с
ар1в
ар1д
ардо1
2а1ре
аре1м
2а1ри
ар1к
аркї1
аркї1
ар1л
ар1м
а1ро
аро1в
ар1с
ар1т
артї1
артї1
а1ры
2арь
а1рю
а1рѐ
а1рє
арє1м
а1рі
арі́1
арї1
арїи1
а1рї1
арїи1
2а1рѝ
а1рѡ
1арѡ̑
а1рѣ
2а1рѧ
а1рѷ1
а1рѷ1
а1рꙋ2
а1са
а1се2
а1си
ас1ло
а2с1н
а1со
ас1па1
ас1пе
аспи1
ас1пѧ
ас1с
ассї1
ассї1
2аст
ас1тв
ас1тл
а1стр
а1стѝ
а1сы
а1сѐ
а1сє
асє́1
асі́1
а1сѝ
а1сѡ
а1сѣ
2асѧ1
2ат
а1та
ата́1
ата̑1
ата1в
ата1н
а1тв
а1те
ате́1
а1ти
ати1л
а1т2л
а1то
ато́1
ато1с
а1тр
атрї1
атрї1
а1т2ч
а1ты
аты̑1
а1ті
аті́1
атї1
а1тї1
а1тѝ
а1тѡ
а1тѣ
а1тѧ
а1тꙋ
атꙋ́1
2а1ф2
афа2
афї1
афї1
афѵ́1
2ах
а1ха
аха́1
аха1л
а1хи
а1хо
а1х2т
ахі́1
ахѡ́1
ахꙋ1
а1ц
ацѣ2
а1ч
ачер1
аче1с
ач1н
ачꙋ2
а1ш
ашє́1
ашꙋ2
ашꙋ́1
а1щ2
аща́1
ащꙋ2
2а1ю
ающї1
ающї1
а1і
аі́1
аї1
аїа1
а1ї1
аїа1
2а1ѡ
аѡ1н
2а1ѧ
аѧ́1т
аѧ́ю1
аѯа́1
а1ѳ2
аѳа2
аѳо1
аѳі́1
а1ѵ́1
аѵ1р
аѵ1с
8а҆̀8.
8а҆́8.
а҆́1б
а҆́л1
а҆́1м
а҆́н1
а҆́нгел7ми.
8а҆̈8.
8а҆̑8.
а҆а1
а҆дѡ1
а҆1з2
а҆к2
а҆кꙋ1
а҆ме1
а҆мо1
а҆ра1
а҆1ск
а҆1ст
а҆ѵ1
8аⷠ.
8аⷠ҇.
а2ⷡ
8аⷡ.
8аⷡ҇.
8аⷢ.
8аⷢ҇.
8аⷣ.
8аⷣ҇.
а2ⷤ
8аⷤ.
8аⷤ҇.
8аⷥ.
8аⷥ҇.
8аⷦ.
8аⷦ҇.
8аⷧ.
8аⷧ҇.
8аⷨ.
8аⷨ҇.
2аⷩ
8аⷩ.
8аⷩ҇.
8аⷪ.
8аⷪ҇.
8аⷫ.
8аⷫ҇.
8аⷬ.
8аⷬ҇.
а2ⷭ
8аⷭ.
8аⷭ҇.
8аⷮ.
8аⷮ҇.
8аⷯ.
8аⷯ҇.
8аⷰ.
8аⷰ҇.
а2ⷱ
8аⷱ.
8аⷱ҇.
8аⷲ.
8аⷲ҇.
8аⷳ.
8аⷳ҇.
8аⷴ.
8аⷴ҇.
8аⷵ.
8аⷵ҇.
8аⷶ.
8аⷶ҇.
8аⷷ.
8аⷷ҇.
8аⷸ.
8аⷸ҇.
8аⷹ.
8аⷹ҇.
8аⷺ.
8аⷺ҇.
8аⷻ.
8аⷻ҇.
8аⷼ.
8аⷼ҇.
8аⷽ.
8аⷽ҇.
8аⷾ.
8аⷾ҇.
8аⷿ.
8аⷿ҇.
а1ꙋ
аꙋ́1т
аꙋ́1ч
8аꙴ.
8аꙴ҇.
8аꙵ.
8аꙵ҇.
8аꙶ.
8аꙶ҇.
8аꙷ.
8аꙷ҇.
8аꙸ.
8аꙸ҇.
8аꙹ.
8аꙹ҇.
8аꙺ.
8аꙺ҇.
8аꙻ.
8аꙻ҇.
8а꙼.
8а꙼҇.
8а꙽.
8а꙽҇.
2б.
2б̾1
1ба
ба́1н
ба́1с
ба́1т
ба́1ч
ба́1ш
ба̑2
ба1в2
баг2
ба1н
2б1б
2бвѐ
бве́1
2б1ви
бви́1
2бвѐ
2б1вѝ
1бг
2б1де
б2ди
бди́1
1б2дѣ
1б2е
бе2з1
бе1р2
бе1с
бет1
бе2х
1бж
1б2з2
бза2
бза́1
бзꙋ́1
1б2и
би́1д
би́1н
би́1с
би́1ц
би̑1
била1
би2м
бин2
би1р
би1с2
бити1
биша1
бл2
1бла
б1ла̀
бла́з7нен
бла1д
1бле1в
1блег1
б1лек
бле1м
б1лен
1бле1с
б1ле1ц
б1леч
1б2лѝ
1бли́
1ближ
1блим
1блис
2б1ло1
2блъ
2бль
б1лю̀
1блю́
1блю1д
б1лющ
2б1лє
блєн1
1б2лї1
1б2лї1
1б2лѝ
1блѧ.
1блѧ̀
б1лѧ́1
1блѧ̑
1блѧг
1бл҃
1блꙋ
2б1м
2бн2
бна1
бне2
б1нем
б1нет
б1ни
б1нов
бно1м
б1ны.
бнї1
бнї1
б1нѣ.
б1нѣм
б1нꙋ
1б2о
бо́1з
бо́1к
бо́1ц
бое2
бож2
бо1з2
болѣ́7зне
болѣ́7зни
бо1н
бо1р
бор1ц
бос2
бо1щ
бою́1
боѧ́7зни
бр2
1бра.
1бра̀
1бра̑
1браг
1браж
1браз
1бран
б1рат
1браѧ
1б2ре
бре1м
бре1т
1б2ри
1б2ро
бро1н
2бръ
1б2ры
2брь
1брє1
1брї1
1брї1
1б2рѡ2
1брѣ.
1брѣй
1брѣй
1брѣс
1брѣт
1б2рѧ
брѧ́1
1брꙋ̀
б1рꙋ́
б1рꙋг
1брꙋю
2б1с2
бско1
бсто1
2б1х
бхо́1
2бц
б1ца
б1цы
б1цꙋ
2бч
2б1ш
бша1
бшꙋ1
б2щ
1бща
бща́1
1бще
бще́1
1бщи
2бщн
1бщї2
1бщї2
2б2ъ
1бы
бы́7вы
бы́1д
бы́1ш
бы̑1н
бы1м
2бь1
1бѐ
1бє
бє́2
бє́с1
1бі
бі́2
бї1
1бї1
1бѝ
1бѡ
бѡ́1г
бѡ́р1
бѡ̑1
бѡ1л
1бѣ
бѣ́1ж
бѣ́1л
бѣ́1м
бѣ́1ш
бѣ1д
бѣдо1
бѣ1л
бѣ1с
бѣ1т
бѣто1
1б2ѧ
бѧ́1х
бѧ2т
бѧще1
б҃2
1бꙋ
бꙋ́1д
бꙋ̑1
бꙋ2з1
бꙋ1р
в̾2
в2а
1ва́1г
ва́1д
1ва́е
ва́1ж
1ва́й
1ва́й
1ва́м
ва́1т
ва́1ш
1ва́ю
1ва́є1
1ва́ѧ
1ва̑1н
1ва̑р
ва̑1ш
1ва̑ю
1вав
1вагѡ
ва1д
1вае
1вай
1вай
1вак2
вал2
1валъ
1вани
1ванн
1ванї
1ванї
1варѝ
1варс
1варъ
1вары
1варѝ
1варѡ
1варѧ
1вас
ва1ст
1ва1т
вати1
вах2
1вахо
1вахꙋ
1ваш
ваша1
ваше1
1ваю
вают1
1ваѡ
1ваѧ
2ваⷤ
2вв
в1ва
вва́1
в2ве
вве1д
ввер1
вве1с
в1во.
вво́1
в1вы
в1вꙋ
2в1г
вго1
1вда.
в1да́
в1да̑1
2вди
1в2до
1в2ды
1в2ді
в2дѡ
1в2дѣ
1в2дꙋ
в2е
1вѐ
1ве́а
1ве́д
1ве́и
1ве́к
1ве́м
1ве́с
1ве́т
ве́7тсѣмъ.
ве́тхо7мꙋ
1ве́ц
ве́1ч
1ве́1ш
ве1в
1ведд
1веди
1вед1н
1ведо
1ведꙋ
ве2з1
1ве1л
веле1
1вена
1вене
1вени
1вен1т
1венц
венї1
венї1
1вера
вер1д
1верз
1вери
веро1
1верш
1веръ
1верꙋ
1вес
ве1ст
1ве1т
1вецъ
1ве1ч
1вещ
в2ж
вжи1
1в2з2
вза1
взи1
взы́1
в2и
вѝ1
1ви́д
1ви́м
1ви́н
1ви́р
1ви́ц
1ви́1ч
1ви́ш
1ви̑
ви̑н1
1вив
2виг
2виж
2ви1з2
1вил
вила1
1вим
вима1
вимо1
1ви1н
ви1р
1вирї
1вирї
1вис
вис7сарїѡ́н
вис7сарїѡ́н
1вит
вити1
ви1ф
1вих
вице1
1вича
1вичю
1вичѣ
1вичꙋ
1виш
виша1
1вищ
в2к
вл2
1в2ла
вла1д
вла1с
1влек
1вле1ц
1влеч
1влещ
2в1ли
в2ло1
2влъ
2вль
в1лю̀
в1лю́1
в1лєн1
1в2лі
1в2лѣ
влѣ́1
в1лѧ.
влѧ́1
1в2м
вма́1
вмѣ1
вмѣ́1
в1на1
1вна̀
вне́1
1внег
в1нее
вне1м
в1ни.
в1ник
в1них
в1ниц
вно1
в1нод
в1ном
2внш
2внъ
2в1ны
2в1ню1
2внї
2внї
1внѡ́
1внѣ̀
2внѧ
в1нѧг
1внꙋ̀
в1нꙋю
во́з1
1во́л
1во́н
1во́т
1во́ю
1воа
во1в
1вовѣ
1вог
1вода
1води
вод1н
во8дна́
во8дно́
во8дны́
1воды
1водѝ
1водѣ
1вое.
2воѐ
вое1м
вож2
1вожꙋ
воз1
1возб
1возв
1возг
воз8да́н
1возм
1возн
возо1
1возс
1возш
1вой
1вок
1вол
1вомꙋ
1вон
вона1
1воп2
во1р
1воро
вор1ц
1вос
воси1
восо1
1вот2
воца1
1воч
воче1
во2ш1
2воѐ
2воє
2воѝ
1воѡ
2воѧ
в2п2
впа1д
впе1
1в2р2
вра̑1
вра1з
вре1д
вре1м
вро2
вро́1
врꙋ1
2вс2
в2са
в2се
все1н
все1р
все1х
все1ц
всеѡ1
в2си
вска1
вскї1
вскї1
в1ст2
в2сы1
в2сю
в2сѐ
в2сѝ
в2сѣ
всѧ́1
в2сꙋ
всꙋ́1
1в2т
вто1р
в2х2
вц2
в1ца.
1вца́
в1цы̀
2в1цє
1в2ча
1вче́
вче1р
2вчї1
2вчї1
2в1ш2
вша1
вшаѧ1
вше1м
вшꙋ1
2в2ъ
в2ы
1вы́
вы́1м
вы́1н
1вы̑
1вый
1вый
1вык
1выма
вы1с
1вы1ш2
2вь1
1вѐ
1вє́1л
1вє́н1
1вє́с
вє́1т
1вєд
вєн1
1ві
ві́1к
в2ї
вї1к
вї2л1
вї1м
вї1н
вї1с
в2ї
1вїа
1вїй
1вїй
вї1к
вї2л1
1вї1м
вї1н
вї1с
в2ѝ1
1вѡ.
1вѡ́1д
1вѡ́л
1вѡ́р
1вѡ́т
1вѡв
2вѡи
1вѡм
в2ѣ
1вѣ́д
1вѣ́е
1вѣ́ж
1вѣ́й
1вѣ́й
1вѣ́м
1вѣ́н
вѣ́8ст7во
1вѣ́ц
вѣ́1ш
1вѣ̑д
1вѣ̑к
1вѣ̑с
1вѣ̑т
вѣ̑ч1
1вѣд2
1вѣе
2вѣ2з1
1вѣй
1вѣй
вѣко1
2вѣ1л
1вѣмъ
1вѣрѧ
1вѣс
вѣст7во
вѣст7вꙋ́
2вѣт
вѣто1
1вѣх
1вѣщє
в2ѧ
1вѧ.
1вѧ̀
1вѧ́д1
1вѧ́1с
1вѧ́1х
1вѧ́ш
1вѧ́щ
1вѧд
вѧ1з2
1вѧзе
1вѧтс
1вѧтъ
1вѧть
1вѧ1х
вѧ1ч
вѧче1
1вѧш
1вѧщи
1вѧщы
1вѧщї
1вѧщї
1вѵ́1л
1вѵ́п
вѵ́1т
1в2ѷ
вѷ2с1
1в2ѷ
вѷ2с1
в҃2
в҃и́1
в҃о1
в҃ы1
2вⷣ2
в2ꙋ
1вꙋ́.
1вꙋ́л
1вꙋ́р1
1вꙋ́т
1вꙋ́1щ
1вꙋ1д
вꙋе1м
1вꙋ1х
вꙋхо1
1вꙋю.
г2а
1га̀
1га́в
га́1г
1га́е
1га́й
1га́й
1га́л
1га́м
1га́н
1га́п
1га́т
1га́1х
1га́1ш
1га́ю
1га́ѳ
га̑1
1га̑т
гаа́1
га1в
1гаг
1га1д2
1гае
1гаж
1гай
1гай
га1л
га1м
гама1
2га1р
1га1с
1га1т
1гаѧ
1гаѳ
1г2в
1г2гі
2гг҃
г2д
1гда
гда́1
гда1л
1гдо2
гдо́1
2гдъ
1гдѣ
гдѣ́1
1ге
ге́р1
ге1д
геде1
гее2
ге2н1
гер1м
геѡ2
г2и
1ги.
1гѝ
1ги́б
1ги́з
ги́1н
1ги́1т
1ги̑2
ги̑з1
1гиб
1гим
1ги1с
1гих
2г1к2
гко1
гкѵ́1
1гла
гла1в
гла1с
1г2ле1
1г2ли
г1ло.
гло́1
1глот
2глс
2глъ
2г2лы
2гль
1г2лі
глї1
1г2лї1
1г2лѡ
1г2лѣ
1г2лѧ
глѧ́1
г2лѷ1
г2лѷ1
2г2лꙋ
1г2м
гма́1
1г2на2
1гне́
1гнед
1гнез
г1нем
1гнен
1гнеп
1гнер
г1нет
1гнец
1гнеѡ1
г1ни.
1г2нѝ
1гни́1
1гниц
1г2но
2гн1ц
2гн1ч
2гнъ
2гнь
1г2ню2
1г2ні
гнї2
1г2нї2
1г2нѝ
1г2нѣ
1г2нѧ
г1нꙋ1т
1гнꙋш
г2о
1го.
1го̀
1го́.
1го́д
1го́1ж
го́1м
1го́1н
1го́р
1го́1с
1го́ф1
1го́х
1го́ш
1го́ю
1гоб2
го1в2
1гова
1гови
1говм
1гогл
1гогр
1годи
1годо
1годꙋ
1гое
1гож2
1го1з2
гоиз1
1гок
го1л
голꙋ1
1гом
1го1н2
гона1
гоп2
1гопи
1гопл
1гопо1
1гопѣ
1гори
1горо
1горч
1горї
1горї
го1с2
1госв
1госѧ
госꙋ1
1гот
1гох2
1гоц
1гоча
гочє1
1гою
1гоѡч
1гоѧ
гоѧв1
1гоѹ
1гоѻ
1гоᲂу
гоꙋ1
1гоꙋв
1г2р2
гра̑1
гра1н
гре́1
гре1м
гро1м
грі́1
грї2
грї2
грѷ1
грѷ1
грꙋ1
2г1с2
гст2
1г2т
2г1х
гха́1
1г2ца
2г1цѣ
2г1ч
2г1ш2
гша1
гше1
гшї1
гшї1
2г2ъ1
1гє
1гі́а
1гі́е
1гі́и
1гі́ю
1г2ї
гї1г
1гі̑1
1г2ї
гї1г
1гѝ
1гѡ
гѡ́д1
гѡ́1ж
гѡ́р1
гѡ1с2
1гѣ
1гѵ
гѵ́1
г҃2
г҃о1
2гⷣ2
2гⷭ
1г2ꙋ
гꙋ́1
гꙋ̑1
гꙋб1л
гꙋ2т
гꙋю1
2д2̾1
д̾ѧв1
д̾ꙋ1
д2а
да́1г
да́1д
1да́й
1да́й
1да́к
1да́м
1да́р
да́1ш
да́є1
1да̑р
1да̑т
1дав
дав1л
1даг
1да1д
1дае
1дайт
1дайт
1дак
дако1
1дала
1дале
1далъ
1далї
1далї
да1м
1дама
1данъ
1данї
1данї
1да1р
даро1
1да1с2
1да1т
дати1
1дахꙋ
1даш
1даю
1даѧ
2д1б
дбѣ2
дв2
1два̀
два́1
два1н
д1ва1р
д2ве
две1р
1д2ви
дви́8г7ла
д1воз
1двор
д2вє
двє́1
2двѣ
двѣ1м
1дв҃
д2вꙋ
2д1г2
дгла1
дгрѧ1
2д1д
д2е
1дѐ
1де́а
1де́б
1де́ж
1де́и
1де́1к
1де́р
1де́с
1де́т
1де́ц
1де́ч1
1де́1ш
1де́ю
1де́є
1де́ѡ
1деб
дебе1
1де1в
1деж
1дей
1дей
2де1л
1дем
1ден
1дер1
де1с
1деса
1десе
1десѝ
1десн
1десы
1десѐ
1десѝ
1десѣ
1десѧ
1дета
1дете
1де2х
1дец
2дею
1деѡ́
2д1з2
1д2и
ди́1с
ди́1щ
ди̑в1
ди̑1м
див1л
диво1
ди1л
дима1
димо1
ди1н
дино1
ди1р
дис2
ди1ф
2д1к
дка1
дкло1
дко1
дл2
2дла
дла̑1
д1лаг
д1леж
1длен1
2д1ло1
д2лѧ
д2м
1дма
дма́1
1дме1
1дми
дми́1
1дмо2
дмо́1
1дмы
2дмь
1дмѝ
дна1
д1на́1
д1нас
д2нѐ
1дне́
1днеа
днев1
дне8внꙋ́
д1нем
1дне1с
1днеє
д1ни.
2д1нѝ
д1ни́
д1них
д1но́1
1дно1в
1днол
д1но1м
1днос
д1ноє
2днс
1дны.
д1ны́
д1ным
2дню
д1ню.
д2нѐ
2днї
2днї
2д1нѝ
2днѡ
д1нѣм
2д1нѧ1
днꙋ1
1днꙋе
1днꙋи
д2о
1до̀
1до́
до́1в
до́1г
до́1с
1доб
доб1л
добо1
до1в2
1дове
1дово
1довы
1дод
1дое
1дож2
1дои
дои́1
1док
1дол
1дом
дома1
дом1н
домо1
1до1н
1доп
до1р
1дос2
дости́8г7ла
1дот2
1дох
1доч
доче1
2дою
1доѯ
доꙋ1
1доꙋм
2д1п2
дпи́1
дпо1
дпро1
дпꙋ1
1дра.
1дра̀
1драг
1драж
д1раз
1драѧ
1дре.
д1рек
дре1м
1дрен1
д1реч
1д2ри
1д2ро
дро1в
дро1м
дро1н
2др1с
2дръ
1д2ры
1д2рі
дрї1
1д2рї1
1д2рѡ
дрѡ́1
1д2рѣ2
дрѣ́1
дрѣ́7вле
1д2рꙋ
2дс2
дска1
дско1
д1со2
д1ст2
2д1т
дте́1
2дх2
д1хо2
дхо́1
2д1ц2
2д1ч
2д1ш2
дша1
дше́1
дше1м
дшꙋ1
д2щ
дщє́1
2д2ъ
д2ы
1ды́
ды́1к
ды́1н
ды́1ш
1дыг
1дый
1дый
1дым
1ды2р
1дых
1дыѧ
2д2ь1
1дѐ
1дє́ж
1дє́и
1дє́й
1дє́ч1
1ді́д
1ді́е1
1ді́и
1ді́м
1ді́с
1ді́1т
1ді́ѳ
д2ї
1дїа
1дї1г
1дїѐ
1дїе́
1дїи
1дїй
дїо1
1дїф
1дїц
1дїю
1дїѐ
1дїѝ
1дїѡ
1дїѧ̀
1дїѧ́
1ді̑
д2ї
1дїа
1дї1г
1дїѐ
1дїе́
1дїи
1дїй
дїо1
1дїф
1дїц
1дїю
1дїѐ
1дїѝ
1дїѡ
1дїѧ̀
1дїѧ́
1д2ѝ
1д2ѡ
дѡ2м
дѡ1н
дѡна1
д2ѣ
1дѣ́
дѣ́1ж
дѣ́1с
дѣ́1т
дѣ́1ш
1дѣ̑
1дѣв
1дѣд
1дѣл
1дѣм
1дѣн
1дѣ1с
1дѣ1т
дѣто1
1дѣх
1дѣш
1дѣѧ
1д2ѧ
дѧ́1х
дѧз2
дѧ2т
дѧ1х
1дѵ
дѵ́2
2дⷧ
д2ꙋ
1дꙋ́1г
1дꙋ́е
1дꙋ́ж1
1дꙋ́1з
дꙋ́1л
дꙋ́1с
1дꙋ́х
1дꙋ́ш
1дꙋ́1щ
1дꙋ̑
дꙋ̑ж1
дꙋ1б
1дꙋе
1дꙋж
1дꙋи2
дꙋим1
1дꙋй
дꙋ2т
1дꙋх
1дꙋш2
дꙋща1
1дꙋю
1дꙋѧ
8е.
8ѐ8.
е2́
8е́8.
2е́а
е́бе1
е́ви1
е́в1л
е́г1ц
е́дї1
е́дї1
2е́е
е́е1в
е́жа1
е́за1
е́з1д
е́з1н
е́зо1
е́1зр
е́1зꙋ
е́ко1
е́м1в
1е́мы
1е́мь
е́на1
е́н1м
е́но1
е́нї1
е́нї1
е́нꙋ1
е́п2
е́р1б
е́са1
е́с1н
е́1тв
е́те1
е́ти1
2е́2ц
2е́ч
е́ши1
е́щї1
е́щї1
е́ю1
2е́є2
е́1ѯ
2е́1ѳ
е́ѵ2
1е́ѵк
8ё8.
е2̑2
8е̑8.
е̑н1
е1а
еа́н1
еа̑1
еа1з2
еа1м
е1б
ебе1л
еб1ле
еб1лю
ебо́1
ебѣ2
е1ва
ева́1
ева̑1
ева1с
2е1ве
еве1д
еве1р
еве1с
евзы1
е1ви
еви̑1
ев1ле
ев1лѧ
е1вни
е1вно
е1во
евол1
ево1н
евос1
евра1
ев1с
1евск
е1вы
евы1м
е1вє
евє́1
е1вѡ
е1вѣ
евѣ1с
е1вѧ
евѧ́1
евѧ1т
е1вꙋ
е1г
ега1
еги́1
его́1
егра1
егре1
егрѣ1
егѡ́1
егꙋ1б
е1да
еда̑1
ед1ва1
ед1во
ед1вѣ
е1де
еди̑1
1един
ед1ла1
е1дм
ед1на
е1дне1
ед1ни
ед1но1
ед1ны
еднї1
еднї1
ед1нѣ
ед1нꙋ
е1до
едо1м
едо1с
едох1
едр2
ед1ра
ед1с
ед1х
е1ды
2е1ді
е1дѣ
едѣ1л
е1дꙋ2
е1е
ее́н1
ее1с
е1ж
еза1х
е2з1в
е2з1д
езды1
е1зе
езе́1
1езек
е1зи1
е2з1н
езна1
езне1
езо́1
езпо1
е1з2р
е1зы2
е1зѧ
ез1ꙋ
е1и
еи́1
ей1
1ейж
еиз1
еи1м
еи1сп
еи1т
е2й1
1ейж
е1к
ека2
ека́1
1екк
еко1н
2екі
екї1
2екї1
екꙋ2
ел2
е1ла
ела̑1
е1ле
2е1ли
ели̑1
е1ло
ело1в
2елп
2елъ
е1лы
2ель
е1лю
елю́1
елю1б
е1лє
елє1н
е1лї1
е1лї1
е1лѝ
2е1лѡ
е1лѣ
2е1лѧ
е1лꙋ1
е1ма
ема́1
1емаѧ
2е1ме
еме1н
1емж
е1ми
1еми.
2емѝ
еми1н
2е1м2л
2ем1н
е1мо
емол1
1емо1м
емо1р
емощ1
1емою
2е2м1п
е1мы
1емы1м
1емь
емї1
е1мї1
1емїи
2е1мѝ
2емѡ
емѡщ1
2е1мѣ
2е1мѧ2
емѧ́1
2емⷣ
2ен
е1на
ена1д
е1не
ене1с
енеѡ1
е1ни
ени1х
ен1м
е1но
ено1в
ено1м
ентї1
ентї1
ен1ц
е1ны
е1ню1
е1нѐ
е1ні
е1нѝ
е1нѣ
е1нѧ
енѧ́1
е1нꙋ
е1о
ео́1г
ео́1д
ео́н1
ео́1п
ео́1ф
ео1н
е1п2
епе1т
епи1
епо1
епре1
епро1
1епі
епі́1
епѣ́1
1епⷭ
е1ра
ераз1
ер1б
ер1в
ерво1
ер1г
е1ре
ер1ж2
ер1з2
е1ри2
ер1к
ерн2
ерна1
е1ро
1еро1в
1еро1м
ерп1л
ер1с
ер1тв
ер1х
е2р1ц
2еръ
е1ры
е1рю
е1рє1
е1рі
ері́1
ерї1к
ерїн1
е1рї
ерї1к
ерїн1
е1рѝ
1е1рѡ
ерѡ1н
е1рѣ1
е1рѧ
ерѧ́1
1ерⷭ
е1рꙋ
1ерꙋс
ес2
е1са
2е1се
е1си
2е1ск
еско1
ескꙋ1
еслꙋ1
е1сн
е1со
есож1
есо1м
е1сп
еспа1
есса1
1ессе
е1ств
е1сте
е1сто
е1стр
е1сы
е1сѐ
е1сє
есї1
есї1
е1сѝ
е1сѡ
есѡ́1
е1сѣ
е1та
ета̑1
1етас
2е1тв
е1те
2етѐ
етер1
1етес
2е1ти
2е1т2к
2е1т2л
1ет1на1
1ет1но
1ет1ны
2е1то2
ето́1
2е1тр
2етш
е1ты
еты́1
еты1р
2е1тѐ
2е1тє
2е1ті
етї1
2е1тї1
2е1тѝ
2е1тѡ1
е1тѣ
2е1тѧ
е1тꙋ
етꙋ́1
е1ф2
ефа2
ех2
е1хи1
2е1хо
2ец
е1ца
е1це2
е1цы
е1цѣ2
е1цꙋ
еча1т
ече1р
ечи1с
еч1н
ечна1
е1чѐ
е1чⷭ
е1чꙋ2
е1ш2
2еше2
еши1
2ешл
е1щ
еще́1
ещи́1
е1ю
е1є
е1ѕ2
2е1ѡ
еѡ́р1
еѡ1д
еѡ1р
еѡ1с2
е1ѧ
еѧ́1
е1ѯ
еѯа2
е1ѱ
е1ѳ2
еѳо2
еѵ1к
еѵ1р
еѵ1с
е1ѻ1
еѻр2
е1ѿ1
е҆1
8е҆̀8.
8е҆́8.
8е҆̈8.
8е҆̑8.
8еⷠ.
8еⷠ҇.
е2ⷡ
8еⷡ.
8еⷡ҇.
8еⷢ.
8еⷢ҇.
е2ⷣ
8еⷣ.
8еⷣ҇.
8еⷤ.
8еⷤ҇.
8еⷥ.
8еⷥ҇.
е2ⷦ
8еⷦ.
8еⷦ҇.
8еⷧ.
8еⷧ҇.
2е2ⷨ
8еⷨ.
8еⷨ҇.
8еⷩ.
8еⷩ҇.
8еⷪ.
8еⷪ҇.
е2ⷫ
8еⷫ.
8еⷫ҇.
8еⷬ.
8еⷬ҇.
8еⷭ.
8еⷭ҇.
8еⷮ.
8еⷮ҇.
8еⷯ.
8еⷯ҇.
8еⷰ.
8еⷰ҇.
8еⷱ.
8еⷱ҇.
8еⷲ.
8еⷲ҇.
8еⷳ.
8еⷳ҇.
8еⷴ.
8еⷴ҇.
8еⷵ.
8еⷵ҇.
8еⷶ.
8еⷶ҇.
8еⷷ.
8еⷷ҇.
8еⷸ.
8еⷸ҇.
8еⷹ.
8еⷹ҇.
8еⷺ.
8еⷺ҇.
8еⷻ.
8еⷻ҇.
8еⷼ.
8еⷼ҇.
8еⷽ.
8еⷽ҇.
8еⷾ.
8еⷾ҇.
8еⷿ.
8еⷿ҇.
е1ꙋ1
еꙋвѧ1
еꙋга1
1еꙋго
8еꙴ.
8еꙴ҇.
8еꙵ.
8еꙵ҇.
8еꙶ.
8еꙶ҇.
8еꙷ.
8еꙷ҇.
8еꙸ.
8еꙸ҇.
8еꙹ.
8еꙹ҇.
8еꙺ.
8еꙺ҇.
8еꙻ.
8еꙻ҇.
8е꙼.
8е꙼҇.
8е꙽.
8е꙽҇.
1ж2а
жа́1ж
жа́1ш
жа́1щ
жа̑1
жа1м
жа2т
жа2х
2ж1б
2ж1г
ж2д
1жда
жда́1
жда1н
1жде
ждеѡ1
1жди
жди1в
2жд1н
1ждо1
2жд1с
2ждш
ждшї1
ждшї1
2ждъ
1жды
2ждь
1ждє
ждє́1
1ждѝ
1ждѣ
1ждѧ
1ждꙋ
ж2е
1же.
1же́й
1же́й
1же́с
же2з1
1жей
1жей
1же1л
1же2м
1жен
женї1
женї1
же2р1
1жес
1жет
1жеш
1жею
жже́1
1ж2жи
жжи́1
1ж2и
жи́7зни
жи́1н
жи́1с
жи̑1
жи1в
жив1л
жи8в7ле́н
жи1з2
жи1с2
жити1
жице1
жиша1
2ж1к
жка1
жко1
2ж1н2
жна1
жне1м
жно1
жнї1
жнї1
жнѧ1
1ж2р
жро2
жро́1
жрꙋ2
2ж1с2
жска1
жско1
2ж1ц
2ж1ш
жша1
жше1
2жъ
1жы
2ж2ь
1жє́м
жє́р1
1жє́1с
1жєн
1жєс
1ж2ї
жїѧ1
1ж2ї
жїѧ1
1жѧ
ж҃е́1
2жⷭ
ж2ꙋ
1жꙋ.
жꙋ́1
1жꙋ́с
1жꙋс
1жꙋт1
2з2̾1
з̾и1
з̾ѧ1в
1з2а
за́1м
за́1с
за́1ш
за́ѧ1
за̑д1
за̑1н
за1в
за1д
2заи
зак2
за1л
за1м
зан1т
запе1
запо1
за1р2
за1с
за1т2
захо1
заꙋ́1
2з1б2
збе1
зби́1
збла1
збле1
збо1л
зв2
з1ва.
1зва̀
1зва́
з1вам
1зван
2з1ве
зве1д
звер1
зве1с
2з1ви
зви1т
2з1вл
звла1
2з1во
зво1л
2звр
2звъ
2з1вы
звы́1
2з1вѝ
2звѣ
з1вѣ.
з1вѣ̑
з1вѣщ
2з1вꙋ
2з1г2
згн2
згнꙋ1
зго1
згре1
1зда̑
з1да1л
1здан1
2з1д2в
2з1де
2зди
2здн
з1дна
з1дне1
з1дно1
з1дны
з1днѣ
з1днꙋ
2здо
здо́1
2зд2р
2здъ
зды1х
2здь
2з1дї1
2з1дї1
2здѝ
1здѣ.
здѣ1л
2здꙋ2
з1дꙋ́
з2е
1зе.
1зѐ
1зе́й
1зе́й
1зе́н
зе́р1
1зе́ю
зе1в
1зек
1зем
1зен
1зер
1зе1с
1зе2т1
1зеш
2з1ж2
зже1н
зжи1
2з1з2
зза1
ззо1
з2и
1зѝ
1зи́
зи́1д
зи́1ж
зи́1с
1зид
2зи1м
зи1н2
зи1р
1зи1т
з1к
зко1
з1ла̀
зла́1
зла̑1
з1лаг
1злат
1злащ
2з1ле
зле1т
з1ли
зли1в
2з1ло
2злс
2злъ
2з1лю
2з1лї1
2з1лї1
2з1лѡ
з1лѣ
з1лꙋ1
2з1м2
зма́1
зми́1
змо1в
1зна̀
1зна́
1знав
з1не́
з1нев
з1нег
1знет
1знех
з1ни́1
з1ни1к
з1нис1
зно1в
1знод
з1но1м
з1нос
2знс
2знъ
2з1ны
зны1м
2знь
1з2нї1
1з2нї1
2знѡ
з1нѣ
1знꙋ́
з1нꙋт
1з2о
зо1в
зои1
зо2м
зос2
зото1
зо2ч1
2з1п2
зпа1
зпи2
зпо́1
зпро1
зр2
2зра
з1рас
з1ращ
1зре́1
з1реч
з1рещ
1зри.
1з2рѝ
1зрим
з1рин
1зрит
1зриш
1з2рю
1з2рѝ
1зрѣ̀
з1рѣш
зрѧ2
1зрѧ̀
1зрѧт
з1рꙋ
2з1с2
зсе1
зска1
зско1
зсло1
зсмо1
зсто1
зсы1
зсї1
зсї1
зсѣ́1
зсꙋ́1
зсꙋ1д
з1х
зхо1
з1ц
зцѣ1
з1ч
зче́1
зчи́1
2з1ш2
зши1
зшꙋ1
2з2ъ
з2ы
1зы.
1зы̀
1зы́б1
зы́1д
1зы́й
1зы́й
1зы́к
зы́1т
1зы́ц
1зы́ч
1зы̑
2зыг
1зыди
1зы1к
зыко1
1зыл
2зы1с
2зыщ
2зь
1з2ю
1з2ѐ
1з2є
зє́2
зєм1
1з2і
зї1
1з2ї1
1з2ѝ
1з2ѡ
зѡ́1
зѡ1р
зѡ1с2
з2ѣ
1зѣ̀
зѣ̑1
1зѣм
1зѣх
з2ѧ
2зѧ̀
1зѧ́б
1зѧ́м
зѧ́1с
1зѧ́щ
1зѧб
1зꙋ.
1зꙋ́е
з1ꙋ́м
1зꙋ́ѧ
з1ꙋ̑
зꙋ̑м1
з2ꙋ1б
1зꙋе
1зꙋме
1зꙋми
1зꙋмл
з1ꙋмы
1зꙋмѝ
1з2ꙋт1
1зꙋю2
8и.
8ѝ8.
ѝ1д
ѝдѣ1
и2́
8и́8.
и́1бл
и́бо1
2и́в
и́ва1
и́во1
и́вї1
и́вї1
и́г1н
2и́ж
и́1зв
и́зо1
и́1зр
и́1зꙋ
и́ка1
и́к1н
и́ли1
и́лї1
и́лї1
и́ма1
1и́мш
и́на1
и́ни1
и́н1м
и́нї1
и́нї1
и́рї1
и́рї1
и́с2
и́си1
и́1ск
и́1сн
и́сѧ1
и́та1
и́1тр
и́1тч
и́тї1
и́тї1
и́1ф
2и́ц
2и́ч
и́че1
и́1ш
и́ша1
и́щꙋ1
2й
8й.
8й̀8.
8й́8.
8й̈8.
8й̑8.
й1д2
йде2
йдꙋ2
й1ж2
й1м2
й1н2
йне1
йно1
йню1
йнї1
йнї1
йнѧ1
йнꙋ1
й1с2
йска1
йско1
йскꙋ1
йст2
й1т
йте1
й1ц
й1ч
йче1
й1ш2
йша1
йшꙋ1
8й҆̀8.
8й҆́8.
8й҆̈8.
8й҆̑8.
8йⷠ.
8йⷠ҇.
8йⷡ.
8йⷡ҇.
8йⷢ.
8йⷢ҇.
8йⷣ.
8йⷣ҇.
8йⷤ.
8йⷤ҇.
8йⷥ.
8йⷥ҇.
8йⷦ.
8йⷦ҇.
8йⷧ.
8йⷧ҇.
8йⷨ.
8йⷨ҇.
8йⷩ.
8йⷩ҇.
8йⷪ.
8йⷪ҇.
8йⷫ.
8йⷫ҇.
8йⷬ.
8йⷬ҇.
8йⷭ.
8йⷭ҇.
8йⷮ.
8йⷮ҇.
8йⷯ.
8йⷯ҇.
8йⷰ.
8йⷰ҇.
8йⷱ.
8йⷱ҇.
8йⷲ.
8йⷲ҇.
8йⷳ.
8йⷳ҇.
8йⷴ.
8йⷴ҇.
8йⷵ.
8йⷵ҇.
8йⷶ.
8йⷶ҇.
8йⷷ.
8йⷷ҇.
8йⷸ.
8йⷸ҇.
8йⷹ.
8йⷹ҇.
8йⷺ.
8йⷺ҇.
8йⷻ.
8йⷻ҇.
8йⷼ.
8йⷼ҇.
8йⷽ.
8йⷽ҇.
8йⷾ.
8йⷾ҇.
8йⷿ.
8йⷿ҇.
8йꙴ.
8йꙴ҇.
8йꙵ.
8йꙵ҇.
8йꙶ.
8йꙶ҇.
8йꙷ.
8йꙷ҇.
8йꙸ.
8йꙸ҇.
8йꙹ.
8йꙹ҇.
8йꙺ.
8йꙺ҇.
8йꙻ.
8йꙻ҇.
8й꙼.
8й꙼҇.
8й꙽.
8й꙽҇.
и2̑
8и̑8.
2и̑1г
и̑1д
и̑2ж1
1и̑мш
и̑1р2
и̑1с2
и̑1т2
и1б2
иба́1
ибо2
ибо́1
2и1ва
ива́1
и1ве
иве1д
иве1с
и1ви
ив1лю
ив1лѧ
и2в1н
и1во
иво1м
иво1н
иво1с
ив1с
ившы1
и1вы
ивї1
и1вї1
и1вѝ
и1вѡ
и1вѣ1
и1вѧ2
и1вꙋ
2и1г2
ига́1
иги́1
игла1
иго1р
и1д2
2ида
ида́1
1иди
иди́1
идо2
идї1
идї1
1идѝ
идѣ́1
1идꙋ2
идꙋ́1
и1ж2
ижє́1
иза2
иза̑1
1изб
и1зва
1изг
и1зи1
из1л
изла1
изло1
1изм
из1не
1из1ни
и1зно1
изо1
1из1ре1
из1ри
и1зрѣ
1изс
и1зы
1изы́1
и1зѣ
2ик
и1ка
ика́1
и1ки
и1кл
икло1
и2к1н
и1ко
и1кр
и1кт
и1кі
и1кѝ
и1кѡ
и1кѣ
и1кꙋ2
и1ла
ила́1
ила1с
и1ле
1илев
1илем
и1ли
или́1
или̑1
и1ло
ило1с
1иль.
1ильт
1и1лю
1и1лє1
и1лї1
и1лї1
и1лѡ
и1лѣ
и1лѧ
1илѧ.
илѧ́1
и1лꙋ
илꙋ́1
и1ма
и1ме1
1имен
и1ми
1имѝ
ими́1
и1мо
1имод
и2м1т
и1мы
1и1мѝ
и1мѣ
имѣ́1
1имꙋ̀
1имꙋ́
и1на2
и1не
1ине.
и1ни2
1ини.
инин1
иннї1
иннї1
и1но
ино1в
ино1м
1инст
и1ны
и1ні
ині́1
и1нѝ
1инѡв
и1нѣ
и1нѧ
инѧ́1
и1нꙋ2
и1п
ипа́1
ипа1д
ипї1
ипїо1
ипї1
ипїо1
ипѣ1в
2ир
и1ра
ира́1
ир1г
и1ре2
ирен1
и1ри2
и1ро
иро1н
и1рє
и1рі
ирї1
и1рї1
и1рѝ
и1рѣ
и1рѧ
ирѧ́1
и1са
иса̑1
исво1
исвѧ1
1и1се2
и1с2к
1искꙋ1
и2с1л
и1с2н
и1со2
ис7полн
1испѡ
и1спѣ
ис1с
исса1
и1с2т
исте1
и2с1х
ис7хо́д
ис7хожд
1и2с1ц
ис7цѣ́ль
ис7цѣ̑ль
1исч
ис7черп
исі́1
исї1
исї1
и1та
и1тв
и1те
ите1ц
и1ти
и1то2
и1тр
итро1
итрї1
итрї1
2итс
и1ты
и1тѐ
и1тє
и1ті
итї1
и1тї1
и1тѝ
и1тꙋ1
иф2
ифа2
ифле1
и1ха
1иха.
и1хо
ихо́1
их1т
1ихѣ
ихꙋ2
и1ц2
ица2
ица́1
ице1м
2ицъ
ицє1
ицѣ2
и1ч
иче́1
иче1с
ич1н
1ичнѡ
ичє́1
и1ш
ише2
2иши
иши1н
иш2л
ишꙋ2
и1щ2
2ища2
ище1т
и1ю
ию́1
и1ѡ1
и1ѳ2
иѳа́1
2и҃2
8и҆̀8.
8и҆́8.
и҆́1б
и҆́1г
и҆́1д
и҆́1ж
и҆́з1
и҆́1р
и҆́1с
8и҆̈8.
8и҆̑8.
и҆г2
и҆з1д
и҆з1р
и҆1л
и҆лї1
и҆лї1
и҆1м
и҆1н2
и҆с1п
8иⷠ.
8иⷠ҇.
8иⷡ.
8иⷡ҇.
8иⷢ.
8иⷢ҇.
8иⷣ.
8иⷣ҇.
и2ⷤ
8иⷤ.
8иⷤ҇.
8иⷥ.
8иⷥ҇.
8иⷦ.
8иⷦ҇.
8иⷧ.
8иⷧ҇.
и2ⷨ
8иⷨ.
8иⷨ҇.
8иⷩ.
8иⷩ҇.
8иⷪ.
8иⷪ҇.
8иⷫ.
8иⷫ҇.
8иⷬ.
8иⷬ҇.
8иⷭ.
8иⷭ҇.
8иⷮ.
8иⷮ҇.
и2ⷯ
8иⷯ.
8иⷯ҇.
8иⷰ.
8иⷰ҇.
8иⷱ.
8иⷱ҇.
8иⷲ.
8иⷲ҇.
8иⷳ.
8иⷳ҇.
8иⷴ.
8иⷴ҇.
8иⷵ.
8иⷵ҇.
8иⷶ.
8иⷶ҇.
8иⷷ.
8иⷷ҇.
8иⷸ.
8иⷸ҇.
8иⷹ.
8иⷹ҇.
8иⷺ.
8иⷺ҇.
8иⷻ.
8иⷻ҇.
8иⷼ.
8иⷼ҇.
8иⷽ.
8иⷽ҇.
8иⷾ.
8иⷾ҇.
8иⷿ.
8иⷿ҇.
1и1ꙋ
иꙋ́2
8иꙴ.
8иꙴ҇.
8иꙵ.
8иꙵ҇.
8иꙶ.
8иꙶ҇.
8иꙷ.
8иꙷ҇.
8иꙸ.
8иꙸ҇.
8иꙹ.
8иꙹ҇.
8иꙺ.
8иꙺ҇.
8иꙻ.
8иꙻ҇.
8и꙼.
8и꙼҇.
8и꙽.
8и꙽҇.
2й
8й.
8й̀8.
8й́8.
8й̈8.
8й̑8.
й1д2
йде2
йдꙋ2
й1ж2
й1м2
й1н2
йне1
йно1
йню1
йнї1
йнї1
йнѧ1
йнꙋ1
й1с2
йска1
йско1
йскꙋ1
йст2
й1т
йте1
й1ц
й1ч
йче1
й1ш2
йша1
йшꙋ1
8й҆̀8.
8й҆́8.
8й҆̈8.
8й҆̑8.
8йⷠ.
8йⷠ҇.
8йⷡ.
8йⷡ҇.
8йⷢ.
8йⷢ҇.
8йⷣ.
8йⷣ҇.
8йⷤ.
8йⷤ҇.
8йⷥ.
8йⷥ҇.
8йⷦ.
8йⷦ҇.
8йⷧ.
8йⷧ҇.
8йⷨ.
8йⷨ҇.
8йⷩ.
8йⷩ҇.
8йⷪ.
8йⷪ҇.
8йⷫ.
8йⷫ҇.
8йⷬ.
8йⷬ҇.
8йⷭ.
8йⷭ҇.
8йⷮ.
8йⷮ҇.
8йⷯ.
8йⷯ҇.
8йⷰ.
8йⷰ҇.
8йⷱ.
8йⷱ҇.
8йⷲ.
8йⷲ҇.
8йⷳ.
8йⷳ҇.
8йⷴ.
8йⷴ҇.
8йⷵ.
8йⷵ҇.
8йⷶ.
8йⷶ҇.
8йⷷ.
8йⷷ҇.
8йⷸ.
8йⷸ҇.
8йⷹ.
8йⷹ҇.
8йⷺ.
8йⷺ҇.
8йⷻ.
8йⷻ҇.
8йⷼ.
8йⷼ҇.
8йⷽ.
8йⷽ҇.
8йⷾ.
8йⷾ҇.
8йⷿ.
8йⷿ҇.
8йꙴ.
8йꙴ҇.
8йꙵ.
8йꙵ҇.
8йꙶ.
8йꙶ҇.
8йꙷ.
8йꙷ҇.
8йꙸ.
8йꙸ҇.
8йꙹ.
8йꙹ҇.
8йꙺ.
8йꙺ҇.
8йꙻ.
8йꙻ҇.
8й꙼.
8й꙼҇.
8й꙽.
8й꙽҇.
к2а
1ка́в
ка́1г
1ка́е
ка́1ж
1ка́з
1ка́й
1ка́й
1ка́1к
1ка́1м
1ка́п
1ка́р
ка́1ш
1ка́ю1
1ка́ѳ
1ка̑в
1ка̑1з
1ка̑н1
1ка1в
1каго
1ка1д
1каж
ка1з2
1как
1кал
кали1
1кам
1кан
1кар
1ка1с2
1ка1т
ката1
1ках
1каш
1каѧ́
к2в
ква2
квер1
кво1
1квї2
1квї2
1к2д
кді́1
1ке́и
1ке́к
ке́л1
1ке́м1
1ке́1р
1ке́с
ке́1ѵ
1кеа
1ке1д2
ке2л
2кен1
кер1
ке1с
кеса1
1кеѱ
1ки́1р
1ки́т
1ки́ф
1киб
кибы1
ки1н
ки2р1
ки1т2
2к1к2
кка1
ккли1
к2л
1кла
кла1н
1кле
кле1в
1кли́
1клик1
1клис
1клиц
1кло
2клс
2клъ
2кль
1клю1
клї1п
1клїй
1клїй
клї1п
1клѡ
1клѧ2
клѧ́т7ва
клѧ́т7вен
клѧ́т7во
клѧ́т7вы
клѧ́т7вѣ
клѧ́т7вꙋ
1к2м
кн2
2к1не2
кни1т
2кно1
2кнъ
к2нѧ
к2о
1ко̀
ко́1ж
1ко́з
1ко́и
1ко́л
1ко́н
1ко́1п
1ко́с
1ко́х
1ко́ш
1ко́ѧ
1ков
кова́р7ство.
ков1н
ков1с
1ког
1код
1кое́1
1коег
1коей
1коей
1коем
1кож2
ко2з1
1кои1
1кой
1ко1л
колос7са́
колє1
1комч
1кона
1коне
1коно
1конъ
1коны
1конє
1коні
1конꙋ
1копи1
1копѣ
1коре1
1кори
1корм
корѡ1
1корꙋ1
1косн
кос7не́т
кос7ни́т
кос7нов
кос7нꙋ́
1ко1ст
1косы
1косѣ
1коть
1коц
1коѝ
1коѧ
1коѻ
1коꙋ1
к2п
к2р2
1кра
крае1
крен1
1кро
кро1в
кро1м
кро1н
1крыв
1кры1м
1крі
1крѡ
1крѣ
2кр҃
2крⷭ
1крꙋ
2к1с2
к2т
1кта
кта́1
1кте
кте1н
1кто
кто́1
кто1м
2ктъ
1ктю
1ктє1
1кті
ктї1
1ктї1
1ктѡ
ктѡ́1
1кхе2
2кхъ
2к1ш2
кша1
кше1
2къ
кы1
кє́2
кє́л1
1кі́а
1кі́и
1кі́м
1кі́н
1кі́с1
1кі́1т
1кїа
1кїе
1кїи2
1кї2л1
1кї2н1
1кі̑й
1кі̑й
1кїа
1кїе
1кї2л1
1кї2н1
к2ѡ
1кѡ.
кѡ́з1
1кѡ́н
кѡ́р1
кѡ́1с
1кѡ́т
1кѡ̑1
1кѡва
1кѡве
1кѡвл
1кѡво
1кѡвꙋ
кѡ1л
1кѡн
кѡ1р
1кѵ
кѵ́1л
к2ѷ
кѷ2м1
1к2ѷ
кѷ2м1
2кⷮ
к2ꙋ
1кꙋ̀
1кꙋ́е
1кꙋ́и
1кꙋ́й
1кꙋ́л
1кꙋ́м
1кꙋ́н
1кꙋ́1р
1кꙋ́т
кꙋ́1ф
1кꙋ́1щ
2кꙋ1д
1кꙋ2з1
1кꙋп
кꙋсо1
1кꙋст
1кꙋ1т
1кꙋша
л2а
1ла́.
1ла́а
1ла́е
1ла́й
1ла́й
1ла́р
ла́1ш
1ла́ю
1ла́ѣ
1ла́ѧ
ла́ѵ1
ла̑в1
ла̑д1
ла̑1с
1лаа
лав1л
1лавш
1лавъ
2лад
ладо1
1лае
2лаж
1лай
1лай
лак2
1лакт
1лал
лам2
1лама
1лами
1ламъ
1ланн
лан1т
1ланї
1ланї
1лар
лас2
1ласѧ
ла1т2
1лате
1лати1
лато1
1лах
2лач
2лащ
лаща1
1лаю1
1лаѧй
1лаѧй
ла2ѵ1
2лв
л1ва
л1ве
л2в1н
лв1с
л1вы
лвї1
л1вї1
л1вѣ
л1вꙋ
2лг
л1га
л1ги
л1го1
2лд
л1де
л1дє
лдє́1
л2е
2лѐ
1ле́а
1ле́б1
1ле́е
1ле́ж1
1ле́и
ле́1п
1ле́1р
1ле́с
ле́т1
1ле́х
1ле́1ч
ле́1щ
1леа1
1леб
лев2
леве1
1легл
2лее2
1лежѐ
1лежи
1лежѐ
1лезв
лезо1
1леи
1лема1
1лемо1
1лемѡ
1лемꙋ1
1лен1т
2лео
1ле1р2
лерї1
лерї1
1леса
1лесѐ
1лесѝ
1лесн
1лесы
1лесѐ
1лесє
1лесѝ
1лесѣ
1лете
1летс
1летѣ
1летѧ
ле2х
1леце
1лецъ
ле1ч
1лею
1леѡ2
1леѯ
1леѵ
2лж
л2жа
л1же2
л2жи
л2жѝ
л2жꙋ
2л2з1
лзно1
лзше1
л2и
1ли́1б
1ли́в
1ли́л
1ли́н
ли́1р
1ли́с
1ли́х
1ли́ц
1ли́ч
1ли́ш
1ли́1щ
1ли̑1к
1ли̑1м
1ли̑т
1ли̑ч
1ли̑щ
1либ
1лив
1лид
2лиж
2ли2з1
ли1к
1лико
1лил
лимо1
1лимс
1лимт
1линг
1лини
1лины
1линѡ
2лип
2ли1с2
1лит
1ли2х
1лице
1лич
1лиши
1лищ
2лк
л1ка2
л1ки
л1ко1
л1кі
л1кѝ
л1кѡ
2л1л2
лле́1
лли1
ллї1н
ллї1н
ллѵ́1
2лм
л1ма
лма1т
л1ми
л1мы
л1мї1
л1мї1
л1мѣ
2лн
л1на2
лна́1
л1не
лнеч1
л1ни
лни1с
л1но
лно́1
лн1ц
л1ны
лнє́1
лнї1
лнїи1
лнїѧ1
лнї1
лнїи1
лнїѧ1
л1нѧ2
лнѧ́1
лнѧт1
л1нꙋ2
лнꙋ́1
л2о
1ло́.
1ло́г
1ло́ж
1ло́м
лоб2
1лобы
1лова
лов1л
1ловс
1ловъ
1ловы
1лові
1ловѣ
1ловꙋ
1лог
логи1
1лодъ
1ложа
1ложи
1ложꙋ
ло1з2
1ло1л
лом2
1ломе
1ломѡ
ло1н
ло1р
1лоро
1лорꙋ
1лос2
ло1щ
1лоѳ
2лп
л1па2
л1пе
л1пѝ
л2п1н
лпни1
л1по2
л1пі
лпї1
лпї1
л1пѝ
л1пѡ
л1пѣ
л1пꙋ2
2л1с2
2л1т
2л1ф
лфа1
лфе2
2лх2
лхї1
лхї1
2л1ц
лцѣ2
2лч
лче2
лче́1
лчи1т
лч1н
лчє́1
лчї1
лчї1
л1чꙋ1
2л1ш
лшꙋ1
2л2ъ
л2ы
лы́в1
лы́1ш
1лы̑.
1лых
2л2ь1
л2ю
1лю́.
1лю́б
1лю́с
1люб
2люд
1лютс
2люч
1люща
1люще1
1лющи
1лющы
1лющї
1лющї
1лющꙋ
2лѐ
л2є
1лє́з
1лє́с1
лє1в
1лєм
1лєны
1лєс
1лєц
лі́1в
лі́1д
1лі́м
1лі́н
1лі́п
1лі́1т
л2ї
1лїа̀
1лїан
1лїѐ
1лїев
1лїѝ
1лїи́
1лїим
1лїин
1лї1к
лїко1
1лї1л
1лї1м
1лїн
1лїо
лїо́1
1лїпп
1лїс
лїса1
1лїт
1лїч
1лїю̀
1лїѐ
1лїѝ
1лїѡ
1лїѧ.
1лїѧ̑
2лі̑
л2ї
1лїа̀
1лїан
1лїѐ
1лїев
1лїѝ
1лїи́
1лїим
1лїин
1лї1к
лїко1
1лї1л
1лї1м
1лїн
1лїо
лїо́1
1лїпп
1лїс
лїса1
1лїт
1лїч
1лїю̀
1лїѐ
1лїѝ
1лїѡ
1лїѧ.
1лїѧ̑
л2ѡ
1лѡ̀
1лѡ́в
1лѡ́г
лѡ́ж1
1лѡ́с
1лѡ1с2
1лѡть
1лѡтї
1лѡтї
л2ѣ
1лѣ́ж1
1лѣ́з
1лѣ́л
лѣ́1с
1лѣ́т
1лѣ́х
1лѣ́1ш
1лѣ̑.
лѣ̑д1
1лѣ̑з
2лѣб
1лѣ1в
2лѣ1д
1лѣе
1лѣжа
1лѣже
1лѣй
1лѣй
1лѣм
2лѣ1н
1лѣпи
лѣ2х
л2ѧ
лѧ́1д
1лѧ́1с
1лѧ́щ
2лѧ̑
2лѧг
1лѧй
1лѧй
2лѧ1м
1лѧ1н
лѧ2т
1лѧтс
1лѧх
1лѧ1ц
2лѧ1ч
1лѧщ
лѧще1
1л2ѵ
лѵ́м1
лѵ́1п
лѵ́1р
лѷ1к
лѷ2м1
л2ѷ
1лѷе
лѷ1к
1лѷка
1лѷ2м1
1л2ѻ
лѻр1
2л҃2
л҃ко1
л҃о1
2лⷣ2
л2ꙋ
1лꙋ́1в
1лꙋ́е
1лꙋ́й
1лꙋ́й
1лꙋ́1н
1лꙋ́ф
1лꙋ́ч1
лꙋ́1ш
1лꙋ́ю
1лꙋ́ї
1лꙋ́ї
1лꙋ̑.
лꙋ̑ж1
1лꙋ̑ч
1лꙋа
лꙋ1б
1лꙋе
1лꙋй
1лꙋй
1лꙋк
1лꙋм
1лꙋч
1лꙋѧ
1лꙋⷩ
м2а
1ма.
1ма́.
ма́1г
1ма́1ж
1ма́1з
1ма́й
1ма́й
ма́1м
1ма́н
1ма́р
1ма́с
ма́1т
1ма́х
1ма́1ш
1ма́ю
1ма́ѧ
1ма̑1
1маг2
мага1
1ма1л
мала1
1мамъ
1мамы
1ман
мано1
1марі
1марѧ1
1ма1с
1мат2
мате1
2ма2х
1маш
1маі
1маѧ
ма1ѯ
маѵ1
2мв2
м1ва
мва́1
м2г2
м2е
1ме.
1ме́а
1ме́в
1ме́е
1ме́з1
1ме́й
1ме́й
1ме́1л
ме́м1
1ме́н
1ме́т
1ме́ц1
1ме1в
1ме1д2
меж2
1мел
1ме2м
1мен
мено1
мер1т
1мерш
1мерщ
1меръ
1мерї1
1мерї1
ме2с
1мет
меч1т
1меш
1меѡ2
2м1ж2
м2з2
м2и
1ми.
1ми́.
1ми́в
ми́1ж
1ми́л
ми́1м
1ми́н
1ми́1с
1ми́1т
1ми́х
ми́1ц
1ми́ш
ми̑1
1миж
1ми1л
мило1
ми1м
мимо1
1мин
ми1р
1мира
1мирѝ
миро1
1мирѝ
1ми1с2
1ми1т2
1мищ
мл2
1мла
мла́1
мла1д
м1ле.
1млѐ
мле́1
м1лем
м1лет
м1леш
м1ли.
1м2лѝ
1мли́1
2мль
1млю̀
м1лют
1млѐ
1м2лє
млє́1
1м2лѝ
м1лѧ.
1млѧ̀
1млⷭ
2м1м
мма1
ммѡ́1
2м1на
мна́1
2м1не1
м2нѐ
м1ник
1мни1т
мно́1
1множ
м1но1м
2мнъ
2м1ны
м2ню2
м2нѐ
2м1ні
мні́1
мнї1
2мнї1
2мнѡ
мнѡ́1
м1нѣ.
м2нѧ
2м1нꙋ
мнꙋ́1
1мо.
1мо́г
1мо́ж
1мо́1к
1мо́л
1мо́м
мо́1р
1мо́с
1мо́щ
1моб
1мов2
мо1вл
1мога
1моге
1мого
1могꙋ
1мод
1мое
мое1м
1мож
1мо1з2
1мои
2мок
1мола
1моли
моли́7тва
моли́7твен
моли́7тво
моли́7твы
моли́7твѣ
моли́7твꙋ
1молч
1молю
1молѝ
1мом
1мон
1моп
мопо1
1море1
1мос2
мо1ск
мот2
1моты
1мотꙋ
1моф
1мощ
1моѳ
мп2
2м1па2
1м2пе
мпе1р
2м1по1
2мпї
2мпї
1м2р2
мре́1
мро2
мро́1
мрє́1
мрꙋ2
2м1с2
мска1
мско1
2м1ти1
2мтъ
1мт҃
2м1ф2
мфа1
мфе1
мфї1
мфї1
2мча
2мчї
2мчї
1мч҃
м2чⷭ
2м1ш2
мша1
мше1
мшї1
мшї1
мшꙋ1
1м2щ
мще́1
мщꙋ2
2м2ъ
м2ы
1мы́н1
мы́ш1
1мы̑
1мыв
1мый
1мый
1мым
1мыс
1мых
1мыш1
1мыѧ
2м2ь1
мє́2
1мє́н1
1мєн
1мі́а
1мі́и
1мі́1н
1мі́р
1мі́ю
мі́є1
м2ї
1мїа
1мїе
1мїи.
1мїѝ
мїи́1
1мїй
1мїй
1мї1л
мїлї1
мїлї1
1мї1н
1мїр
1мї1с
мїса1
мїха1
2мїю
1мїѝ
1мїѡ1
1мїѧ
1мі̑
м2ї
1мїа
1мїе
1мїи.
1мїѝ
мїи́1
1мїй
1мїй
1мї1л
мїлї1
мїлї1
1мї1н
1мїр
1мї1с
мїса1
мїха1
2мїю
1мїѝ
1мїѡ1
1мїѧ
1м2ѡ
мѡ́ж1
мѡ́л1
мѡ̑1
мѡи1
мѡ1л
мѡ2р1
1мѣ́
мѣ́1т
мѣ́1ш
1мѣ̑
мѣ̑д1
мѣ̑1н
мѣ̑р1
1мѣ1в
1мѣи
1мѣй
1мѣм
мѣ1н
1мѣне
1мѣнѝ
1мѣнѝ
2мѣ1с
1мѣх
2мѣш
2мѣщ
2мѣѧ
мѣѧ́1
м2ѧ
1мѧ.
1мѧ́
1мѧ1н
1мѧр
1мѧти
1мѧтн
1мѧтс
1мѧть
1мѧтї
1мѧтї
2м1ѱ2
1мѵ́л
мѷ1
мѷг2
мѷ1
мѷг2
2м҃
1мⷣ
2мⷬ
1м2ꙋ
мꙋ́и1
мꙋ́1ч
мꙋ́1ѳ
мꙋ̑1
мꙋ1д2
мꙋси1
2мꙋщ
н2а
1на.
1на́д
на́1з
1на́и
1на́к
1на́р
на́ч1
на́1ш
1на́ѳ
1на̑1
1наа
наа́1
2наб
на1в
1нави
навꙋ1
1наг
1над
нае1
1наж
на1з2
нази1
наи́1
1нак
на1л
налѧ1
1нам
1на1н
напе1
на1р2
нари1
на1с
наса1
1насс
1наст
1насѧ
1на1т
нахо1
1нач
начи1
1наі
1наѧ
1на1ѯ
1наѳ
на1ѵ2
1наꙋ
2нб
2н1г2
2нд2
н1да
н1де
нди2
нди́1
н1дра
н1дре
ндро1
н1ды1
н1ді
ндї1
н1дї1
н1дѣ
н1дꙋ2
ндꙋ́1
н2е
1не.
1не́.
1не́а
не́1б
не́1г
1не́1ж
1не́и
1не́1л
1не́н
не́1р
1не́ц
1не́ч1
1не̑
2неа1
1неб
небы1
не1в
1нева
неве1
нев1н
1невѣ
нег2
1него
1негъ
не1д2
1неди
1неді
1недѣ
1не2ж1
2не1з2
не7зра́ч
1неи
не1л
нели1
1немо
1немп
1немс
1немꙋ
1нена1
нене1
1нени
1нено
1ненꙋ
нео1
1непо
2не1р2
нерꙋ1
1нес
не8с7ла̀.
не8с7ло̀.
не8с7тѝ.
не8с7тѝ.
несѣ1
нетѣ1
не2х
не2ц
1неш
2неє
1неѡ́
1неѡп
1не1ѵ
2н1з
н2и
1ни́.
ни́1д
ни́ж1
ни́1з
1ни́м
1ни́н
1ни́р
1ни́1с
1ни́х
1ни́ч
1ни́ш
1ни̑в1
1нив
ниво1
2нид
2ни2з1
ник2
1нико
1никѣ
1нил
1нин
1ни1р
1нис1п
1нисі
1нисѧ
1нити1
1нитс
1нитъ
1ниха
1нихо
1нихс
1нихꙋ
нице1
1ницꙋ
1нич
1ниш
ниша1
1нищ
нище1
1ниⷯ
2нк
н2ка
н2кѝ
н1ко2
н2кѝ
н2кѡ
н2кꙋ
2нм2
н1ма
н1ме
н1ми
н1мѝ
н1мѣ
2н1н2
нна1
нна́1
нне1
нни́1
нни1н
нно1
нню1
ннѧ1
ннꙋ1
ннꙋю1
н2о
1но.
1но́в
1но́1д
но́1з
но́1к
1но́с
1но́1ф
1но́щ
1но́ї
1но́ї
1ноа
2ноб
1нови
1новл
нов7ле́н
1ново1
1новъ
1новы
1нові
1новѝ
1новѡ
1новѧ
1новꙋ
1ногд
1ногр
1ноде
1нодꙋ
1ное2
нож2
1ножд
ножи1
1ной
1ной
1нок
но1л
1нолѣ
1нома
1номе
1номо
1номъ
1номы
1номꙋ
1но1н
нона1
ноп2
1нопи
1нопл
1нопо1
1нопр
1но1р
но1с2
1носи
1носѧ
нот2
1нота
1нотв
ноте1
1ноф
1ноч
ноче1
1нош
1нощ
ноще1
1ною
1ноєѵ
1ноѧ
ноѧв1
2нр
н1рѐ
н1рѐ
2н1с2
нска1
нско1
нскꙋ1
нст2
нсї1
нсї1
2нт
н1та
нта́1
н1те1
н1ти
н1то2
н1ті
н1тї
н1тѡ
нтѡ́1
нтѡ1н
н1тѣ
2нц2
н1ца̀
н1це́
н1цем
н1цы̀
н1цє
н1цѣ2
н1цꙋ̀
н1цꙋ́
2нч
нче2
нчи́1
нч1н
2н1ш2
нша1
нше1
ншꙋ1
2н2ъ
н2ы
1ны̀
1ны́1н
1ны̑.
1ны̑м
1ный
1ный
1ныма
1ных
1ныѧ
2н2ь1
н2ю
1ню́
1нюе
1нюю
1нюѧ
1н2є
нє́ч1
н2і
1ні́г
1ні́и
1ні́к
1ні́л
1ні́н
1ні́с
1ні́ч
1нї
нї2г1
нїе1в
нї1к
нїка1
нї1м
нїма1
нї1н
нїне1
нїо1
нїѧ1м
1н2ї
нї2г1
нїе1в
нї1к
нїка1
нї1м
нїма1
нї1н
нїне1
нїо1
нїѧ1м
1н2ѡ
нѡ́1г
нѡ́1ж
н2ѣ
1нѣ́.
нѣ́1к
1нѣ́м
нѣ́1т
1нѣ́х
нѣ́ч1
нѣ́ш1
нѣ̑1
2нѣ1д
1нѣе
1нѣи
1нѣй
1нѣми
1нѣх
1нѣ2ш1
2нѣꙋ
н2ѧ
1нѧ́е
нѧ́1ж
1нѧ́й
1нѧ́й
нѧ́1х
1нѧ́ю
1нѧ́ѧ
1нѧго
1нѧгѡ
1нѧе
2нѧ1з
1нѧ1н
1нѧт
нѧти1
1нѧ2х
1нѧю
1нѧѧ
2нѳ
н1ѳи
нѳи́1
н1ѳі
нѳї2
нѳї2
1н2ѵ
нѷ1
нѷ1
2н҃2
2нⷣ
2нⷴ
н2ꙋ
1нꙋ.
1нꙋ́.
1нꙋ́1д
1нꙋ́е
1нꙋ́и
1нꙋ́1с
1нꙋ́1ф
1нꙋ́х
нꙋ́1ш
1нꙋ́ѧ1
1нꙋа
1нꙋв
1нꙋич
1нꙋ2л
1нꙋ1р
1нꙋти
1нꙋтъ
1нꙋ2х
1нꙋю.
1нꙋѧ
8о.
о2̀
8о̀8.
о2́
8о́8.
о́бо1
о́бѧ1
о́в1л
о́в1ц
о́га1
о́1гн
о́1др
о́з1н
о́з1р
о́к2
о́ка1
о́лч1
о́лє1
о́лѣ1
2о́м
о́ма1
о́мꙋ1
о́н1д
1о́пѣ
2о́р
о́ра1
о́р1д
о́р1ж
о́ри1
о́р1л
о́рм1
о́р1с
о́рꙋ1
2о́с
о́с1н
о́1сп
о́с1ц
о́тї1
о́тї1
2о́ц
о́ц1к
2о́1ш
о́ша1
о́щї1
о́щї1
о́ї2
о́ї2
о2̑
8о̑8.
о̑л1
о1а
оа1м
о1б
оба́1
оби1
об1лѧ
обо1с
об2р
о1ва
ова1с
2о1ве
ове1д
овер1
ове1с
о1ви
2овѝ
ови1в
ов1лю
ов1лє
ов1лѧ
о1вне1
ов1но
ов1нѣ
ов1нꙋ
о1во
ово1л
ово1с
1овою
овто1
о2в1ц
о1в2ч
о1вы
о1вє
ові́1
2о1вѝ
о1вѡ
о1вѣ
о1вѧ2
2о1вꙋ
о1г2
огло1
1огно
1огні
ого1
ого́1
огрѣ1
о1д
од̾и1
ода1в
од2в
одво1
2оде
о2д1л
2одн
од1на
од1но
од1ны
одо1с
одох1
одро1
одрꙋ1
од1с
оды́1
одї1
одї1
2одѣ
одѣ̑1
одѣ1в
одꙋ2
одꙋх1
2о1е
ое́1н
ое́1ш
ое1в
ое1д
оеди1
ое1с
2о1ж
оже1н
оже1с
о2ж1ж
о2з1в
озвѣ1
озд2
оз1до1
оз1ды1
оз1дѣ
оз1дꙋ
озже1
о1зи
ози́1
о2з1л2
озн2
о1зна
оз1не
оз1ни
оз1но
озор1
оз1ра
о1зри
о1зрѣ
о1зрѧ
озсо1
о1зы
о1зѣ
о1зѧ
2о1и
ои́1д
ои́1с
ой1
ои̑2
оиз1в
оиз1н
ои1м
ои2с1
ои1т
о2й1
о1к2
ока1р
окла1
око1в
око1р
окри1
окрꙋ1
1окт
2окъ
2ол
о1ла
ол1в
ол1г
о1ле
оле1с
оле1т
о1ли
оли̑1
оли1в
ол1к
оллї1
оллї1
ол1н
о1ло
оло1м
ол1п
ол1х
ол1ч
о1лы
о1лю
олю1б
о1лє
о1лі
олі́1
олїн1
о1лї
олїн1
о1лѝ
о1лѡ
о1лѣ
олѣ̑1
о1лѧ
олѧ́1
олѷ1
о1лѷ1
о1лꙋ
2о1ма
ома́1
о1ме
о1ми
оми1н
о1м2л
о1мнѣ
2о1мо
омо1л
омо1н
омо1щ
о1м2п
омра1
2омс
о1мт
о1мч
о1мы
омы́1
омы1с
о1мѣ
о1мѧ1
о1на
он1д
о1не
о1ни
он1к
он1м
о1но
он1р
2онт
он1ц
он1ч
о1ны
о1ню2
оню́1
о1нѐ
о1ні
онї1
онї1
о1нѝ
о1нѧ
онѧ́1
1онѵ
онѵ́1
о1нꙋ
о1о
оо́2
о1п
опа1д
опа1р
1опе́
опер1
2опи
опи1т
оп1лѧ
2опо
опро1
2опі
опї1
2опї1
2опѝ
2опѣ
2ор
о1ра
орас1
ор1в
ор1д
ордї1
ордї1
о1ре
оре1н
оре1х
ор1ж
о1ри2
ор1л
ор1м2
о1ро
ор1с
ор1т
орто1
о1рцы
о1ры
о1рю
о1рє
орє́1
о1рі
орї1
о1рї1
о1рѝ
о1рѡ
орѡ1н
о1рѣ
орѣ́1
орѣ̑1
о1рѧ
о1рѷ1
о1рѷ1
о1рꙋ
о1са
оса́1
о1се2
2о1си
оси̑1
ос1кл
ос2л
о1см
о2с1н
о1со
ос1пе1
о1спи1
ос1пл
ос1пꙋ
ос1с
2ос2т
о1сте
о1стл
о1сто
о1стѝ
о2с1х
о1с2ц
о1сы
осі́1
осї1
осї1
о1сѝ
о1сѣ
2осѧ
осꙋ1д
о1т
отер1
от1н
2ото
отов1
оть1
отѣ̑1
2отꙋ
о8у
о1ф
офа2
офа́1
1офѵ
1офѷ
о1х
охе2
ох1н
1охі
охі́1
охꙋ1
о1ц2
оцѣ1л
2о1ч
оче1н
оче1с
оче1т
очи1т
очно1
о1ш
оша2
оша́1
оше1н
о2ш1л
ошє́1
ошꙋ2
о1ща
ощни1
о1щє
ощї1
ощї1
о1щѝ
ощꙋ2
2о1ю
ою́1д
о1ѐ
о1є
оє́1
о1і
оі́2
ої1
о1ї1
о1ѝ
о1ѡ1
о1ѧ
оѧ́в1
оѧ́1ж
оѧв1л
оѧ1з
о1ѯ
о1ѱ
о1ѳ
оѳе2
о1ѹ
оѹ҆1
о1ѻ1
о҆1
8о҆̀8.
8о҆́8.
8о҆̈8.
8о҆̑8.
о1ᲂу
оᲂу҆1
8оⷠ.
8оⷠ҇.
8оⷡ.
8оⷡ҇.
8оⷢ.
8оⷢ҇.
о2ⷣ
8оⷣ.
8оⷣ҇.
8оⷤ.
8оⷤ҇.
о2ⷥ
8оⷥ.
8оⷥ҇.
о2ⷦ
8оⷦ.
8оⷦ҇.
8оⷧ.
8оⷧ҇.
8оⷨ.
8оⷨ҇.
8оⷩ.
8оⷩ҇.
8оⷪ.
8оⷪ҇.
8оⷫ.
8оⷫ҇.
о2ⷬ
8оⷬ.
8оⷬ҇.
8оⷭ.
8оⷭ҇.
8оⷮ.
8оⷮ҇.
8оⷯ.
8оⷯ҇.
8оⷰ.
8оⷰ҇.
8оⷱ.
8оⷱ҇.
8оⷲ.
8оⷲ҇.
8оⷳ.
8оⷳ҇.
8оⷴ.
8оⷴ҇.
8оⷵ.
8оⷵ҇.
8оⷶ.
8оⷶ҇.
8оⷷ.
8оⷷ҇.
8оⷸ.
8оⷸ҇.
8оⷹ.
8оⷹ҇.
8оⷺ.
8оⷺ҇.
8оⷻ.
8оⷻ҇.
8оⷼ.
8оⷼ҇.
8оⷽ.
8оⷽ҇.
8оⷾ.
8оⷾ҇.
8оⷿ.
8оⷿ҇.
о1ꙋ
оꙋ1б
оꙋ1в
оꙋме1
оꙋ1т
оꙋ1х
8оꙴ.
8оꙴ҇.
8оꙵ.
8оꙵ҇.
8оꙶ.
8оꙶ҇.
8оꙷ.
8оꙷ҇.
8оꙸ.
8оꙸ҇.
8оꙹ.
8оꙹ҇.
8оꙺ.
8оꙺ҇.
8оꙻ.
8оꙻ҇.
8о꙼.
8о꙼҇.
8о꙽.
8о꙽҇.
п2а
1па́1г
1па́е
па́1ж
па́1к
1па́л
1па́м
1па́р
1па́т
1па́1ч
1па́ю1
1па́ѵ
1па̑1
1па1в
па2г1
1пада
1падѐ
1падѝ
1падн
1падъ
1падѐ
1падѝ
1падѣ
1падꙋ
1пак
пако1
1па1л
па2м1
па2н1
1пар
пара1
пари1
пас1л
1пасї1
1пасї1
па1т2
1паф
па1х
1паѧ
паѧ́1
п2е
2пѐ
1пе́в
1пе́1з
1пе́л
1пе́м
пе́1п
1пе́р
пе́1с
1пе́щ
1пе1в
1пел
пела1
пелє1
1пен
1перв
1пере
1перн
1перѧ
пе1с
1пет
1пец
1пе1ч
2пе2ѵ1
п2и
1пи́
пи́1щ
1пи̑1
пи1н
1пино
1пины
1пинѣ
1пинꙋ
1пи1р
1пи1с
пит2
1питъ
1пиц
1пиш
1пищ
1пию
2п1к
пка1
пки2
пко1
пкꙋ1
пл2
1п2ла
пла1м
1пле.
1пле1в
1пле1м
1пле1н
1плет
1плещ
1п2ли
1п2ло
пло1м
2плъ
1п2лы
2пль
1плю.
п1лю̀
1плют
2п1лє
1п2лі
плї1
1п2лї1
1п2лѡ2
плѡт1
1п2лѣ
1плѧ.
п1лѧ́1
1плѧм
1п2лꙋ1
пн2
2п1на1
1п2не2
пнет1
2п1ни
п2нѝ
2п1но1
1пны́
п1ным
2пнї1
2пнї1
п2нѝ
2пнѡ
2п1нѣ
2п1нꙋ1
п2о
1по.
по́1ж
по́1з
1по́й
1по́й
1по́л
1по́м
1по́н
по́1п
1по́с
по́1т
по́1х
по́1ч
1побѣ
1по1в2
пове1
поде1
под1н
1поді
1подѡ
1пое2
пож2
поже1
1пожр
по1з2
1пои
1пок
1пол
пола1
полї1
полї1
1по1м2
поп2
попа1
попе1
попи1
попꙋ1
1пор
пора1
поре1
порꙋ1
1по1с2
посы1
1пот
пох2
1поч2
почꙋ1
по1щ
поща1
1пою
1поѝ
1поѧ
поꙋ1
2пп
п1па
п1пе
п1пи1
1п2р2
пра́з7дник
пра́з7дниц
пра̑1
пра1ѯ
пре1з
пре1м
пре1н
пре1т
пре1х
при1
при́1
про1в
про1з
про1м
про1н
2прь
2прє
прєн1
прї1
прїѡ1
прї1
прїѡ1
прѣ́1
прѧ́1
прꙋ2
прꙋ́1
2пс
п2сѝ
п1ст2
п2сѝ
п2т
1пта
пта́1
1пте
пти̑1
1пто2
2птр
1птѣ
1птѧ
1п2ф
пфі́1
2п1ц
пцы1
пцѣ2
2п1ч
2пш
п2ше1
1п2щ
пще1
2п2ъ
1п2ы
пы́2
2пѐ
1пє
пє́2
пє́н1
пє́р1
1пі́и
1пі́1н
1пі́с
1пі́1т
1п2ї
пї1к
пї1л
пї1м
пїо́1
пї1с2
1п2ї
пї1к
пї1л
пї1м
пїо́1
пї1с2
1пѡ́в
1пѡ́н
пѡ́1т
1пѡ̑2
пѡ̑н1
1пѡ1в
п2ѣ
1пѣ.
1пѣ́
пѣ́1т
пѣ́ѧ1
пѣ̑1
1пѣ1л
пѣ1с
2пѣш2
пѣше1
1пѣю
п2ѧ
1пѧ́л1
1пѧ́1с
1пѧ́ш
1пѧт
1пѵ
пѵ́1
пѷ1
пѷ1
п҃2
пⷣ2
2пⷬ
2пⷭ
п2ꙋ
1пꙋ̀
1пꙋ́
1пꙋс
пꙋ1т2
1пꙋщ
р2а
1ра́р
1ра́ї1
1ра́ї1
1ра́ѯ
ра̑1в
ра̑1ж
ра̑з1
ра̑1л
ра̑ш1
1раб
рав1л
1раві
ра1д
1раек
1разл
раз1н
1разр
1разс
ра1л
1рала
ра1м
рамо1
1рапо
1рапї
1рапї
1раск
ра8с7ка́ет
ра8с7ка́ѧн
1расл
ра8с7пад
ра8с7пал
ра8с7прост
ра8с7та́ѧ
ра8с7твор
ра8с7терз
ра8с7то́рг
ра8с7то́рж
расѡ1
ра1т2
рато1
1ратр
1раф
1рах
1раѡ
2рб
рбе2
р2б1л
рб1н
рбѣ2
рбѣ́1
рбѧ́1
2рв2
р1ва
рва́1
рве́1
р1вен
р1вл
рвле1
р1во
рво1з
р1вы
рвї1
р1вї1
р1вѣ1
р1вꙋ1
2рг
р1га
р1ги
р2гл
р2г1н
ргнꙋ1
р1го2
р1гі
ргі́1
2рд
р1да
рда1л
р1де
рди1с
рди1т
р2д1н
р1до
р1ды
рды́1
р1дє
р1ді
р1дѣ
рдѧ́1
р1дꙋ1
р2е
ре́7в8ност
ре́1ж
ре́1з
1ре́к
ре́1л
ре́1п
ре́1ч
1ре́ѳ
ре1в2
1рева
1ревн
ред1в
1реде1
ред1л
редо1
ред1р
рее1
реж2
реи1
1рей.
1рей.
рек2
1реко
1рекі
1рекꙋ
ре1л
рела1
релю1
рем2
ре1мн
1ремї
1ремї
1рена1
рене1
1ренъ
1рень
1ренї1
1ренї1
ре1р2
ре1с
1ресь
рет2
1реті
1ретї
1рехъ
1рецъ
ре1ч2
1речѐ
1речѐ
1речє
2реш
1рещи
1рею
реѡ1
2рж
р1жд
р1же
рже1с
ржет1
р1жє
р1жꙋ
2рз
рза2
р1зе
рзе́1
р1зи
р2з2л
р1з2н2
рзно1
рзо́1
р1зы2
рзѡ1
р1з2ꙋ
р2и
ри́1д
ри́1ж
1ри́н
1ри́х
1ри́1ц
1ри́ч1
ри́1щ
ри̑1
1ри̑.
1ри̑г
1ри̑м
рив2
ри1вл
ри1з2
ризы1
ри1к
рика1
2ри1л
рили1
2рим2
рими1
ри1н2
1рина
ри1с2
2рит
ри1х
1риц
2риш2
2рк2
р1ка
р1кв
р1ко2
р1кї
р1кї
р1кѡ
р1кѣ
ркѵ́1
р1кꙋ2
2рл
р1ла1
р1ли
рли́1
рлин1
2рм
р1ма
рма́1
рма1н
р1ме
р1ми
р1м2л
р2м1н
р1мо
рмо1л
р2м1ч
р1мї1
р1мї1
р1мѝ
рмꙋ́1
2р1н
рна́1
рне1м
рншї1
рншї1
рню1
рнѧ1
рнꙋ1
р2о
1ро́д
1ро́е
1ро́ж
ро́1л
ро́1н
ро́1п
ро́1х
1ро́1ц
робо1
1ров1н
1ров1с
ровѣ1
род2
1роде
1роди
1родн
1родо1
1родѝ
1родѧ
рое2
рое́1
рож2
1рожд
ро1зр
рои́1
рока1
ро1л
роли1
ролї1
ролї1
ромо1
рона1
1роно
рон1т
1ронѡ
роп2
ропо1
1ропѣ
1ропꙋ
ро1р2
ро1с2
росо1
рот2
1ротв
1ротѣ
ротѧ1
1ротꙋ
1рохи
роче1
ро1щ
1рою
роѧ́1
1роѳ
2рп
р1па
рпа́1
рпа1с
р1пе
р1пи
р2пл
рп1лю
рп1с
рпї2
рпї2
р1пѝ
р1пѣ
р1пѧ
рпѧ́1
р2пⷣ
2рр
р1ра
2рс2
р1са
р1се2
рсе́1
р1си
р1скꙋ
р1со1
р1сто
р1сѣ
2рт
р1та
р1тва
р1тве
р1тви
р1тво
р1твы
р1твє
р1твї
р1твї
р1твѣ
р1твꙋ
р1те
р1ти2
р2т1к
рт1н
ртна1
ртно1
ртнꙋ1
р1то
р1ты
рты1м
р1ті
р1тї
ртѵ́1
р1тꙋ1
2р1ф
рфѵ́1
2рх
р1ха
р1хи
р1хо1
рхї1
рхї1
рхꙋ2
рц2
2р1ца
рца́1
р2це2
р1цы.
2р1цє
2р1цѣ
2р1цꙋ
2р1ч
рче1
рчи́1
2р1ш2
рша́1
рше1м
ршꙋ1
р2щ1
2р2ъ
р2ы
1ры́г
ры́1с
ры́1т
ры́1ш
1ры́ѧ
ры̑1
2рыѧ
2р2ь1
рько1
р2ю
1рю.
1рю́1
1рют
р2є
1рє́м
1рє́н
1рєѝ
1рєм
рєни1
1рєс
1рєѝ
р2і
1рі́а
1рі́е1
1рі́и
рі́1к
1рі́м
рі́1х
1рі́ю
1рі́ѧ
1рїд
1рїе1в
рїи1м
1рїин
1рїкъ
1рї1л
1рїн
рї1с2
1рїсе
1рїсє
1рїтѡ
1рїц
р2ї
1рїд
1рїе1в
рїи1м
1рїин
1рїкъ
1рї1л
1рїн
рї1с2
1рїсе
1рїсє
1рїтѡ
1рїц
р2ѝ
р2ѡ
1рѡ́к
рѡ́1с
1рѡ̑1
1рѡд
1рѡма
1рѡн
1рѡп
1рѡ2с
2рѡ1т
1рѡі
р2ѣ
1рѣ́.
1рѣ́е
рѣ́1ж
рѣ́1з
1рѣ́й
1рѣ́й
рѣ́1н
рѣ́1с
1рѣ̑й
1рѣ̑й
1рѣ̑1ч
рѣ1з2
рѣ1л
рѣ1с
рѣ1т
1рѣ2ч
р2ѧ
1рѧ.
1рѧ́д
рѧ́з1
рѧ́1м
рѧ́1х
рѧ́ю1
2рѧд
рѧ1н
2рѧс
2рѧ2т
2рѧ1ц
2р1ѳ
рѳе2
рѳе́1
рѳо1
рѵ́1
р2ѷ
1рѷ2к
1рѷ1м
1рѷн
2рѷп
2рѷ1с
1рѷѱ
р2ѷ
1рѷ2к
1рѷ1м
1рѷн
2рѷп
2рѷ1с
1рѷѱ
р҃2
р҃ї1
р҃ї1
рⷣ2
2р2ⷭ
р2ꙋ
рꙋ́1з
1рꙋ́л
рꙋ́1п
1рꙋ́т1
1рꙋ́х
1рꙋ́ч1
1рꙋ́ш
1рꙋ́ю
1рꙋ́ѳ
рꙋ̑1п
1рꙋ̑с
рꙋ1б2
1рꙋ1в
рꙋ1д
1рꙋем
1рꙋет
1рꙋеш
рꙋ1з
1рꙋй
1рꙋй
1рꙋк
1рꙋмы
1рꙋс
2рꙋ2т
рꙋцѣ1
1рꙋче
1рꙋющ
1рꙋѧ.
1рꙋѧй
1рꙋѧй
1рꙋⷯ
с2а
1са́.
1са́в
1са́н
са́р1
1са́1с
са́1т
1са́ф
1са́х
са́1ш
1са́ю
1са́є
1са́ї1
1са́ї1
1са́ѵ
са̑д1
1са̑1н
1саа
1сав
сава1
са1д
1саж
1саи
саи́1
1са1л2
сала1
сало1
1сан
санꙋ1
1са1р2
1са1с2
са1т
сата1
1саф
са1х
саха1
1саш
саша1
саꙋ2
с2б
сбꙋ́1
1с2в2
сва1
сви́1
свы́1
сві́1
свѧ1т
свѵ́1
с2г
сга1
с2е
1се́а
се́1в
1се́е
1се́и
1се́о
1се́р
се́1с
се́1ш
1се́є
1се́1ѵ
себо1
се1в
сева1
севе1
сег2
сегꙋ1
се1д2
се1з2
1сей
1сей
секо1
се1л
1селѡ
се1м
сена1
сене1
1сенъ
1сера1
1серъ
се1с
1сехъ
сеца1
1сецъ
се1ч
1сеѡ́
с2и
1си́в
1си́л
1си́м
си́1р
1си́1с
си́1т
си́1ц
1си́ш
1си̑
1сиб
1сив
1си1к
1си2л
1сим
си1р
1си1с2
1сит
1сиф
1си1х
1сиц
сице1
1сиш
ск2
1с2ка
ска̑1
1скв
1с2ке
1с2ки
1склї1
1склї1
1с2ко
скон1
1с2кр
скри1
2скъ
1с2кі
скі̑1
1скї
с2кѡ
1с2кѣ
1скꙋ.
1скꙋд
с1кꙋш
1скꙋю
1сл
сла́8в7лен
сла́8в7лю
с2ле
сле1з
слен1
с2ли
сли1м
сли1н
с1ло̀
2слс
2слъ
с2лы
слы́1
2сль
с2лю
с2лє
слєн1
с2лї1
с2лї1
с2лѝ
с2лѡ
с2лѣ
с2лѧ
с1лꙋ̀
с2м2
1сма
сма́1
сма1м
сма1р
1сме
смер1
сми1
1смѝ
1смо
смо1л
1смы
2смь
1смѝ
1смѣ
смѧ1
1смꙋ1
сн2
1сна̀
1сна́
сне2
1сней
1сней
1снен1
с1нет
1снех
1снец
1с2нѝ
1сни̑1
с1ни1к
снис1
1сниц
сно1
с1но̀
1сно́
1сноб
1снож
1сноп
1снос
1снот
1снц
2снъ
1сны́1
2снь
снї1
1снїю
снї1
1снїю
1с2нѝ
с1нꙋ̀
с1нꙋт
с1нꙋю
с2о
1со.
1со́
со́п1
со́1с
со́1ц
1соб2
со1в
1сове
1совѡ
1сог
1сод
сое1
1сож
1со1з2
соза1
созы1
сои2
соиз1
1сок
со1л
соло1
сом2
1со1мн
1сомꙋ
1со1н
сони1
1соп2
сопо1
1сор
со1с2
1сот2
1соч2
соче1
сочи1
1соѧ
соѧ́1
соꙋ2
сп2
1спа́
с1па1д
1спа1с
спа8с7ла̀.
спа8с7ло̀.
1спе.
1с2пѝ
1спи́
1спи1т
2спл
2с1пн
1спод
1спож
спол1
2спр
спре1
спро1
спрѧ1
2спы1
2спї1
2спї1
1с2пѝ
1с2пѡ
1спѣ̀
спѣ1в
1спѣш
2спѧ2
2спꙋ1
1с2р2
срав1
сраи1
сра1с
сре́7д8не
сре1д
сри2
сри́1
сро2
срѧ́1
2сс2
с1са.
сса́1
с1се2
с1ск
сска1
сскꙋ1
с1со2
ссо́1
с1ст2
с1сѡ
ссѡ́1
с2сѣ
ссѣ́1
ссѷ1
ссѷ1
1с2та
ста́8в7лен
ста́в7лю.
став1
стан1
1ства
1стве
1стви
8ствъ.
1ствы
1ствє
1ствї
1ствї
1ствѣ
1сте.
1с2тѐ
1стей
1стей
1стен
стер1
1стес
1стех
сте1ц
с1теч
1с2ти
сти̑1
ст2л
1стла
с1тлѣ
2ст1н
1сто.
1стоб
1стов
1стод
1стое
1стож
1стои
1сток
1стол
1стом
1стон
1сто1с
1стот
1стоф
1стох
1стош
1стою
1стоѡ
1стоѧ
1стоѱ
1стра
страж7бы̑.
1стрѐ
1стри
1стро
1стры
1стрѐ
1стрі
1стрѝ
1стрѣ
1стрѵ
2стс
2с2т1ц
2стъ
1с2ты
2сть1
1с2тѐ
1с2тє1
1с2ті
стї1
1с2тї1
1с2тѡ
1с2тѣ
1с2тѧ
1ст҃
1с2тꙋ
сх2
1с2ха
2схв
1схи.
схи́1
2схо
1с2хꙋ
2с1ца
1с2це1
с1цы.
1сцы̀
2с1цѣ
сцѣ1л
2с1ч
сча̑1
счер1
счи1
2сш2
сша1
сше1м
сшї1
сшї1
1сщ
2с2ъ
1сы.
1сы̀
1сы́.
1сы́п
1сы́1т
1сыл
2сын
сынов8ле́н
1сып
1сы1р
1сыщ
2с2ь1
сю́1
1сє́й
1сє́й
1сє́1н
1сі
сі́1л
сі́1м
сі́1н
с2ї
сї1к
сї1н
сїо1
сї1п
сї1с
сі̑2
1с2ї
сї1к
сї1н
сїо1
сї1п
сї1с
1сѡ̀
1сѡ́
сѡ́1ж
сѡ́1з
сѡ́1к
сѡ́с1
2сѡ1в
сѡ1с2
1сѡ1т
сѣ́1в
1сѣ́д
1сѣ́к
сѣ́ю1
2сѣ̑
сѣ̑1т
1сѣ1д
1сѣк
2сѣм
1сѣн
1сѣ1т
1сѣх
1сѣ1ч
1сѣщ
1с2ѧ
сѧ́1д
сѧ́з1
сѧто1
сѧ2ч1
сѧща1
сѧще1
1с2ѳ
сѳе2
1сѵ
1сѷ
2с҃
1с2ꙋ
сꙋ́1х
сꙋ́1ш
сꙋ́ю1
сꙋ̑1
сꙋ2б1
сꙋе1
сꙋм2
сꙋ1р
сꙋще1
т2а
1та́1г
та́1д
та́1ж
та́1к
1та́п
та́1т
та́1ш
та̑в1
та̑1н
1та̑ѧ
1тава
тав1л
1тавш
1тавъ
1таго
та1д
1таи
1тай
такѡ1
1та1л
1там
1тана
1танн
тан1т
1танꙋ
та1р
1таре
1тарѝ
1тарю
1тарѝ
1тарѧ
та1с2
1та1т
1та2х
1таш
1таю.
1тают
таѧ́1
таѵ1
т2в
1тваг
тва1м
1твар
твен1
1твер
1тве1ц
1тви.
1твѝ
твич1
1твор
1твос
2твъ
1твый
1твый
1твым
1твых
1твыѧ
2твь
твї1
твї1
1твѝ
твѡ1
1твѣ́1
твꙋ́1
2т1д
тде1
т2е
те́1б
1те́ж
те́1л
1те́п
те́1ч
2те1з2
тезо1
тек2
1текꙋ
1тел
тели1
тем1
тенї1
тенї1
2теп
1тера
1терб
1терг
1тере
1терз
1тери
1тер1м
1терн
1теро1
тер8п7лю̀
тер8п7лѧ
1терс
1теры
1терь
1тері
1терї
те1с
1теск
1те1т2
2теф
те2х
1тецъ
те1ч
1течѐ
1течѐ
1теш
т2и
1ти́1д
ти́1ж
1ти́1з
ти́1н
1ти́р
ти́1с
1ти̑.
1ти̑л
1ти̑1н
тива1
1тив1л
1тиво1
2тиг
2тиж
1тила
1тими1
2тин
тино1
2ти1р
1ти1с2
тити1
ти1х
тихо1
1тиш
тиша1
тиши1
1тищ
тк2
2тка2
т1ка̀
тка́1
2т1ки2
1т2кн
2т1ко1
2т1кї
2т1кї
2т1кꙋ2
тла́1
т1лаг
1тлан1
т1лаѧ
т2ле1
т1ли.
1т2лѝ
1тли́1
тли1в
2т1ло
2тлш
2т1лы
т2лю
2т1лї1
2т1лї1
1т2лѝ
2т1лѡ
т1лѣ.
1тлѣ̑
т2лѧ
2т1лꙋ1
т2м
тма́1
тмо́1
тмо1р
2тн
тне́1
т1нее
т1ни
тно́1
т1ном
тны̑1
т1ню1
т1ні
тні́1
тнї1
тнї1
т1нѣ.
т1нѣ̀
тнꙋ́1
т1нꙋю
т2о
то́е1
то́1ж
1то́1з
1то́п
то́т1
1то́х
1то́ш
1то́ю
то́ѧ1
1това
1тов1л
тов1н
1тово
тов1с
1товъ
1товы
1товѣ
1тог
тод2
1тода
1тодн
1тодї
1тодї
тоже1
1то1з2
1толе1
1толѝ
толю1
1толѝ
1толѧ
1толꙋ
том2
то1н
1тона1
1тоні
1топе
1топи
1топ1л
топо1
1топѝ
1топѧ
1торж
1торн
1торѣ
тос2
1тосо1
1тост
тот2
1тотв
тох2
1точа
1точи
точ1н
1точє
1точѝ
то1щ
1тоща
1тощѝ
1тощѝ
2тоѧ
1тоꙋ2
т2р2
траг1
1тре.
1треб
тре8б7ле́н
тре8б7лю̀.
тре8б7лѧ
трез1
тре1м
1трен
1треп
1тре1ц
три1в
1трил
1тро.
1трок
1троп
1трос
1троф
1троц
1троч
2тръ
1тры.
2трь
1трє
трєн1
1трї
1трї
1трѡ
трѡ́1
1трѧ
1трꙋб
1трꙋж
2т1с2
тст2
т2сѣ
2т1т
1т2х
тха1
тхо1
тхї2
тхї2
1тца.
1т2це2
1тцы.
1тцы̀
1т2цє
тцѣ2
т1цѣ.
1тцѣ̀
1т2цꙋ
тча2
1тча.
тча́1
1тчах
1т2чѐ
1тчее
1тчей
1тчей
1тчею
1т2чи2
1т2чѐ
1т2чꙋ
2т1ш2
тша2
тшы1
1т2щ2
тще1
2т2ъ
т2ы
ты́д1
1ты́м
ты́1с
1ты́х
1ты́ѧ
1ты̑.
ты̑н1
1ты̑ѧ
2тыд
2тыж
1тыма
2ты1н2
ты2х
2т2ь
ть1с
тю́1
1тє́й
1тє́й
1тє́ц
1тє́1ч
2тєз
1тєл
2тє1н2
1тєск
1тєц
1ті́а
ті́1г
1ті́е1
ті́1м
1ті́ч
1ті́ю
1ті́ѡ
т2ї
1тїа.
1тїѐ
1тїе́
1тїею
1тїѝ
1тїй
1тїих
1тїй
1тїк
тї1л
1тїлї1
1тїлї1
тї1м
тї1н
1тїно1
тїнї1
тїнї1
1тїо
1тї1п
1тїф
1тїю̀
1тїѐ
1тїѝ
1тїѧ̀
1тїѧг
1тїѧм
1тїѧх
1ті̑1
т2ї
1тїа.
1тїѐ
1тїе́
1тїею
1тїѝ
1тїй
1тїих
1тїй
1тїк
тї1л
1тїлї1
1тїлї1
тї1м
тї1н
1тїно1
тїнї1
тїнї1
1тїо
1тї1п
1тїф
1тїю̀
1тїѐ
1тїѝ
1тїѧ̀
1тїѧг
1тїѧм
1тїѧх
т2ѡ
тѡ́и1
1тѡ́1к
1тѡ́н
1тѡв
2тѡ1д
1тѡлі
1тѡм
1тѡн
2тѡп
2тѡ2р
2тѡѧ
т2ѣ
1тѣ́в
1тѣ́л
1тѣ́м
тѣ́1с
1тѣ́1т
1тѣ́1ш
1тѣ́ю1
1тѣ̑
тѣ̑1н
тѣ1л
2тѣм
2тѣ1н
1тѣ2р
1тѣ1с
1тѣш
т2ѧ
1тѧ̀
1тѧ́й
1тѧ́й
1тѧ́1х
1тѧ́ш
1тѧ̑
1тѧже
1тѧ1з
1тѧ2т1
1т2ѳ
тѳе2
1тѵ
тѷ2м1
1тѷ
тѷ2м1
т҃2
т҃о1м
2тⷭ
тⷯ2
т2ꙋ
1тꙋ́е1
тꙋ́1н
тꙋ́1ч
тꙋ́1щ
1тꙋ́ю1
тꙋ̑2
тꙋ̑д1
тꙋ̑п1
тꙋ1д
1тꙋе
2тꙋк
1тꙋн
1тꙋ2р1
8у.
8у̀8.
8у́8.
8у̑8.
8у҆̀8.
8у҆́8.
8у҆̈8.
8у҆̑8.
8уⷠ.
8уⷠ҇.
8уⷡ.
8уⷡ҇.
8уⷢ.
8уⷢ҇.
8уⷣ.
8уⷣ҇.
8уⷤ.
8уⷤ҇.
8уⷥ.
8уⷥ҇.
8уⷦ.
8уⷦ҇.
8уⷧ.
8уⷧ҇.
8уⷨ.
8уⷨ҇.
8уⷩ.
8уⷩ҇.
8уⷪ.
8уⷪ҇.
8уⷫ.
8уⷫ҇.
8уⷬ.
8уⷬ҇.
8уⷭ.
8уⷭ҇.
8уⷮ.
8уⷮ҇.
8уⷯ.
8уⷯ҇.
8уⷰ.
8уⷰ҇.
8уⷱ.
8уⷱ҇.
8уⷲ.
8уⷲ҇.
8уⷳ.
8уⷳ҇.
8уⷴ.
8уⷴ҇.
8уⷵ.
8уⷵ҇.
8уⷶ.
8уⷶ҇.
8уⷷ.
8уⷷ҇.
8уⷸ.
8уⷸ҇.
8уⷹ.
8уⷹ҇.
8уⷺ.
8уⷺ҇.
8уⷻ.
8уⷻ҇.
8уⷼ.
8уⷼ҇.
8уⷽ.
8уⷽ҇.
8уⷾ.
8уⷾ҇.
8уⷿ.
8уⷿ҇.
8уꙴ.
8уꙴ҇.
8уꙵ.
8уꙵ҇.
8уꙶ.
8уꙶ҇.
8уꙷ.
8уꙷ҇.
8уꙸ.
8уꙸ҇.
8уꙹ.
8уꙹ҇.
8уꙺ.
8уꙺ҇.
8уꙻ.
8уꙻ҇.
8у꙼.
8у꙼҇.
8у꙽.
8у꙽҇.
1ф2а
фа́1в
фа1в
фа1л2
фа1м
фа1н
фара1
1фе
фе́1с
фе1в
фе1л
фе1р2
фе1с
фе2ѵ1
фи1
1ф2л
фла1
фле́1
фло1
1ф2н
фнꙋ2
фнꙋ́1
1фо
фо1в
фо2м
1ф2р2
фра2
фран1
фре2
фро́1
фрон1
фрї1к
фрї1к
фрꙋ1
2ф1с2
фска1
2фъ
1фі́в
1фі́и
1фі́л
1фі́м
1фі́н
фі́р1
1фї
фї1л2
фїла1
1фі̑
1фї
фї1л2
фїла1
1ф2ѡ
фѡ́1к
фѡ́1т
фѡ1т
2ф1ѳ
фѳо2
1фѵ
фѵ́1р
фѷ1
1фѷ1
1фꙋ
фꙋ́2
фꙋ̑2
фꙋ2л1
фꙋ2р1
1ха̀
1ха́
ха́1м
ха́1р
ха́ю1
1ха̑
ха̑1н
1хаа
2хаг
1хаи
1хал
ха1н
хана1
ха1р
хара1
2хаѧ
1х2в
хва1л
хво2
х2е
хе1в2
хе1р2
херꙋ1
2х1ж
х2и
1хѝ
1хи́
хи́н1
хи́1р
хи́1т
хи́щ1
1хи̑
хи̑н1
1хи2м
1хи1т2
1хищ
1х2л
1х2ма
2х1мѝ
2х1мѝ
2хн
х2не2
х1но1
х2о
1хо.
1хо́в1
1хо́м
1хо́1щ
1хо1в
ход2
1хода
1ходв
1ходо1
1хое
хож2
1хо1л
холю1
1хом
1хоп
хопа1
1хо2р
1хо1с
1хот2
хо1щ
1хоѻ
1х2р2
хра1н
хре1
хри1
хро1
хрї1
хрї1
хрѷ1
хрѷ1
2х1с2
хска1
хст2
хстѣ1
х1ти1
1х2ті
хті́1
2х1ш
2х2ъ
1хі
хї2к
хї1м
хї1с
хїсе1
1хї
хї2к
хї1м
хї1с
хїсе1
1хѝ
1хѡ
хѡ́1м
хѡ1т
1хѣ
1хꙋ
хꙋ́1д
хꙋ1д
хꙋ1л
1ца́.
1ца́е
1ца́1л
1ца́р
ца́р7ства
ца́р7ство
ца́р7ствї
ца́р7ствї
ца́р7ствѣ
ца́р7ствꙋ
1ца́1т
1ца́х
1ца́1ш
1ца́ю1
1ца́ѧ
1цам
1ца1р
1ца2х
1ц2в
цвѣ1т
ц2е
1цѐ
1це́в
це́р1
1це́1т
1це1в
1цег
цего1
1цемѣ
1це1н
2цеп
це2р1
1це1с
цеса1
1цею
2цк
ц1ка1
ц1ки
ц1ко1
ц1кї
ц1кї
1цр
2ц1т
цто2
2ц2ъ
цы́1
1цы̑
1цыи
1цѐ
ц2є
цє́2
1цє́м
1цєва
1цєм
1цї1
цїо2
1цї1
цїо2
1цѣ́
1цѣ̑
цѣ1в2
1цѣй
1цѣй
1цѣл
1цѣ2м
1цѣ2х
2ц҃
цⷣе1
цꙋ́2
1цꙋ́з1
1цꙋ̑
1ч2а
ча́1м
ча́1н
ча́1ш
ча̑1т
ча1в
ча1л
чало1
ча1м
ча1с2
часо1
2ча2х
1ч2е
че́1ж
че́з1
че́1ш
чево1
че1з2
2чей
2чей
че1л
чело1
че2м
чено1
ченї1
ченї1
черм1
чер1т
черї1
черї1
че7с8тѝ.
че7с8тѝ.
чет2
1ч2и
чи́1с
чи́щ1
чи̑1
чи1в
чи2л
чи1н
чино1
чис7ле
чис7лѣ
чити1
чи2х
чиша1
2ч1к
1ч2л
чле1
2чн2
ч1на
ч1не1м
ч1нет
ч1ник
ч1ниц
ч1но
чноа1
ч1ны
чнї1
чнї1
ч1нѣ
ч1нꙋ1
чнꙋю1
1чо
1чр
2ч1та
чта̑1
1ч2ти
что2
ч1то.
1что̀
1что́1
ч2тє
чтє́1
1чтѝ
2чт҃
1чтⷭ
ч2тꙋ
ч2ц
2ч1ш2
чша1
чше1
чши2
1чы
2ч2ь
1ч2ю1
чюде1
1чє
чє́в1
чє́1л
чє́р1
чє1н2
1чі
чі́1
ч2ї
1ч2ї
1ч2ѝ
1чѣ1
1чѧ
2ч҃2
ч҃е1
ч҃ї2
ч҃ї2
2чⷣ
1чⷭ҇т
ч2ꙋ
1чꙋ̀
1чꙋ́
чꙋ̑2
чꙋ̑д1
1чꙋ1д
чꙋдо1
1чꙋж
1чꙋщ
1ш2а
ша́в1
ша́л1
ша́1н
ша́1ш
ша́є1
шаго1
шагѡ1
ша2м
ша1н
ша1с2
1ш2е
ше́в1
ше́1с
ше2в1
шее1
ше1л
шело1
шемо1
шемꙋ1
шенї1
шенї1
ше1с
шет2
ше1х
1ш2и
ши́1п
ши́р1
ши́1с
ши1в
ши2л
ши1р
широ1
ши1с2
шити1
ши2х
2ш1к
шла2
2ш1ли
ш1лє
шлє́1
ш1лѧ
2ш1н2
шна1
шно1
шню1
шнѧ1
2ш1ц
шце1
2ш1ш
шша1
шшым1
шшꙋ1
2шъ
1шы
шы2м
1шѐ
1шє
шє́в1
шє́1с
1шї
шїи1
1шї
шїи1
1шѝ
1шѣ
1ш2ѧ1
2ш҃
1ш2ꙋ
шꙋ́1с
шꙋ́ю1
шꙋще1
шꙋю1
1ща.
1ща̀
1ща́в
1ща́д1
1ща́е
1ща́1м
ща́1с
1ща́1х
ща́1ш
ща́1щ
1ща́ю
1ща1в
1щаг
щаго1
1ща1д
1ща1м
1ща1н
1ща1с2
1ща2х
1щаѧ1
2щ1в2
1щ2е
ще́1с
щебо1
2ще1в
ще1д2
щее1
щемꙋ1
щенї1
щенї1
ще1с
ще2х
1щ2и
щи́1с
щи1с2
щи1т
2щ1н
щна́1
щно́1
щно1м
щнꙋ1
2щ1с2
щст2
2щ1ш2
щша1
щшаѧ1
щше1
2щъ
1щы
щы2м
2щ2ь1
щ2є
1щє́н1
щє́1р
щє́т1
1щєм
1щє1н2
1щєс
1щ2ї
щїи1
1щ2ї
щїи1
1щѡ
1щѣ
1щ2ѧ
1щ2ꙋ
щꙋ́1
щꙋ2т
щꙋю1
8ъ
ъ1д2
2ы
8ы.
ы2̀
8ы̀8.
ы2́
8ы́8.
ы́б1л
ы́2в
ы́2г1
ы́к2
ы́1кн
ы́лї1
ы́лї1
ы́нї1
ы́нї1
ы́2п1
ы́с2
ы́те1
ы́ти1
ы́ты1
ы́тї1
ы́тї1
ы́1ц
ы́че1
ы́чи1
ы́ше1
ы́1щ2
ы2̑
8ы̑8.
ы̑1б
ы̑2в1
ы̑2м
ы̑1с2
ы̑ч1
ы̑ш1
ы1в
ыва́1
ыва̑1
ы1г2
ы1д
ыдо2
ыдѣ́1
ы1ж2
ы1з
ыза2
ыза́1
ызы1
ы1и
ый1
ы2й1
ы2к1н
ы1ко
ыко́1
ыко1в
ы1л2
ыла2
ыла́1
ы1ма
ы1ми
ы1не1
ы1ни
ын1м
ы1но1
ы1ню
ы1нѣ
ы1п
ыпа2
ыпа́1
ы1ре
ыре1д
ыре1н
ы1ри
ыр1м
ы1ро1
ы1рю
ы1рє
ы1рї1
ы1рї1
ы1рѣ
ы1рѧ
ыс2
ы1ск
ы1со
ы1сѡ
ысѡ́1
ы1т
ытї1
ытї1
ытꙋ́1
ы1ха
ыха̑1
ыша2
ыша́1
ыше2
ыше́1
ыш1л
ы1щ
ыща́1
ыщи́1
ыщꙋ2
ы1ѧ1
8ы҆̀8.
8ы҆́8.
8ы҆̈8.
8ы҆̑8.
8ыⷠ.
8ыⷠ҇.
8ыⷡ.
8ыⷡ҇.
8ыⷢ.
8ыⷢ҇.
8ыⷣ.
8ыⷣ҇.
8ыⷤ.
8ыⷤ҇.
8ыⷥ.
8ыⷥ҇.
8ыⷦ.
8ыⷦ҇.
8ыⷧ.
8ыⷧ҇.
8ыⷨ.
8ыⷨ҇.
8ыⷩ.
8ыⷩ҇.
8ыⷪ.
8ыⷪ҇.
8ыⷫ.
8ыⷫ҇.
8ыⷬ.
8ыⷬ҇.
8ыⷭ.
8ыⷭ҇.
8ыⷮ.
8ыⷮ҇.
8ыⷯ.
8ыⷯ҇.
8ыⷰ.
8ыⷰ҇.
8ыⷱ.
8ыⷱ҇.
8ыⷲ.
8ыⷲ҇.
8ыⷳ.
8ыⷳ҇.
8ыⷴ.
8ыⷴ҇.
8ыⷵ.
8ыⷵ҇.
8ыⷶ.
8ыⷶ҇.
8ыⷷ.
8ыⷷ҇.
8ыⷸ.
8ыⷸ҇.
8ыⷹ.
8ыⷹ҇.
8ыⷺ.
8ыⷺ҇.
8ыⷻ.
8ыⷻ҇.
8ыⷼ.
8ыⷼ҇.
8ыⷽ.
8ыⷽ҇.
8ыⷾ.
8ыⷾ҇.
8ыⷿ.
8ыⷿ҇.
8ыꙴ.
8ыꙴ҇.
8ыꙵ.
8ыꙵ҇.
8ыꙶ.
8ыꙶ҇.
8ыꙷ.
8ыꙷ҇.
8ыꙸ.
8ыꙸ҇.
8ыꙹ.
8ыꙹ҇.
8ыꙺ.
8ыꙺ҇.
8ыꙻ.
8ыꙻ҇.
8ы꙼.
8ы꙼҇.
8ы꙽.
8ы꙽҇.
8ь
ь1б
ьбо́1
ь2в
ьво2
ьво́1
ь1г
ь1д
ьде1
ь1ж
ь1з2
ьзꙋ1
ь1к
ька1
ькї1
ькї1
ькꙋ1
ь1ме
ь1ми
ь2мо2
ьмо́1
ь2мы
ь1мѝ
ь2мѣ
ь2мꙋ
ь1н
ьна1
ьно1
ьнї1
ьнї1
ьнꙋ1
ь2п2
ьс2
ь1ск
ьска1
ьскꙋ1
ьст2
ь1ств
ь1т
ьте1
ьтє1
ьтѧ1
ь1ц
ь1ч
ьче1
ь1ш2
ьша1
ьшаѧ1
ьшым1
ьшꙋ1
ь2щ
ь1ꙋ
ьꙋ́1
8э.
8э̀8.
8э́8.
8э̑8.
8э҆̀8.
8э҆́8.
8э҆̈8.
8э҆̑8.
8эⷠ.
8эⷠ҇.
8эⷡ.
8эⷡ҇.
8эⷢ.
8эⷢ҇.
8эⷣ.
8эⷣ҇.
8эⷤ.
8эⷤ҇.
8эⷥ.
8эⷥ҇.
8эⷦ.
8эⷦ҇.
8эⷧ.
8эⷧ҇.
8эⷨ.
8эⷨ҇.
8эⷩ.
8эⷩ҇.
8эⷪ.
8эⷪ҇.
8эⷫ.
8эⷫ҇.
8эⷬ.
8эⷬ҇.
8эⷭ.
8эⷭ҇.
8эⷮ.
8эⷮ҇.
8эⷯ.
8эⷯ҇.
8эⷰ.
8эⷰ҇.
8эⷱ.
8эⷱ҇.
8эⷲ.
8эⷲ҇.
8эⷳ.
8эⷳ҇.
8эⷴ.
8эⷴ҇.
8эⷵ.
8эⷵ҇.
8эⷶ.
8эⷶ҇.
8эⷷ.
8эⷷ҇.
8эⷸ.
8эⷸ҇.
8эⷹ.
8эⷹ҇.
8эⷺ.
8эⷺ҇.
8эⷻ.
8эⷻ҇.
8эⷼ.
8эⷼ҇.
8эⷽ.
8эⷽ҇.
8эⷾ.
8эⷾ҇.
8эⷿ.
8эⷿ҇.
8эꙴ.
8эꙴ҇.
8эꙵ.
8эꙵ҇.
8эꙶ.
8эꙶ҇.
8эꙷ.
8эꙷ҇.
8эꙸ.
8эꙸ҇.
8эꙹ.
8эꙹ҇.
8эꙺ.
8эꙺ҇.
8эꙻ.
8эꙻ҇.
8э꙼.
8э꙼҇.
8э꙽.
8э꙽҇.
8ю.
ю2̀
8ю̀8.
ю2́
8ю́8.
2ю́б
ю́б1л
ю́дї1
ю́дї1
ю́дꙋ1
ю́1ж
1ю́з
ю́2л
ю́1с2
ю́та1
ю́то1
1ю́тс
ю́1щ2
1ю́ща
1ю́ще
1ю́щи
1ю́щѧ
ю́щꙋ1
ю́ю1
8ю̈8.
ю̑1
8ю̑8.
ю2б1в
ю2б1л
юбо1м
ю1да
ю1де
юди́1
ю1дм
ю1до2
юдо́1
юд1с
ю1ді
ю1е
1ю1ж2
ю1с2
2юст
ю2т
1ютс
ю1ч
юче2
юче́1
ю1щ2
юща1
1ющас
1ющаѧ
1юще
1ющис
1ющих
1ющъ
1ющыѧ
1ющь
1ющїи
1ющїѧ
1ющїи
1ющїѧ
2ющѣ
1ющѧ
ющꙋ1
1ющꙋс
1ющꙋю
ю1ю1
ю1ѧ
8ю҆̀8.
8ю҆́8.
ю҆́1ж
ю҆́1н
8ю҆̈8.
8ю҆̑8.
ю҆1р
8юⷠ.
8юⷠ҇.
8юⷡ.
8юⷡ҇.
8юⷢ.
8юⷢ҇.
8юⷣ.
8юⷣ҇.
8юⷤ.
8юⷤ҇.
8юⷥ.
8юⷥ҇.
8юⷦ.
8юⷦ҇.
8юⷧ.
8юⷧ҇.
8юⷨ.
8юⷨ҇.
8юⷩ.
8юⷩ҇.
8юⷪ.
8юⷪ҇.
8юⷫ.
8юⷫ҇.
8юⷬ.
8юⷬ҇.
8юⷭ.
8юⷭ҇.
8юⷮ.
8юⷮ҇.
8юⷯ.
8юⷯ҇.
8юⷰ.
8юⷰ҇.
8юⷱ.
8юⷱ҇.
8юⷲ.
8юⷲ҇.
8юⷳ.
8юⷳ҇.
8юⷴ.
8юⷴ҇.
8юⷵ.
8юⷵ҇.
8юⷶ.
8юⷶ҇.
8юⷷ.
8юⷷ҇.
8юⷸ.
8юⷸ҇.
8юⷹ.
8юⷹ҇.
8юⷺ.
8юⷺ҇.
8юⷻ.
8юⷻ҇.
8юⷼ.
8юⷼ҇.
8юⷽ.
8юⷽ҇.
8юⷾ.
8юⷾ҇.
8юⷿ.
8юⷿ҇.
8юꙴ.
8юꙴ҇.
8юꙵ.
8юꙵ҇.
8юꙶ.
8юꙶ҇.
8юꙷ.
8юꙷ҇.
8юꙸ.
8юꙸ҇.
8юꙹ.
8юꙹ҇.
8юꙺ.
8юꙺ҇.
8юꙻ.
8юꙻ҇.
8ю꙼.
8ю꙼҇.
8ю꙽.
8ю꙽҇.
8ѐ8.
8ё8.
8є.
8є̀8.
є2́
8є́8.
є́би1
є́1бр
є́2д1
є́1ж2
є́2з1
є́лю1
є́лї1
є́лї1
1є́мы1
є́нї1
є́нї1
1є́нѣ
є́1п2
є́р1д
є́р1с
є́с1н
є́2ц
2є́ч
є́че1
1є́ю
8є̈8.
8є̑8.
є1ва
єва́1
є1вы
єд1
єдни1
є1з
2є1ѝ
є1ли
є1ма1
1єма.
2єм1н
є1мы
2є1мї1
2є1мї1
2єн
є1ни
єнни1
є1ны
єнї1
єнї1
є1с2
єска1
єскї1
єскї1
єст2
єт1
1єтн
єтна1
є2ц
єч1
єчны1
2є1ѝ
1єѵ1
єѵрѡ1
8є҆̀8.
8є҆́8.
є҆́1в
є҆́1ж
є҆́л1
є҆́м1
8є҆̈8.
8є҆̑8.
є҆1в2
є҆г2
є҆1з2
є҆ка1
є҆ре1
є҆1с2
є҆1ф
є҆ѧ́1
8єⷠ.
8єⷠ҇.
8єⷡ.
8єⷡ҇.
8єⷢ.
8єⷢ҇.
8єⷣ.
8єⷣ҇.
8єⷤ.
8єⷤ҇.
8єⷥ.
8єⷥ҇.
8єⷦ.
8єⷦ҇.
8єⷧ.
8єⷧ҇.
8єⷨ.
8єⷨ҇.
8єⷩ.
8єⷩ҇.
8єⷪ.
8єⷪ҇.
8єⷫ.
8єⷫ҇.
8єⷬ.
8єⷬ҇.
8єⷭ.
8єⷭ҇.
8єⷮ.
8єⷮ҇.
8єⷯ.
8єⷯ҇.
8єⷰ.
8єⷰ҇.
8єⷱ.
8єⷱ҇.
8єⷲ.
8єⷲ҇.
8єⷳ.
8єⷳ҇.
8єⷴ.
8єⷴ҇.
8єⷵ.
8єⷵ҇.
8єⷶ.
8єⷶ҇.
8єⷷ.
8єⷷ҇.
8єⷸ.
8єⷸ҇.
8єⷹ.
8єⷹ҇.
8єⷺ.
8єⷺ҇.
8єⷻ.
8єⷻ҇.
8єⷼ.
8єⷼ҇.
8єⷽ.
8єⷽ҇.
8єⷾ.
8єⷾ҇.
8єⷿ.
8єⷿ҇.
8єꙴ.
8єꙴ҇.
8єꙵ.
8єꙵ҇.
8єꙶ.
8єꙶ҇.
8єꙷ.
8єꙷ҇.
8єꙸ.
8єꙸ҇.
8єꙹ.
8єꙹ҇.
8єꙺ.
8єꙺ҇.
8єꙻ.
8єꙻ҇.
8є꙼.
8є꙼҇.
8є꙽.
8є꙽҇.
ѕ2
ѕвѣ̑1
1ѕл
ѕла2
ѕла̑1
ѕло1в
ѕмї1
ѕмї1
ѕѣ́2
ѕѣ1л
8і.
8і̀8.
8і́8.
2і́а
і́г2
і́и1
і́к2
2і́л
1і́мв
і́н1д
і́ни1
1і́нт
і́нꙋ1
і́2п
і́р1м
і́ро1
і́1см
і́с1с
і́то1
і́тѧ1
і́1ф
і́1ц
і́1ч
і́че1
і́є1в
і́2ѯ
і́2ѳ
8ї8.
ї1а
2їа́
їа́1д
їа1д
їа1м
їа1н
ї1в2
їве́1
ївї1
ївї1
ї1га
ї2г1г
ї1ги
їги́1
ї1д2
їдї1
їдї1
2їе
їе́1ш
їе2м
їе1р2
ї1и
2їѝ
їи́1д
їи́1н
їй1
їи̑2
їи̑м1
2їим
їи1н
1їина
їи1с2
їи1т
2їих
ї2й1
їк2
2ї1ка
їка1н
ї1ке
2ї1ки
їки́1
ї1ко
їко́1
їко1н
ї1кт
їкто1
ї1кі
їкї1
ї1кї1
ї1кѡ
2ї1ла
їла1р
їл1в2
ї1ле
їле́1
ї1ли
їллї1
їллї1
ї1ло1
ї1лі
2їлї
їлїп1
2ї1лї
їлїп1
1ї1лѧ
ї1лꙋ1
2їм
ї1ма
їман1
ї1ме1
ї1мо1
ї1мї1
ї1мї1
ї1на2
2їн1б
їн1д
ї1не
їне́1
ї1но
1їно.
їноа1
їн1т
їнтї1
їнтї1
1їнъ
1ї1ны
ї1о
їо́1п
їо1м
їо1н
їо1с2
ї1па2
їп1п
їпї1
їпїо1
їпї1
їпїо1
ї1ра
ї1ре
ї1ро1
їр1с
2їс
ї1са
їса1в
ї1се
ї1со1
їс1с
їс2т2
ї1сте
ї1сто
ї1стр
ї1сє
їсі́1
ї1сѡ
ї1т2
1їтѝ
їті́1
1їтѝ
їтѷ1
їтѷ1
їтꙋ2
ї1ф2
їфа́1
ї1х
їха́1
їхи́1
їхи̑1
ї1ц
ї1ч
їча́1
2ї1ю
ї1ѐ
2ї1є
їє́1
2ї1ѝ
ї1ѡ
їѡ1н
їѡ1с
2ї1ѧ
їѧ́1с
їѧ1в2
ї2ѯ
ї1ѳ
1їѳа
їѳе2
ї1ѷ1
ї1ѷ1
2і̑
8і̑8.
і̑2к
і̑р1
і̑1с2
8і҆̀8.
8і҆́8.
і҆́1д
і҆́н1
8і҆̈8.
8і҆̑8.
і҆а́1
і҆г2
і҆дѡ1
і҆2з1
і҆к2
і҆1м2
і҆2н1
і҆1с2
і҆са1
8іⷠ.
8іⷠ҇.
8іⷡ.
8іⷡ҇.
8іⷢ.
8іⷢ҇.
8іⷣ.
8іⷣ҇.
8іⷤ.
8іⷤ҇.
8іⷥ.
8іⷥ҇.
8іⷦ.
8іⷦ҇.
8іⷧ.
8іⷧ҇.
8іⷨ.
8іⷨ҇.
8іⷩ.
8іⷩ҇.
8іⷪ.
8іⷪ҇.
8іⷫ.
8іⷫ҇.
8іⷬ.
8іⷬ҇.
8іⷭ.
8іⷭ҇.
8іⷮ.
8іⷮ҇.
8іⷯ.
8іⷯ҇.
8іⷰ.
8іⷰ҇.
8іⷱ.
8іⷱ҇.
8іⷲ.
8іⷲ҇.
8іⷳ.
8іⷳ҇.
8іⷴ.
8іⷴ҇.
8іⷵ.
8іⷵ҇.
8іⷶ.
8іⷶ҇.
8іⷷ.
8іⷷ҇.
8іⷸ.
8іⷸ҇.
8іⷹ.
8іⷹ҇.
8іⷺ.
8іⷺ҇.
8іⷻ.
8іⷻ҇.
8іⷼ.
8іⷼ҇.
8іⷽ.
8іⷽ҇.
8іⷾ.
8іⷾ҇.
8іⷿ.
8іⷿ҇.
8іꙴ.
8іꙴ҇.
8іꙵ.
8іꙵ҇.
8іꙶ.
8іꙶ҇.
8іꙷ.
8іꙷ҇.
8іꙸ.
8іꙸ҇.
8іꙹ.
8іꙹ҇.
8іꙺ.
8іꙺ҇.
8іꙻ.
8іꙻ҇.
8і꙼.
8і꙼҇.
8і꙽.
8і꙽҇.
8ї8.
ї1а
2їа́
їа́1д
їа1д
їа1м
їа1н
ї1в2
їве́1
ївї1
ївї1
ї1га
ї2г1г
ї1ги
їги́1
ї1д2
їдї1
їдї1
2ї1е
їе́1ш
їе2м
їе1р2
ї1и
2їѝ
їи́1д
їи́1н
їй1
їи̑2
їи̑м1
2їим
їи1н
1їина
їи1с2
їи1т
2їих
ї2й1
їк2
2ї1ка
їка1н
ї1ке
2ї1ки
їки́1
ї1ко
їко́1
їко1н
ї1кт
їкто1
ї1кі
їкї1
ї1кї1
ї1кѡ
2ї1ла
їла1р
їл1в2
ї1ле
їле́1
ї1ли
їллї1
їллї1
ї1ло1
ї1лі
2їлї
їлїп1
2ї1лї
їлїп1
1ї1лѧ
ї1лꙋ1
2їм
ї1ма
їман1
ї1ме1
ї1мо1
ї1мї1
ї1мї1
ї1на2
2їн1б
їн1д
ї1не
їне́1
ї1но
1їно.
їноа1
їн1т
їнтї1
їнтї1
1їнъ
1ї1ны
ї1о
їо́1п
їо1м
їо1н
їо1с2
ї1па2
їп1п
їпї1
їпїо1
їпї1
їпїо1
ї1ра
ї1ре
ї1ро1
їр1с
2їс
ї1са
їса1в
ї1се
ї1со1
їс1с
їс2т2
ї1сте
ї1сто
ї1стр
ї1сє
їсі́1
ї1сѡ
ї1т2
1їтѝ
їті́1
1їтѝ
їтѷ1
їтѷ1
їтꙋ2
ї1ф2
їфа́1
ї1х
їха́1
їхи́1
їхи̑1
ї1ц
ї1ч
їча́1
2ї1ю
ї1ѐ
2ї1є
їє́1
2ї1ѝ
ї1ѡ
їѡ1н
їѡ1с
2ї1ѧ
їѧ́1с
їѧ1в2
ї2ѯ
ї1ѳ
1їѳа
їѳе2
ї1ѷ1
ї1ѷ1
8ѝ8.
ѝ1д
ѝдѣ1
8ѡ.
8ѡ̀8.
ѡ2́
8ѡ́8.
ѡ́1бр
2ѡ́в
ѡ́ва1
ѡ́ви1
ѡ́га1
ѡ́гї1
ѡ́гї1
1ѡ́дь
ѡ́1жд
ѡ́же1
ѡ́жї1
ѡ́жї1
ѡ́1зд
ѡ́з1н
ѡ́ин1
ѡ́и1х
ѡ́ка1
ѡ́л1г
ѡ́ли1
ѡ́л1н
ѡ́лї1
ѡ́лї1
ѡ́мї1
ѡ́мї1
ѡ́1п
ѡ́р1б
1ѡ́р1г
ѡ́р1д
ѡ́р1с
ѡ́с1н
ѡ́с1с
ѡ́1ч
ѡ́ча1
1ѡ́ѳ
8ѡ̈8.
8ѡ̑8.
ѡ̑м1
ѡ̑1т
ѡ1а
1ѡа́д
1ѡа́н
1ѡа́с
1ѡак
1ѡа2н1
1ѡа1с
1ѡ1б2
ѡби́1
ѡби1т
ѡбли1
ѡбо1
ѡбра7зꙋ́
ѡбрꙋ1
ѡбѣ2
ѡбѣ́1
ѡбꙋ1
ѡ1ва
ѡва́1
ѡ1ве
ѡв1лю
ѡв1лѧ
ѡ1во2
ѡ1вы
ѡ1вѣ1
ѡ1вꙋ
1ѡ1г
ѡго2
ѡгор1
ѡ1да
1ѡ1де
ѡ1ді
ѡді́1
ѡдї1
ѡ1дї1
ѡ1з
ѡзо2
ѡ1и
ѡи́2
1ѡи́л
ѡи1с
ѡ1к
1ѡкр
ѡ1ли
ѡли́1
ѡ1ло1
ѡ1лы
ѡ1лі
ѡлі́1
ѡ1лѡ
ѡ1лѣ
ѡлѣ́1
2ѡ1ма
ѡма́1
ѡ1мо2
ѡ1мы
ѡ1мѣ
ѡ1мѵ
ѡ1на
1ѡнаѳ
ѡ1не
ѡ1ни
ѡ1ны
ѡ1ні
ѡні́1
2ѡнѵ
ѡ1нꙋ
ѡ1п
1ѡпа
2ѡпе
1ѡпи2
ѡпи́1
1ѡпр
ѡпре1
2ѡпы
ѡ1ра
1ѡра́
2ѡ1ре2
ѡре́1
ѡ1ри2
ѡри́1
ѡ1ро
ѡров1
ѡр1с
ѡ1ры
ѡры́1
ѡ1рꙋ
1ѡрꙋ́
1ѡрꙋж
1ѡ1са1
ѡсвѧ1
1ѡ1с2к
1ѡсл
ѡс1с
ѡ1с2т2
1ѡстр
1ѡсщ
ѡсї1
ѡсї1
1ѡ1сѣ1
1ѡсѧ́
1ѡсꙋ1
ѡ1ти
ѡ1то1
ѡ1ты
ѡ1ті
ѡтї1
ѡ1тї1
ѡ1ф
1ѡ1ч
ѡчи́1
ѡ1ш
ѡ1і
ѡі́1
ѡ1ѧ
ѡѧ́1
ѡ1ѷ1
ѡ1ѷ1
8ѡ҆̀8.
8ѡ҆́8.
ѡ҆́1б
8ѡ҆̈8.
8ѡ҆̑8.
ѡ҆гꙋ1
ѡ҆до1
ѡ҆дꙋ1
ѡ҆1з2
ѡ҆за1
ѡ҆к2
ѡ҆ка1
ѡ҆1м
ѡ҆мо1
ѡ҆1п
ѡ҆па1
ѡ҆1р
ѡ҆ро1
ѡ҆1с2
ѡ҆сѣ1
ѡ҆1ч
8ѡⷠ.
8ѡⷠ҇.
8ѡⷡ.
8ѡⷡ҇.
8ѡⷢ.
8ѡⷢ҇.
8ѡⷣ.
8ѡⷣ҇.
8ѡⷤ.
8ѡⷤ҇.
8ѡⷥ.
8ѡⷥ҇.
8ѡⷦ.
8ѡⷦ҇.
8ѡⷧ.
8ѡⷧ҇.
8ѡⷨ.
8ѡⷨ҇.
8ѡⷩ.
8ѡⷩ҇.
8ѡⷪ.
8ѡⷪ҇.
8ѡⷫ.
8ѡⷫ҇.
8ѡⷬ.
8ѡⷬ҇.
8ѡⷭ.
8ѡⷭ҇.
8ѡⷮ.
8ѡⷮ҇.
8ѡⷯ.
8ѡⷯ҇.
8ѡⷰ.
8ѡⷰ҇.
8ѡⷱ.
8ѡⷱ҇.
8ѡⷲ.
8ѡⷲ҇.
8ѡⷳ.
8ѡⷳ҇.
8ѡⷴ.
8ѡⷴ҇.
8ѡⷵ.
8ѡⷵ҇.
8ѡⷶ.
8ѡⷶ҇.
8ѡⷷ.
8ѡⷷ҇.
8ѡⷸ.
8ѡⷸ҇.
8ѡⷹ.
8ѡⷹ҇.
8ѡⷺ.
8ѡⷺ҇.
8ѡⷻ.
8ѡⷻ҇.
8ѡⷼ.
8ѡⷼ҇.
8ѡⷽ.
8ѡⷽ҇.
8ѡⷾ.
8ѡⷾ҇.
8ѡⷿ.
8ѡⷿ҇.
8ѡꙴ.
8ѡꙴ҇.
8ѡꙵ.
8ѡꙵ҇.
8ѡꙶ.
8ѡꙶ҇.
8ѡꙷ.
8ѡꙷ҇.
8ѡꙸ.
8ѡꙸ҇.
8ѡꙹ.
8ѡꙹ҇.
8ѡꙺ.
8ѡꙺ҇.
8ѡꙻ.
8ѡꙻ҇.
8ѡ꙼.
8ѡ꙼҇.
8ѡ꙽.
8ѡ꙽҇.
2ѣ
8ѣ.
ѣ2̀
8ѣ̀8.
ѣ2́
8ѣ́8.
ѣ́ви1
ѣ́1вл
ѣ́в1ц
ѣ́1гд
ѣ́г1н
ѣ́до1
ѣ́дї1
ѣ́дї1
ѣ́дꙋ1
ѣ́жи1
ѣ́з2
ѣ́за1
ѣ́ка1
ѣ́ко1
ѣ́1кт
ѣ́ли1
ѣ́н1м
ѣ́пї1
ѣ́пї1
ѣ́ро1
ѣ́р1с
ѣ́рї1
ѣ́рї1
ѣ́с2
ѣ́со1
ѣ́та1
ѣ́1ц
ѣ́чи1
ѣ́ще1
ѣ́є1
8ѣ̈8.
ѣ2̑
8ѣ̑8.
ѣ̑1в
ѣ̑2п1
ѣ̑с2
ѣ̑1сн
ѣ̑ст1
ѣ̑ш1
ѣ1б
ѣбо2
ѣ1ва
ѣ1ви
ѣви́1
ѣ1в2н
ѣ2в1ц
ѣ1г2
ѣга́1
ѣго2
ѣ1да
ѣ1де2
ѣ2д1н
ѣдне1
ѣдню1
ѣ1до
ѣдо́1
ѣ1ды
ѣ1дї2
ѣ1дї2
ѣдѡ2
ѣ1дꙋ2
ѣ1е
ѣ1ж2
ѣже́1
ѣ2з1д
ѣ1з2р
ѣ1и
ѣй1
ѣ2й1
ѣ1к
ѣка2
ѣки́1
ѣ2к1н
ѣко́1
ѣкꙋ2
ѣ1ла2
ѣла́1
ѣ1ле
ѣле1с
ѣ1ли
ѣ1ло1
ѣло́1
ѣ1лє
ѣ1лѝ
ѣ1лѡ
ѣ1лѣ
ѣлѣ́1
ѣ1лѧ
ѣлѧ́1
ѣ1лꙋ2
ѣ1ма
ѣ1ме
ѣ1ми
ѣ1на2
ѣ1не2
ѣ1ни
ѣ1но2
ѣн1ц
ѣн1ч
ѣнї1
ѣнї1
ѣ1нѝ
ѣ1нѣ
ѣ1нѧ
ѣнѧ́1
ѣ1па2
ѣпа́1
ѣ1пи2
ѣ2п1л
ѣ1по2
ѣ1пі
ѣпі́1
ѣ1пѝ
ѣ1ре2
ѣ1ро1
ѣ1рє
ѣ1рѧ
ѣрѧ́1
ѣс2
ѣ1си
ѣ1сн
ѣ1со2
ѣ1сте
ѣ1сто1
ѣ1стѝ
ѣ1сѝ
ѣ1сѡ
ѣ1сѣ
ѣсѧ1
ѣ1та
ѣта́1
ѣ1те
ѣ1ти
ѣ2т1л
ѣ1то
ѣто1в
ѣто1л
ѣто1р
ѣ1тѐ
ѣ1ті
ѣ1тѝ
ѣ1тꙋ
ѣ1ха
ѣха́1
ѣ1хи
ѣ2х1м
ѣ1хо
ѣхꙋ2
ѣ1ц
ѣцѣ2
ѣче2
ѣ1чѐ
ѣ1ш
ѣша2
ѣше1м
ѣшє́1
ѣ1щ
ѣще1н
ѣщꙋ2
ѣ1ю1
ѣ1ѧ
8ѣ҆̀8.
8ѣ҆́8.
8ѣ҆̈8.
8ѣ҆̑8.
8ѣⷠ.
8ѣⷠ҇.
8ѣⷡ.
8ѣⷡ҇.
8ѣⷢ.
8ѣⷢ҇.
8ѣⷣ.
8ѣⷣ҇.
8ѣⷤ.
8ѣⷤ҇.
8ѣⷥ.
8ѣⷥ҇.
8ѣⷦ.
8ѣⷦ҇.
8ѣⷧ.
8ѣⷧ҇.
8ѣⷨ.
8ѣⷨ҇.
8ѣⷩ.
8ѣⷩ҇.
8ѣⷪ.
8ѣⷪ҇.
8ѣⷫ.
8ѣⷫ҇.
8ѣⷬ.
8ѣⷬ҇.
8ѣⷭ.
8ѣⷭ҇.
8ѣⷮ.
8ѣⷮ҇.
8ѣⷯ.
8ѣⷯ҇.
8ѣⷰ.
8ѣⷰ҇.
8ѣⷱ.
8ѣⷱ҇.
8ѣⷲ.
8ѣⷲ҇.
8ѣⷳ.
8ѣⷳ҇.
8ѣⷴ.
8ѣⷴ҇.
8ѣⷵ.
8ѣⷵ҇.
8ѣⷶ.
8ѣⷶ҇.
8ѣⷷ.
8ѣⷷ҇.
8ѣⷸ.
8ѣⷸ҇.
8ѣⷹ.
8ѣⷹ҇.
8ѣⷺ.
8ѣⷺ҇.
8ѣⷻ.
8ѣⷻ҇.
8ѣⷼ.
8ѣⷼ҇.
8ѣⷽ.
8ѣⷽ҇.
8ѣⷾ.
8ѣⷾ҇.
8ѣⷿ.
8ѣⷿ҇.
ѣ1ꙋ
ѣꙋ́1
8ѣꙴ.
8ѣꙴ҇.
8ѣꙵ.
8ѣꙵ҇.
8ѣꙶ.
8ѣꙶ҇.
8ѣꙷ.
8ѣꙷ҇.
8ѣꙸ.
8ѣꙸ҇.
8ѣꙹ.
8ѣꙹ҇.
8ѣꙺ.
8ѣꙺ҇.
8ѣꙻ.
8ѣꙻ҇.
8ѣ꙼.
8ѣ꙼҇.
8ѣ꙽.
8ѣ꙽҇.
8ѧ.
ѧ2̀
8ѧ̀8.
ѧ2́
8ѧ́8.
2ѧ́2б
1ѧ́в
ѧ́да1
ѧ́до1
1ѧ́з1в
ѧ́зл1
ѧ́ка1
1ѧ́ла
1ѧ́ли
1ѧ́н
ѧ́н1м
1ѧ́2р
1ѧ́са
ѧ́ти1
ѧ́то1
ѧ́т1ч
ѧ́тї1
ѧ́тї1
1ѧ́тѣ
1ѧ́хо
ѧ́1ц
ѧ́1ч
ѧ́че1
ѧ́1ш
ѧ́ша1
ѧ́ше1
1ѧ́ши
ѧ́1щ
8ѧ̈8.
ѧ2̑1
8ѧ̑8.
2ѧ̑2ж1
2ѧ̑з
2ѧ̑к
1ѧ̑н
2ѧ̑с2
1ѧ̑т
1ѧ̑ю
2ѧб
ѧба́1
ѧбе́1
ѧ2б1л
1ѧв
ѧ1ва
ѧва́1
ѧ1ви
ѧви́1
ѧв1ле
ѧв1с
ѧ1г
ѧги́1
ѧго1
ѧ1д
ѧда́1
1ѧдѐ
ѧдо1
1ѧдѐ
ѧдꙋ2
ѧдꙋ̑1
ѧ1е
ѧем1
ѧ1ж2
1ѧжд
2ѧза2
1ѧ2з1в
2ѧ1зе
1ѧ1зы2
2ѧзь
2ѧзє
2ѧ1зѧ
2ѧ1з2ꙋ
ѧзꙋ́1
1ѧ1и
ѧй1
ѧ2й1
1ѧйс
1ѧл1
ѧ1ми
1ѧмъ
1ѧ1на
ѧ1не2
ѧ1ни
ѧни́1
1ѧнн
ѧ1ны
ѧны́1
1ѧнї1
1ѧнї1
ѧ1нѝ
ѧ1нꙋ2
ѧ1р
ѧре2
ѧ1с2
1ѧса.
ѧса́1
2ѧсе2
1ѧсн
2ѧсо1
1ѧсъ
2ѧсѐ
1ѧсꙋ
ѧсꙋ́1
ѧ1та
ѧта́1
ѧта̑1
ѧ1те
ѧ1ти
ѧти̑1
ѧ2т1к
ѧт1н
ѧтна1
ѧ1то
2ѧтс
2ѧтъ
ѧ1ты
ѧть1
ѧ1ті
ѧті́1
ѧтї1
ѧ1тї1
ѧ1тѝ
ѧ1тѣ
ѧ1тꙋ
ѧ1ца
ѧца́1
ѧ1це1
ѧ1цы
ѧче́1
ѧче1с
ѧч1н
ѧ1ш
1ѧша1
ѧ1щ2
ѧща́1
ѧщен1
ѧщї1
ѧщї1
ѧщѧ1
ѧ1ю1
ѧюще1
ѧ1ѧ
ѧ҆̀1
8ѧ҆̀8.
8ѧ҆́8.
8ѧ҆̈8.
8ѧ҆̑8.
ѧ҆1з2
8ѧⷠ.
8ѧⷠ҇.
8ѧⷡ.
8ѧⷡ҇.
8ѧⷢ.
8ѧⷢ҇.
8ѧⷣ.
8ѧⷣ҇.
8ѧⷤ.
8ѧⷤ҇.
8ѧⷥ.
8ѧⷥ҇.
8ѧⷦ.
8ѧⷦ҇.
8ѧⷧ.
8ѧⷧ҇.
8ѧⷨ.
8ѧⷨ҇.
8ѧⷩ.
8ѧⷩ҇.
8ѧⷪ.
8ѧⷪ҇.
8ѧⷫ.
8ѧⷫ҇.
8ѧⷬ.
8ѧⷬ҇.
8ѧⷭ.
8ѧⷭ҇.
8ѧⷮ.
8ѧⷮ҇.
8ѧⷯ.
8ѧⷯ҇.
8ѧⷰ.
8ѧⷰ҇.
8ѧⷱ.
8ѧⷱ҇.
8ѧⷲ.
8ѧⷲ҇.
8ѧⷳ.
8ѧⷳ҇.
8ѧⷴ.
8ѧⷴ҇.
8ѧⷵ.
8ѧⷵ҇.
8ѧⷶ.
8ѧⷶ҇.
8ѧⷷ.
8ѧⷷ҇.
8ѧⷸ.
8ѧⷸ҇.
8ѧⷹ.
8ѧⷹ҇.
8ѧⷺ.
8ѧⷺ҇.
8ѧⷻ.
8ѧⷻ҇.
8ѧⷼ.
8ѧⷼ҇.
8ѧⷽ.
8ѧⷽ҇.
8ѧⷾ.
8ѧⷾ҇.
8ѧⷿ.
8ѧⷿ҇.
8ѧꙴ.
8ѧꙴ҇.
8ѧꙵ.
8ѧꙵ҇.
8ѧꙶ.
8ѧꙶ҇.
8ѧꙷ.
8ѧꙷ҇.
8ѧꙸ.
8ѧꙸ҇.
8ѧꙹ.
8ѧꙹ҇.
8ѧꙺ.
8ѧꙺ҇.
8ѧꙻ.
8ѧꙻ҇.
8ѧ꙼.
8ѧ꙼҇.
8ѧ꙽.
8ѧ꙽҇.
1ѯа
ѯа́1р
ѯакꙋ1
ѯа2н1
ѯапо1
1ѯе
ѯе1н
ѯено1
2ѯт
2ѯъ
1ѯі
ѯї1
1ѯї1
ѱ2
1ѱа
ѱа́2
ѱа́л1
1ѱі
ѱі́2
1ѱѡ
1ѱѵ
ѱѵ́1
ѳ2
1ѳа
ѳа1в
ѳа2г1
ѳа2д1
ѳа1л
ѳала1
ѳа1н
ѳа2ѵ1
1ѳе́ю
ѳеа1
1ѳе1м
ѳео́1
ѳе1р2
ѳера1
ѳеѡ2
ѳеѡ́1
1ѳи́1с
1ѳл
ѳле1
1ѳо
ѳо́1
ѳо2в
ѳо1л
ѳоло1
ѳо1н
1ѳр
ѳра2
1ѳс
ѳсї1
ѳсї1
2ѳъ
1ѳы
1ѳі́а
1ѳі́м
1ѳі́1с
1ѳї
ѳїс2
ѳїфа1
1ѳі̑1
1ѳї
ѳїс2
ѳїфа1
ѳѡ1
1ѳѧ1
1ѳѵ
ѳѵ́1м
ѳѷ1
ѳѷ1
1ѳꙋ
ѳꙋ́1
8ѵ.
8ѵ̀8.
ѵ2́
8ѵ́8.
2ѵ́м
ѵ́нї1
ѵ́нї1
ѵ́п2
ѵ́1пт
ѵ́1с
ѵ́те1
ѵ́1ф
8ѵ̈8.
ѷ1гд
ѷ1г2н
ѷ1е
ѷе́2
ѷе1л
ѷ1з
ѷза2
ѷзан1
ѷк2
ѷ1ка
ѷка1р
ѷ1ке
ѷке́1
ѷ1кт
ѷкто1
ѷ1л2
ѷла2
ѷлі́1
2ѷм
ѷм1в
ѷ1ме1
ѷ2м1п
ѷмпї1
ѷмпї1
ѷ1мї1
ѷ1мї1
ѷ1н
ѷна1
ѷно́1
ѷ1п2
1ѷпо1
2ѷпр
2ѷпі
ѷпі́1
ѷ1р
ѷри2
ѷро1
ѷрї1
ѷрї1
1ѷ1се2
2ѷ1со2
ѷсо́1
2ѷс1с
1ѷ1сє
ѷ1х
ѷхї1
ѷхї1
2ѷ1ѱ
ѵ̑1
8ѵ̑8.
ѵ̑р2
1ѵ2а
ѵа́2
ѵа́н1
ѵа1р
2ѵ1г
ѵге́1
2ѵ1д
ѵди1
ѵдо1
ѵдї1
ѵдї1
1ѵ2е2
1ѵ2и
ѵи1н
2ѵк2
ѵ1ка2
ѵ1кл
ѵ2кт
ѵ1кі
2ѵл
ѵ1ла
ѵ1ле
ѵ1ло2
ѵло́1
ѵ1лꙋ
2ѵ1м
ѵма́1
ѵме́1
2ѵ1н
ѵно2
ѵно́1
ѵнї1
ѵнї1
1ѵ2о
ѵо́2
2ѵ1п
ѵпра1
2ѵр2
ѵ1ра
ѵ1ре2
ѵ1ры
ѵ1рі
ѵрі́1
ѵрї1
ѵ1рї1
ѵ1рѡ
ѵрѡ́1
ѵ1рѣ
2ѵс2
ѵ1се
ѵсе́1
ѵст2
ѵ1стр
ѵсї1
ѵсї1
ѵсѷ1
ѵсѷ1
2ѵ1т
ѵті́1
ѵтѷ1
ѵтѷ1
2ѵ1ф
ѵфро1
2ѵ2ъ
1ѵы
1ѵі
ѵ2ї1
1ѵ2ї1
ѵ1ѯ
2ѵ1ѱ
2ѵ1ѳ
ѵѳа́1
ѵѳѵ́1
8ѵ҆̀8.
8ѵ҆́8.
8ѵ҆̈8.
8ѵ҆̑8.
ѵ҆а1
ѵ҆1п
ѵ҆пе1
ѵ҆по1
ѵ҆2с1
8ѵⷠ.
8ѵⷠ҇.
8ѵⷡ.
8ѵⷡ҇.
2ѵ2ⷢ
8ѵⷢ.
8ѵⷢ҇.
8ѵⷣ.
8ѵⷣ҇.
8ѵⷤ.
8ѵⷤ҇.
8ѵⷥ.
8ѵⷥ҇.
8ѵⷦ.
8ѵⷦ҇.
8ѵⷧ.
8ѵⷧ҇.
8ѵⷨ.
8ѵⷨ҇.
8ѵⷩ.
8ѵⷩ҇.
8ѵⷪ.
8ѵⷪ҇.
8ѵⷫ.
8ѵⷫ҇.
8ѵⷬ.
8ѵⷬ҇.
8ѵⷭ.
8ѵⷭ҇.
8ѵⷮ.
8ѵⷮ҇.
8ѵⷯ.
8ѵⷯ҇.
8ѵⷰ.
8ѵⷰ҇.
8ѵⷱ.
8ѵⷱ҇.
8ѵⷲ.
8ѵⷲ҇.
8ѵⷳ.
8ѵⷳ҇.
8ѵⷴ.
8ѵⷴ҇.
8ѵⷵ.
8ѵⷵ҇.
8ѵⷶ.
8ѵⷶ҇.
8ѵⷷ.
8ѵⷷ҇.
8ѵⷸ.
8ѵⷸ҇.
8ѵⷹ.
8ѵⷹ҇.
8ѵⷺ.
8ѵⷺ҇.
8ѵⷻ.
8ѵⷻ҇.
8ѵⷼ.
8ѵⷼ҇.
8ѵⷽ.
8ѵⷽ҇.
8ѵⷾ.
8ѵⷾ҇.
8ѵⷿ.
8ѵⷿ҇.
1ѵ2ꙋ
8ѵꙴ.
8ѵꙴ҇.
8ѵꙵ.
8ѵꙵ҇.
8ѵꙶ.
8ѵꙶ҇.
8ѵꙷ.
8ѵꙷ҇.
8ѵꙸ.
8ѵꙸ҇.
8ѵꙹ.
8ѵꙹ҇.
8ѵꙺ.
8ѵꙺ҇.
8ѵꙻ.
8ѵꙻ҇.
8ѵ꙼.
8ѵ꙼҇.
8ѵ꙽.
8ѵ꙽҇.
ѷ1гд
ѷ1г2н
ѷ1е
ѷе́2
ѷе1л
ѷ1з
ѷза2
ѷзан1
ѷк2
ѷ1ка
ѷка1р
ѷ1ке
ѷке́1
ѷ1кт
ѷкто1
ѷ1л2
ѷла2
ѷлі́1
2ѷм
ѷм1в
ѷ1ме1
ѷ2м1п
ѷмпї1
ѷмпї1
ѷ1мї1
ѷ1мї1
ѷ1н
ѷна1
ѷно́1
ѷ1п2
1ѷпо1
2ѷпр
2ѷпі
ѷпі́1
ѷ1р
ѷри2
ѷро1
ѷрї1
ѷрї1
1ѷ1се2
2ѷ1со2
ѷсо́1
2ѷс1с
1ѷ1сє
ѷ1х
ѷхї1
ѷхї1
2ѷ1ѱ
8ѹ.
8ѹ̀8.
8ѹ́8.
8ѹ̈8.
8ѹ̑8.
1ѹ1х
1ѹ҆
ѹ҆̀1
8ѹ҆̀8.
8ѹ҆́8.
ѹ҆́1б
ѹ҆́1н
ѹ҆́1х
ѹ҆́1ч
8ѹ҆̈8.
8ѹ҆̑8.
ѹ҆1б2
ѹ҆1в2
ѹ҆г2
ѹ҆га1
ѹ҆1з2
ѹ҆ко1
ѹ҆1л
ѹ҆1м2
ѹ҆не1
ѹ҆ни1
ѹ҆1п
ѹ҆по1
ѹ҆с2
ѹ҆1ск
ѹ҆1сп
ѹ҆т2
ѹ҆та1
ѹ҆то1
8ѹⷠ.
8ѹⷠ҇.
8ѹⷡ.
8ѹⷡ҇.
8ѹⷢ.
8ѹⷢ҇.
8ѹⷣ.
8ѹⷣ҇.
8ѹⷤ.
8ѹⷤ҇.
8ѹⷥ.
8ѹⷥ҇.
8ѹⷦ.
8ѹⷦ҇.
8ѹⷧ.
8ѹⷧ҇.
8ѹⷨ.
8ѹⷨ҇.
8ѹⷩ.
8ѹⷩ҇.
8ѹⷪ.
8ѹⷪ҇.
8ѹⷫ.
8ѹⷫ҇.
8ѹⷬ.
8ѹⷬ҇.
8ѹⷭ.
8ѹⷭ҇.
8ѹⷮ.
8ѹⷮ҇.
8ѹⷯ.
8ѹⷯ҇.
8ѹⷰ.
8ѹⷰ҇.
8ѹⷱ.
8ѹⷱ҇.
8ѹⷲ.
8ѹⷲ҇.
8ѹⷳ.
8ѹⷳ҇.
8ѹⷴ.
8ѹⷴ҇.
8ѹⷵ.
8ѹⷵ҇.
8ѹⷶ.
8ѹⷶ҇.
8ѹⷷ.
8ѹⷷ҇.
8ѹⷸ.
8ѹⷸ҇.
8ѹⷹ.
8ѹⷹ҇.
8ѹⷺ.
8ѹⷺ҇.
8ѹⷻ.
8ѹⷻ҇.
8ѹⷼ.
8ѹⷼ҇.
8ѹⷽ.
8ѹⷽ҇.
8ѹⷾ.
8ѹⷾ҇.
8ѹⷿ.
8ѹⷿ҇.
8ѹꙴ.
8ѹꙴ҇.
8ѹꙵ.
8ѹꙵ҇.
8ѹꙶ.
8ѹꙶ҇.
8ѹꙷ.
8ѹꙷ҇.
8ѹꙸ.
8ѹꙸ҇.
8ѹꙹ.
8ѹꙹ҇.
8ѹꙺ.
8ѹꙺ҇.
8ѹꙻ.
8ѹꙻ҇.
8ѹ꙼.
8ѹ꙼҇.
8ѹ꙽.
8ѹ꙽҇.
8ѻ.
8ѻ̀8.
8ѻ́8.
8ѻ̈8.
8ѻ̑8.
1ѻ1б
ѻбо1
1ѻ1г2
ѻгне1
1ѻ1к
ѻке1
1ѻ1н
ѻнꙋ2
ѻнꙋ́1
ѻр1д2
1ѻ1рꙋ2
ѻрꙋ́1
1ѻ1т2
ѻте2
ѻтро1
1ѻ2ц
8ѻ҆̀8.
8ѻ҆́8.
8ѻ҆̈8.
8ѻ҆̑8.
ѻ҆бо1
ѻ҆б1р
ѻ҆1в2
ѻ҆г2
ѻ҆ди1
ѻ҆1з2
ѻ҆к2
ѻ҆ка1
ѻ҆1н
ѻ҆1п
ѻ҆1с2
ѻ҆т2
8ѻⷠ.
8ѻⷠ҇.
8ѻⷡ.
8ѻⷡ҇.
8ѻⷢ.
8ѻⷢ҇.
8ѻⷣ.
8ѻⷣ҇.
8ѻⷤ.
8ѻⷤ҇.
8ѻⷥ.
8ѻⷥ҇.
8ѻⷦ.
8ѻⷦ҇.
8ѻⷧ.
8ѻⷧ҇.
8ѻⷨ.
8ѻⷨ҇.
8ѻⷩ.
8ѻⷩ҇.
8ѻⷪ.
8ѻⷪ҇.
8ѻⷫ.
8ѻⷫ҇.
8ѻⷬ.
8ѻⷬ҇.
8ѻⷭ.
8ѻⷭ҇.
8ѻⷮ.
8ѻⷮ҇.
8ѻⷯ.
8ѻⷯ҇.
8ѻⷰ.
8ѻⷰ҇.
8ѻⷱ.
8ѻⷱ҇.
8ѻⷲ.
8ѻⷲ҇.
8ѻⷳ.
8ѻⷳ҇.
8ѻⷴ.
8ѻⷴ҇.
8ѻⷵ.
8ѻⷵ҇.
8ѻⷶ.
8ѻⷶ҇.
8ѻⷷ.
8ѻⷷ҇.
8ѻⷸ.
8ѻⷸ҇.
8ѻⷹ.
8ѻⷹ҇.
8ѻⷺ.
8ѻⷺ҇.
8ѻⷻ.
8ѻⷻ҇.
8ѻⷼ.
8ѻⷼ҇.
8ѻⷽ.
8ѻⷽ҇.
8ѻⷾ.
8ѻⷾ҇.
8ѻⷿ.
8ѻⷿ҇.
8ѻꙴ.
8ѻꙴ҇.
8ѻꙵ.
8ѻꙵ҇.
8ѻꙶ.
8ѻꙶ҇.
8ѻꙷ.
8ѻꙷ҇.
8ѻꙸ.
8ѻꙸ҇.
8ѻꙹ.
8ѻꙹ҇.
8ѻꙺ.
8ѻꙺ҇.
8ѻꙻ.
8ѻꙻ҇.
8ѻ꙼.
8ѻ꙼҇.
8ѻ꙽.
8ѻ꙽҇.
8ѽ8.
8ѽ̀8.
8ѽ́8.
8ѽ̈8.
8ѽ̑8.
ѽ1л
8ѽ҆̀8.
8ѽ҆́8.
8ѽ҆̈8.
8ѽ҆̑8.
8ѽⷠ.
8ѽⷠ҇.
8ѽⷡ.
8ѽⷡ҇.
8ѽⷢ.
8ѽⷢ҇.
8ѽⷣ.
8ѽⷣ҇.
8ѽⷤ.
8ѽⷤ҇.
8ѽⷥ.
8ѽⷥ҇.
8ѽⷦ.
8ѽⷦ҇.
8ѽⷧ.
8ѽⷧ҇.
8ѽⷨ.
8ѽⷨ҇.
8ѽⷩ.
8ѽⷩ҇.
8ѽⷪ.
8ѽⷪ҇.
8ѽⷫ.
8ѽⷫ҇.
8ѽⷬ.
8ѽⷬ҇.
8ѽⷭ.
8ѽⷭ҇.
8ѽⷮ.
8ѽⷮ҇.
8ѽⷯ.
8ѽⷯ҇.
8ѽⷰ.
8ѽⷰ҇.
8ѽⷱ.
8ѽⷱ҇.
8ѽⷲ.
8ѽⷲ҇.
8ѽⷳ.
8ѽⷳ҇.
8ѽⷴ.
8ѽⷴ҇.
8ѽⷵ.
8ѽⷵ҇.
8ѽⷶ.
8ѽⷶ҇.
8ѽⷷ.
8ѽⷷ҇.
8ѽⷸ.
8ѽⷸ҇.
8ѽⷹ.
8ѽⷹ҇.
8ѽⷺ.
8ѽⷺ҇.
8ѽⷻ.
8ѽⷻ҇.
8ѽⷼ.
8ѽⷼ҇.
8ѽⷽ.
8ѽⷽ҇.
8ѽⷾ.
8ѽⷾ҇.
8ѽⷿ.
8ѽⷿ҇.
8ѽꙴ.
8ѽꙴ҇.
8ѽꙵ.
8ѽꙵ҇.
8ѽꙶ.
8ѽꙶ҇.
8ѽꙷ.
8ѽꙷ҇.
8ѽꙸ.
8ѽꙸ҇.
8ѽꙹ.
8ѽꙹ҇.
8ѽꙺ.
8ѽꙺ҇.
8ѽꙻ.
8ѽꙻ҇.
8ѽ꙼.
8ѽ꙼҇.
8ѽ꙽.
8ѽ꙽҇.
8ѿ.
8ѿ̀8.
8ѿ́8.
8ѿ̈8.
8ѿ̑8.
ѿ1б
ѿбѣ1
ѿ1в2
ѿва1л
ѿвер1
ѿвра1
ѿ1г2
ѿго́1
ѿ1д
1ѿ1е
ѿе́2
ѿе́м1
ѿ1ж
ѿже1
ѿ1и
ѿи́1
ѿи1м
ѿи1т
ѿ1к
ѿкро1
ѿкꙋ2
ѿкꙋ́1
ѿ1л2
ѿлꙋ1
ѿ1м2
ѿме1
ѿмы1
ѿ1н2
ѿне2
ѿне́1
ѿню2
ѿ1п
ѿпа1
ѿ1р
ѿра́1
ѿра1с
ѿре1
ѿри2
ѿри́1
1ѿ1с
ѿсе2
ѿсе́1
ѿсто1
ѿ1т2
ѿто2
ѿто́1
ѿтꙋ́1
ѿ1х
ѿхо́1
ѿ1ч
ѿча́1
ѿча̑1
ѿчꙋ1
ѿ1ш
ѿше2
ѿ1ѧ
ѿ1ѻ1
8ѿ҆̀8.
8ѿ҆́8.
8ѿ҆̈8.
8ѿ҆̑8.
8ѿⷠ.
8ѿⷠ҇.
8ѿⷡ.
8ѿⷡ҇.
8ѿⷢ.
8ѿⷢ҇.
8ѿⷣ.
8ѿⷣ҇.
8ѿⷤ.
8ѿⷤ҇.
8ѿⷥ.
8ѿⷥ҇.
8ѿⷦ.
8ѿⷦ҇.
8ѿⷧ.
8ѿⷧ҇.
8ѿⷨ.
8ѿⷨ҇.
8ѿⷩ.
8ѿⷩ҇.
8ѿⷪ.
8ѿⷪ҇.
8ѿⷫ.
8ѿⷫ҇.
8ѿⷬ.
8ѿⷬ҇.
8ѿⷭ.
8ѿⷭ҇.
8ѿⷮ.
8ѿⷮ҇.
8ѿⷯ.
8ѿⷯ҇.
8ѿⷰ.
8ѿⷰ҇.
8ѿⷱ.
8ѿⷱ҇.
8ѿⷲ.
8ѿⷲ҇.
8ѿⷳ.
8ѿⷳ҇.
8ѿⷴ.
8ѿⷴ҇.
8ѿⷵ.
8ѿⷵ҇.
8ѿⷶ.
8ѿⷶ҇.
8ѿⷷ.
8ѿⷷ҇.
8ѿⷸ.
8ѿⷸ҇.
8ѿⷹ.
8ѿⷹ҇.
8ѿⷺ.
8ѿⷺ҇.
8ѿⷻ.
8ѿⷻ҇.
8ѿⷼ.
8ѿⷼ҇.
8ѿⷽ.
8ѿⷽ҇.
8ѿⷾ.
8ѿⷾ҇.
8ѿⷿ.
8ѿⷿ҇.
8ѿꙴ.
8ѿꙴ҇.
8ѿꙵ.
8ѿꙵ҇.
8ѿꙶ.
8ѿꙶ҇.
8ѿꙷ.
8ѿꙷ҇.
8ѿꙸ.
8ѿꙸ҇.
8ѿꙹ.
8ѿꙹ҇.
8ѿꙺ.
8ѿꙺ҇.
8ѿꙻ.
8ѿꙻ҇.
8ѿ꙼.
8ѿ꙼҇.
8ѿ꙽.
8ѿ꙽҇.
8҃
҃а́1
҃а̑1
҃а1в
҃а2л
҃а1т
҃а2х
҃га́1
҃го1
҃д2
҃е́1с
҃ен1
҃ер1
҃е1с
҃з2
҃и2
҃и́1в
҃и́1с
҃и́1ц
҃и́1ч
҃к2
҃л2
҃ло2
҃лє1
҃н2
҃не2
҃неч1
҃нї1
҃нї1
҃о́в1
҃о1в2
҃о1з2
҃оиз1
҃о1л
҃олю1
҃о1н
҃она1
҃оне1
҃о1р
҃о1с
҃оѧв1
҃оꙋ1
҃р2
҃ре2
҃рне1
҃рни1
҃рї1
҃рї1
҃с2
҃се2
҃ст2
҃сѡ1
҃т2
҃тво1
҃ше2
҃ше́1
҃ща́1
҃ще́1
҃ы́1н
҃є́2
҃є́н1
҃і́1
҃ѣ́2
҃ꙋ́1
8҆
҆2̀
҆2́
҆́б2
҆́1бл
҆́1бр
҆́ва1
҆́ве1
҆́во1
҆́1вц
҆́вї1
҆́вї1
҆́г2
҆́1гц
҆́дї1
҆́дї1
҆́з1д
҆́зе1
҆́з1н
҆́1зр
҆́и1
҆́1к
҆́2л
҆́л1ч
҆́мо1
҆́мѧ1
҆́на1
҆́н1д
҆́ни1
҆́нѡ1
҆́нꙋ1
҆́р1т
҆́с2
҆́1ск
҆́1сн
҆́1сп
҆́1т
҆́2ц1
҆́1ш
҆́1щ2
҆́ю1
҆2̑
҆1а
҆а́1к
҆а̑1
҆а1д
҆а2м1
҆анꙋ1
҆а1р2
҆ба́1
҆2б1в
҆2б1д
҆би1т
҆бла1
҆бли1
҆б1н
҆бни1
҆бол1
҆бре1
҆б1рꙋ
҆1бщ
҆бѡ́1
҆в1в
҆вва1
҆1в2д
҆1ве
҆ве1н
҆1ви
҆2в1л
҆1в2н
҆1во1
҆1в2ц
҆1в2ч
҆1вы
҆вї1
҆1вї1
҆1вѝ
҆1вѣ
҆вѣ1р
҆1вѧ
҆1вѵ
҆1вꙋ1
҆1г
҆г2г
҆г2л
҆глѣ1
҆г2н
҆гор1
҆гро1
҆1д2
҆дав1
҆да1л
҆до1л
҆дє́1
҆дї1
҆дї1
҆дѡ1л
҆дѣ́1
҆дѣ1в
҆дꙋ́1
҆1е
҆е1з2
҆езе1
҆ер2
҆еро1
҆ерꙋ1
҆е2с
҆1ж2
҆жи́1
҆з̾ꙋ1
҆з1в
҆зви1
҆з1да1
҆1зе1
҆зже1
҆1зи
҆зи́1
҆з1л
҆зли1
҆змо1
҆з1н2
҆зне1
҆знꙋ1
҆зо2
҆з1ра
҆з1ре1
҆з1ри1
҆з1рѧ
҆зсꙋ1
҆1зы
҆зі́1
҆1и1с
҆1к
҆ка1л
҆ке1
҆кле1
҆кло1
҆ко1в
҆кро1
҆крꙋ1
҆кте1
҆кї2
҆кї2
҆кѵ́1
҆кѷ1
҆кѷ1
҆1ла
҆ла́1
҆ла1р
҆л1в2
҆лве1
҆1ле
҆лез1
҆леѵ1
҆1ли
҆ли́1
҆ли̑1
҆л1м
҆лма1
҆1ло
҆л1п
҆1лі
҆лїи1
҆лїо1
҆1лї
҆лїи1
҆лїо1
҆1лѝ
҆лѷ2
҆1лѷ2
҆1лꙋ1
҆1ма
҆м1в
҆1ме
҆ме1н
҆1ми
҆1мл
҆1м2н
҆1мо
҆мо1в
҆мо1н
҆1м2п
҆мпе1
҆мра1
҆1мы
҆1мї1
҆1мї1
҆1мѣ
҆мѣ̑1
҆1мѧ2
҆мѧ́1
҆мꙋ́1
҆1на
҆на́1
҆н1д
҆1не
҆нем1
҆1ни
҆ни́1
҆ни1с
҆1но
҆н1т
҆нтї1
҆нтї1
҆н1ц
҆1ны
҆1ні
҆ні́1
҆нї1
҆нї1
҆1нѝ
҆1нѣ
҆н1ѳ
҆нѵ́1
҆1нꙋ2
҆нꙋ́1
҆п2
҆1па
҆па1с
҆1пе
҆пе1р
҆1пи2
҆пи́1
҆1пл
҆пле1
҆1по
҆по́1
҆пол1
҆по1р
҆поѧ1
҆про1
҆прѣ1
҆1пі
҆пі́1
҆пї1
҆пї1
҆1пѡ
҆1пꙋ1
҆1ра
҆ра1в
҆ра1з
҆р1г2
҆р1д
҆рда1
҆1ре
҆ре1т
҆1ри
҆р1к
҆р1м2
҆1ро
҆р1п
҆рпа1
҆р1с
҆р1т
҆р1х
҆1рї1
҆1рї1
҆1рѡ1
҆1рѧ
҆рѧ́1
҆1рꙋ2
҆1са
҆свѣ1
҆свѧ1
҆1се2
҆1си
҆ски1
҆1скл
҆с2л
҆1см
҆смо1
҆1с2н
҆1со2
҆1спа
҆1спи
҆с1по
҆1спѣ1
҆с1пꙋ
҆с1с
҆с1тл
҆с1то
҆стꙋ1
҆2с1х
҆2с1ц
҆сцѣ1
҆1сы1
҆сі́1
҆сї1
҆сї1
҆1сѝ
҆1сѣ
҆сѣ́1
҆сѣк1
҆сѣ1н
҆сѷ2
҆сѷг1
҆сѷ2
҆сѷг1
҆сꙋ́1
҆сꙋ1д
҆1т
҆та́1
҆ти́1
҆т2л
҆то́1
҆то1л
҆т2ц
҆2т1ч
҆тѣ́1
҆фе́1
҆фрї1
҆фрї1
҆1фі
҆1х
҆ха́1
҆хі́1
҆2ц
҆ч2
҆ча́1
҆че1н
҆че1с
҆чи1с
҆чре1
҆2чт
҆чє́1
҆1чꙋ1
҆1ш
҆ше1
҆ши́1
҆шꙋ2
҆шꙋ́1
҆1щ
҆ще́1
҆щѧ2
҆1ю
҆1є
҆є́1
҆1ѕ
҆1ї1
҆1ї1
҆1ѡ
҆ѡ́1
҆ѡ1н
҆ѡна1
҆ѡ1р
҆ѡ1с
҆1ѧ
҆ѧ́1ж
҆ѧ́з1
҆ѧ2з1
҆1ѯ
҆ѯа1
҆1ѳ
҆ѳа1
҆ѵ1к
҆ѵ1л
҆ѵ1р
҆ѵрѡ1
҆ѵ1с
҆1ѻ
҆ѻр1
҆1ꙋ́
҆ꙋ́1д
҆ꙋ́1л
҆ꙋ́1н
҆1ꙋ̑1
҆1ꙋ1в
҆1ꙋ1д
҆1ꙋ1л
҆1ꙋс
8҇
҇а1
҇е1в
҇и́1
҇к2
҇ко2
҇л2
҇лі́1
҇лї1
҇лї1
҇н2
҇на́1
҇но́1
҇но1м
҇нї1
҇нї1
҇нꙋ1
҇о1
҇р2
҇рди1
҇рдї1
҇рдї1
҇ро2
҇ро́1
҇т2
҇ти́1
҇то1в
҇тои1
҇то1м
҇ть1
҇тї1
҇тї1
҇тѡ́1
҇ч2
҇че1с
҇ш2
҇ша1
҇ше1
҇ь1
҇ї1
҇ї1
҇ꙋ1
8ӓ8.
8ӥ8.
8ӧ8.
8ӭ8.
8ӱ8.
8ӹ8.
8ᲂ.
8ᲂ̀8.
8ᲂ́8.
8ᲂ̈8.
8ᲂ̑8.
ᲂ8у
8ᲂу.
8ᲂу̀.
8ᲂу́.
8ᲂӱ8.
8ᲂу̑.
1ᲂу1х
1ᲂу҆
ᲂу҆̀1
8ᲂу҆̀.
8ᲂу҆́.
ᲂу҆́1б
ᲂу҆́1н
ᲂу҆́1х
ᲂу҆́1ч
8ᲂу҆̈.
8ᲂу҆̑.
ᲂу҆1б2
ᲂу҆1в2
ᲂу҆г2
ᲂу҆га1
ᲂу҆1з2
ᲂу҆ко1
ᲂу҆1л
ᲂу҆1м2
ᲂу҆не1
ᲂу҆ни1
ᲂу҆1п
ᲂу҆по1
ᲂу҆с2
ᲂу҆1ск
ᲂу҆1сп
ᲂу҆т2
ᲂу҆та1
ᲂу҆то1
8ᲂуⷠ.
8ᲂуⷠ҇.
8ᲂуⷡ.
8ᲂуⷡ҇.
8ᲂуⷢ.
8ᲂуⷢ҇.
8ᲂуⷣ.
8ᲂуⷣ҇.
8ᲂуⷤ.
8ᲂуⷤ҇.
8ᲂуⷥ.
8ᲂуⷥ҇.
8ᲂуⷦ.
8ᲂуⷦ҇.
8ᲂуⷧ.
8ᲂуⷧ҇.
8ᲂуⷨ.
8ᲂуⷨ҇.
8ᲂуⷩ.
8ᲂуⷩ҇.
8ᲂуⷪ.
8ᲂуⷪ҇.
8ᲂуⷫ.
8ᲂуⷫ҇.
8ᲂуⷬ.
8ᲂуⷬ҇.
8ᲂуⷭ.
8ᲂуⷭ҇.
8ᲂуⷮ.
8ᲂуⷮ҇.
8ᲂуⷯ.
8ᲂуⷯ҇.
8ᲂуⷰ.
8ᲂуⷰ҇.
8ᲂуⷱ.
8ᲂуⷱ҇.
8ᲂуⷲ.
8ᲂуⷲ҇.
8ᲂуⷳ.
8ᲂуⷳ҇.
8ᲂуⷴ.
8ᲂуⷴ҇.
8ᲂуⷵ.
8ᲂуⷵ҇.
8ᲂуⷶ.
8ᲂуⷶ҇.
8ᲂуⷷ.
8ᲂуⷷ҇.
8ᲂуⷸ.
8ᲂуⷸ҇.
8ᲂуⷹ.
8ᲂуⷹ҇.
8ᲂуⷺ.
8ᲂуⷺ҇.
8ᲂуⷻ.
8ᲂуⷻ҇.
8ᲂуⷼ.
8ᲂуⷼ҇.
8ᲂуⷽ.
8ᲂуⷽ҇.
8ᲂуⷾ.
8ᲂуⷾ҇.
8ᲂуⷿ.
8ᲂуⷿ҇.
8ᲂуꙴ.
8ᲂуꙴ҇.
8ᲂуꙵ.
8ᲂуꙵ҇.
8ᲂуꙶ.
8ᲂуꙶ҇.
8ᲂуꙷ.
8ᲂуꙷ҇.
8ᲂуꙸ.
8ᲂуꙸ҇.
8ᲂуꙹ.
8ᲂуꙹ҇.
8ᲂуꙺ.
8ᲂуꙺ҇.
8ᲂуꙻ.
8ᲂуꙻ҇.
8ᲂу꙼.
8ᲂу꙼҇.
8ᲂу꙽.
8ᲂу꙽҇.
8ᲂ҆̀8.
8ᲂ҆́8.
8ᲂ҆̈8.
8ᲂ҆̑8.
8ᲂⷠ.
8ᲂⷠ҇.
8ᲂⷡ.
8ᲂⷡ҇.
8ᲂⷢ.
8ᲂⷢ҇.
8ᲂⷣ.
8ᲂⷣ҇.
8ᲂⷤ.
8ᲂⷤ҇.
8ᲂⷥ.
8ᲂⷥ҇.
8ᲂⷦ.
8ᲂⷦ҇.
8ᲂⷧ.
8ᲂⷧ҇.
8ᲂⷨ.
8ᲂⷨ҇.
8ᲂⷩ.
8ᲂⷩ҇.
8ᲂⷪ.
8ᲂⷪ҇.
8ᲂⷫ.
8ᲂⷫ҇.
8ᲂⷬ.
8ᲂⷬ҇.
8ᲂⷭ.
8ᲂⷭ҇.
8ᲂⷮ.
8ᲂⷮ҇.
8ᲂⷯ.
8ᲂⷯ҇.
8ᲂⷰ.
8ᲂⷰ҇.
8ᲂⷱ.
8ᲂⷱ҇.
8ᲂⷲ.
8ᲂⷲ҇.
8ᲂⷳ.
8ᲂⷳ҇.
8ᲂⷴ.
8ᲂⷴ҇.
8ᲂⷵ.
8ᲂⷵ҇.
8ᲂⷶ.
8ᲂⷶ҇.
8ᲂⷷ.
8ᲂⷷ҇.
8ᲂⷸ.
8ᲂⷸ҇.
8ᲂⷹ.
8ᲂⷹ҇.
8ᲂⷺ.
8ᲂⷺ҇.
8ᲂⷻ.
8ᲂⷻ҇.
8ᲂⷼ.
8ᲂⷼ҇.
8ᲂⷽ.
8ᲂⷽ҇.
8ᲂⷾ.
8ᲂⷾ҇.
8ᲂⷿ.
8ᲂⷿ҇.
8ᲂꙴ.
8ᲂꙴ҇.
8ᲂꙵ.
8ᲂꙵ҇.
8ᲂꙶ.
8ᲂꙶ҇.
8ᲂꙷ.
8ᲂꙷ҇.
8ᲂꙸ.
8ᲂꙸ҇.
8ᲂꙹ.
8ᲂꙹ҇.
8ᲂꙺ.
8ᲂꙺ҇.
8ᲂꙻ.
8ᲂꙻ҇.
8ᲂ꙼.
8ᲂ꙼҇.
8ᲂ꙽.
8ᲂ꙽҇.
8ᲆ
8ⷠ
8ⷡ
8ⷢ
ⷢї1
ⷢї1
ⷢ҇2
8ⷣ
ⷣб2
ⷣбно1
ⷣн2
ⷣна1
ⷣне2
ⷣнї1
ⷣнї1
ⷣте́1
ⷣтї1
ⷣтї1
ⷣц2
ⷣце2
ⷣч2
8ⷤ
8ⷥ
8ⷦ
8ⷧ
ⷧ҇2
8ⷨ
8ⷩ
8ⷪ
ⷪ҇2
8ⷫ
8ⷬ
8ⷭ
ⷭ҇2
8ⷮ
8ⷯ
8ⷰ
8ⷱ
8ⷲ
8ⷳ
8ⷴ
8ⷵ
8ⷶ
8ⷷ
8ⷸ
8ⷹ
8ⷺ
8ⷻ
8ⷼ
8ⷽ
8ⷾ
8ⷿ
8ⸯ
8ꙋ.
2ꙋ2̀
8ꙋ̀8.
ꙋ2́
8ꙋ́8.
ꙋ́бо1
2ꙋ́в
ꙋ́гꙋ1
2ꙋ́е
2ꙋ́ж
ꙋ́жї1
ꙋ́жї1
1ꙋ́зъ
ꙋ́ко1
1ꙋ́лї
1ꙋ́лї
1ꙋ́лꙋ
1ꙋ́мн
1ꙋ́мї1
1ꙋ́мї1
1ꙋ́нї
1ꙋ́нї
ꙋ́нѧ1
2ꙋ́п
ꙋ́ре1
ꙋ́рж1
ꙋ́р1т
ꙋ́с1с
ꙋ́ф2
2ꙋ́х
ꙋ́1ц
ꙋ́ча1
ꙋ́че1
1ꙋ́чи
ꙋ́ше1
ꙋ́щꙋ1
2ꙋ́ю
ꙋ́ї1
ꙋ́ї1
2ꙋ́ѧ
2ꙋ́ѳ
8ꙋ̈8.
ꙋ2̑
8ꙋ̑8.
ꙋ̑1б
ꙋ̑2в1
1ꙋ̑ди
ꙋ̑1к
1ꙋ̑мн
ꙋ̑2н1
ꙋ̑2с1
2ꙋ1а
ꙋа́1
ꙋба́1
ꙋби1н
ꙋб1лю
ꙋб1н
ꙋбны1
ꙋбнꙋ1
ꙋбо́1
ꙋ1бр
2ꙋбы
1ꙋбі
2ꙋбѡ
1ꙋ1ве
2ꙋ1ви
ꙋвше1
ꙋ1вы
2ꙋві
1ꙋ1вѣ
1ꙋ1вѧ
ꙋ1г2
ꙋга́1
1ꙋгас
1ꙋгот
ꙋ1да
ꙋда́1
ꙋ1де
ꙋден1
ꙋ2д1н
ꙋ1до
1ꙋдоб
ꙋдо1л
ꙋ1д2р
ꙋдро1
ꙋ1ды
1ꙋ1дє
ꙋ1ді
ꙋдї1
ꙋ1дї1
ꙋ1дѣ
ꙋдѣ1в
ꙋ1дꙋ2
2ꙋ1е
ꙋе́1
ꙋемо1
ꙋете1
ꙋ1ж2
ꙋ2з1д
ꙋ1зи
ꙋ2з1н
ꙋзі́1
ꙋ1и
ꙋи́2
ꙋй1
ꙋи2м
ꙋ2й1
ꙋ1к2
ꙋка2
1ꙋказ
ꙋка7за́
1ꙋкло
1ꙋклѡ
2ꙋко
ꙋко1в
ꙋко1н
ꙋко1с
1ꙋкр
ꙋкра1
ꙋкі́1
ꙋкꙋ2
ꙋл1в
ꙋ1ле
ꙋле́1
1ꙋ1лї1
1ꙋ1лї1
ꙋ1м
1ꙋма
1ꙋмев
2ꙋми
2ꙋ2м1л
2ꙋм2н
1ꙋмо2
1ꙋмъ
1ꙋмы.
2ꙋмі
ꙋмі́1
2ꙋмѝ
1ꙋмѡ
1ꙋмѣ.
1ꙋмѣ̑1
1ꙋмѣв
2ꙋмѧ2
1ꙋмꙋ
ꙋ1н
ꙋна2
ꙋно2
ꙋ1п2
ꙋпа2
ꙋпа́1
ꙋпо1
ꙋр1в
ꙋр1г
ꙋ1ре1
ꙋ1ри2
ꙋ1ро2
ꙋров1
ꙋр1т
ꙋ1с2
2ꙋса1
1ꙋсо́
ꙋсо1м
ꙋсто1
1ꙋстї
1ꙋстї
ꙋстѡ1
1ꙋсы
ꙋсї1
ꙋсї1
2ꙋ1те
ꙋ1ти
2ꙋтѝ
1ꙋтр
ꙋ1тро
ꙋ1трꙋ1
2ꙋтс
2ꙋтъ
2ꙋть
2ꙋ1ті
ꙋтї1
2ꙋ1тї1
2ꙋ1тѝ
ꙋ1ф
1ꙋ1ха
ꙋха́1
ꙋх1н
ꙋ1хо
ꙋ1ц
ꙋцѣ1л
ꙋ1ч
ꙋче1н
ꙋчє́1
ꙋчꙋ2
ꙋ1ш
ꙋша2
ꙋше1т
2ꙋши
ꙋ2ш1л
ꙋшꙋ2
ꙋ1щ2
ꙋща́1
ꙋще́1
ꙋщє1
ꙋщї1
ꙋщї1
ꙋщѧ1
ꙋщꙋ1
2ꙋ1ю
ꙋ1і
ꙋі́2
ꙋ1ѧ
ꙋѧ́1м
8ꙋ҆̀8.
8ꙋ҆́8.
8ꙋ҆̈8.
8ꙋ҆̑8.
8ꙋⷠ.
8ꙋⷠ҇.
8ꙋⷡ.
8ꙋⷡ҇.
8ꙋⷢ.
8ꙋⷢ҇.
8ꙋⷣ.
8ꙋⷣ҇.
8ꙋⷤ.
8ꙋⷤ҇.
8ꙋⷥ.
8ꙋⷥ҇.
8ꙋⷦ.
8ꙋⷦ҇.
2ꙋ2ⷧ
8ꙋⷧ.
8ꙋⷧ҇.
8ꙋⷨ.
8ꙋⷨ҇.
2ꙋ2ⷩ
8ꙋⷩ.
8ꙋⷩ҇.
8ꙋⷪ.
8ꙋⷪ҇.
8ꙋⷫ.
8ꙋⷫ҇.
8ꙋⷬ.
8ꙋⷬ҇.
8ꙋⷭ.
8ꙋⷭ҇.
8ꙋⷮ.
8ꙋⷮ҇.
2ꙋ2ⷯ
8ꙋⷯ.
8ꙋⷯ҇.
8ꙋⷰ.
8ꙋⷰ҇.
8ꙋⷱ.
8ꙋⷱ҇.
8ꙋⷲ.
8ꙋⷲ҇.
8ꙋⷳ.
8ꙋⷳ҇.
8ꙋⷴ.
8ꙋⷴ҇.
8ꙋⷵ.
8ꙋⷵ҇.
8ꙋⷶ.
8ꙋⷶ҇.
8ꙋⷷ.
8ꙋⷷ҇.
8ꙋⷸ.
8ꙋⷸ҇.
8ꙋⷹ.
8ꙋⷹ҇.
8ꙋⷺ.
8ꙋⷺ҇.
8ꙋⷻ.
8ꙋⷻ҇.
8ꙋⷼ.
8ꙋⷼ҇.
8ꙋⷽ.
8ꙋⷽ҇.
8ꙋⷾ.
8ꙋⷾ҇.
8ꙋⷿ.
8ꙋⷿ҇.
8ꙋꙴ.
8ꙋꙴ҇.
8ꙋꙵ.
8ꙋꙵ҇.
8ꙋꙶ.
8ꙋꙶ҇.
8ꙋꙷ.
8ꙋꙷ҇.
8ꙋꙸ.
8ꙋꙸ҇.
8ꙋꙹ.
8ꙋꙹ҇.
8ꙋꙺ.
8ꙋꙺ҇.
8ꙋꙻ.
8ꙋꙻ҇.
8ꙋ꙼.
8ꙋ꙼҇.
8ꙋ꙽.
8ꙋ꙽҇.
8ꙍ.
8ꙍ̀8.
8ꙍ́8.
8ꙍ̈8.
8ꙍ̑8.
8ꙍ҆̀8.
8ꙍ҆́8.
8ꙍ҆̈8.
8ꙍ҆̑8.
8ꙍ҆̑̀8.
8ꙍ҆̑́8.
8ꙍ҆̑̈8.
8ꙍ҆̑̑8.
ꙍ҆̑1л
8ꙍ҆̑҆̀8.
8ꙍ҆̑҆́8.
8ꙍ҆̑҆̈8.
8ꙍ҆̑҆̑8.
8ꙍ҆̑ⷠ.
8ꙍ҆̑ⷠ҇.
8ꙍ҆̑ⷡ.
8ꙍ҆̑ⷡ҇.
8ꙍ҆̑ⷢ.
8ꙍ҆̑ⷢ҇.
8ꙍ҆̑ⷣ.
8ꙍ҆̑ⷣ҇.
8ꙍ҆̑ⷤ.
8ꙍ҆̑ⷤ҇.
8ꙍ҆̑ⷥ.
8ꙍ҆̑ⷥ҇.
8ꙍ҆̑ⷦ.
8ꙍ҆̑ⷦ҇.
8ꙍ҆̑ⷧ.
8ꙍ҆̑ⷧ҇.
8ꙍ҆̑ⷨ.
8ꙍ҆̑ⷨ҇.
8ꙍ҆̑ⷩ.
8ꙍ҆̑ⷩ҇.
8ꙍ҆̑ⷪ.
8ꙍ҆̑ⷪ҇.
8ꙍ҆̑ⷫ.
8ꙍ҆̑ⷫ҇.
8ꙍ҆̑ⷬ.
8ꙍ҆̑ⷬ҇.
8ꙍ҆̑ⷭ.
8ꙍ҆̑ⷭ҇.
8ꙍ҆̑ⷮ.
8ꙍ҆̑ⷮ҇.
8ꙍ҆̑ⷯ.
8ꙍ҆̑ⷯ҇.
8ꙍ҆̑ⷰ.
8ꙍ҆̑ⷰ҇.
8ꙍ҆̑ⷱ.
8ꙍ҆̑ⷱ҇.
8ꙍ҆̑ⷲ.
8ꙍ҆̑ⷲ҇.
8ꙍ҆̑ⷳ.
8ꙍ҆̑ⷳ҇.
8ꙍ҆̑ⷴ.
8ꙍ҆̑ⷴ҇.
8ꙍ҆̑ⷵ.
8ꙍ҆̑ⷵ҇.
8ꙍ҆̑ⷶ.
8ꙍ҆̑ⷶ҇.
8ꙍ҆̑ⷷ.
8ꙍ҆̑ⷷ҇.
8ꙍ҆̑ⷸ.
8ꙍ҆̑ⷸ҇.
8ꙍ҆̑ⷹ.
8ꙍ҆̑ⷹ҇.
8ꙍ҆̑ⷺ.
8ꙍ҆̑ⷺ҇.
8ꙍ҆̑ⷻ.
8ꙍ҆̑ⷻ҇.
8ꙍ҆̑ⷼ.
8ꙍ҆̑ⷼ҇.
8ꙍ҆̑ⷽ.
8ꙍ҆̑ⷽ҇.
8ꙍ҆̑ⷾ.
8ꙍ҆̑ⷾ҇.
8ꙍ҆̑ⷿ.
8ꙍ҆̑ⷿ҇.
8ꙍ҆̑ꙴ.
8ꙍ҆̑ꙴ҇.
8ꙍ҆̑ꙵ.
8ꙍ҆̑ꙵ҇.
8ꙍ҆̑ꙶ.
8ꙍ҆̑ꙶ҇.
8ꙍ҆̑ꙷ.
8ꙍ҆̑ꙷ҇.
8ꙍ҆̑ꙸ.
8ꙍ҆̑ꙸ҇.
8ꙍ҆̑ꙹ.
8ꙍ҆̑ꙹ҇.
8ꙍ҆̑ꙺ.
8ꙍ҆̑ꙺ҇.
8ꙍ҆̑ꙻ.
8ꙍ҆̑ꙻ҇.
8ꙍ҆̑꙼.
8ꙍ҆̑꙼҇.
8ꙍ҆̑꙽.
8ꙍ҆̑꙽҇.
8ꙍⷠ.
8ꙍⷠ҇.
8ꙍⷡ.
8ꙍⷡ҇.
8ꙍⷢ.
8ꙍⷢ҇.
8ꙍⷣ.
8ꙍⷣ҇.
8ꙍⷤ.
8ꙍⷤ҇.
8ꙍⷥ.
8ꙍⷥ҇.
8ꙍⷦ.
8ꙍⷦ҇.
8ꙍⷧ.
8ꙍⷧ҇.
8ꙍⷨ.
8ꙍⷨ҇.
8ꙍⷩ.
8ꙍⷩ҇.
8ꙍⷪ.
8ꙍⷪ҇.
8ꙍⷫ.
8ꙍⷫ҇.
8ꙍⷬ.
8ꙍⷬ҇.
8ꙍⷭ.
8ꙍⷭ҇.
8ꙍⷮ.
8ꙍⷮ҇.
8ꙍⷯ.
8ꙍⷯ҇.
8ꙍⷰ.
8ꙍⷰ҇.
8ꙍⷱ.
8ꙍⷱ҇.
8ꙍⷲ.
8ꙍⷲ҇.
8ꙍⷳ.
8ꙍⷳ҇.
8ꙍⷴ.
8ꙍⷴ҇.
8ꙍⷵ.
8ꙍⷵ҇.
8ꙍⷶ.
8ꙍⷶ҇.
8ꙍⷷ.
8ꙍⷷ҇.
8ꙍⷸ.
8ꙍⷸ҇.
8ꙍⷹ.
8ꙍⷹ҇.
8ꙍⷺ.
8ꙍⷺ҇.
8ꙍⷻ.
8ꙍⷻ҇.
8ꙍⷼ.
8ꙍⷼ҇.
8ꙍⷽ.
8ꙍⷽ҇.
8ꙍⷾ.
8ꙍⷾ҇.
8ꙍⷿ.
8ꙍⷿ҇.
8ꙍꙴ.
8ꙍꙴ҇.
8ꙍꙵ.
8ꙍꙵ҇.
8ꙍꙶ.
8ꙍꙶ҇.
8ꙍꙷ.
8ꙍꙷ҇.
8ꙍꙸ.
8ꙍꙸ҇.
8ꙍꙹ.
8ꙍꙹ҇.
8ꙍꙺ.
8ꙍꙺ҇.
8ꙍꙻ.
8ꙍꙻ҇.
8ꙍ꙼.
8ꙍ꙼҇.
8ꙍ꙽.
8ꙍ꙽҇.
8ꙗ.
8ꙗ̀8.
8ꙗ́8.
8ꙗ̈8.
8ꙗ̑8.
ꙗ1в
ꙗви́1
ꙗ҆̀1
8ꙗ҆̀8.
8ꙗ҆́8.
ꙗ҆́1м
ꙗ҆́1р
8ꙗ҆̈8.
8ꙗ҆̑8.
ꙗ҆1з2
ꙗ҆1п
ꙗ҆1р
ꙗ҆1с2
8ꙗⷠ.
8ꙗⷠ҇.
8ꙗⷡ.
8ꙗⷡ҇.
8ꙗⷢ.
8ꙗⷢ҇.
8ꙗⷣ.
8ꙗⷣ҇.
8ꙗⷤ.
8ꙗⷤ҇.
8ꙗⷥ.
8ꙗⷥ҇.
8ꙗⷦ.
8ꙗⷦ҇.
8ꙗⷧ.
8ꙗⷧ҇.
8ꙗⷨ.
8ꙗⷨ҇.
8ꙗⷩ.
8ꙗⷩ҇.
8ꙗⷪ.
8ꙗⷪ҇.
8ꙗⷫ.
8ꙗⷫ҇.
8ꙗⷬ.
8ꙗⷬ҇.
8ꙗⷭ.
8ꙗⷭ҇.
8ꙗⷮ.
8ꙗⷮ҇.
8ꙗⷯ.
8ꙗⷯ҇.
8ꙗⷰ.
8ꙗⷰ҇.
8ꙗⷱ.
8ꙗⷱ҇.
8ꙗⷲ.
8ꙗⷲ҇.
8ꙗⷳ.
8ꙗⷳ҇.
8ꙗⷴ.
8ꙗⷴ҇.
8ꙗⷵ.
8ꙗⷵ҇.
8ꙗⷶ.
8ꙗⷶ҇.
8ꙗⷷ.
8ꙗⷷ҇.
8ꙗⷸ.
8ꙗⷸ҇.
8ꙗⷹ.
8ꙗⷹ҇.
8ꙗⷺ.
8ꙗⷺ҇.
8ꙗⷻ.
8ꙗⷻ҇.
8ꙗⷼ.
8ꙗⷼ҇.
8ꙗⷽ.
8ꙗⷽ҇.
8ꙗⷾ.
8ꙗⷾ҇.
8ꙗⷿ.
8ꙗⷿ҇.
8ꙗꙴ.
8ꙗꙴ҇.
8ꙗꙵ.
8ꙗꙵ҇.
8ꙗꙶ.
8ꙗꙶ҇.
8ꙗꙷ.
8ꙗꙷ҇.
8ꙗꙸ.
8ꙗꙸ҇.
8ꙗꙹ.
8ꙗꙹ҇.
8ꙗꙺ.
8ꙗꙺ҇.
8ꙗꙻ.
8ꙗꙻ҇.
8ꙗ꙼.
8ꙗ꙼҇.
8ꙗ꙽.
8ꙗ꙽҇.
8ꙴ
8ꙵ
8ꙶ
8ꙷ
8ꙸ
8ꙹ
8ꙺ
8ꙻ
8꙼
8꙽
8꙾8
8ꙿ8
8︦8
8︮8
8︯8
}
\hyphenation{
є҆ѵел-пі́стъ
жа́-тва
жа́-твꙋ
жа́-твы
кел-сі́й
кел-сі́й
кле-о-па́-тра
ло-ви́-тва
ло-ви́-твꙋ
ло-ви́-твы
мї-ли́с-сенъ
мї-ли́с-сенъ
ѿ-нн҃ѣ
па́-сцѣ
пре-вы́-спрєн-нѧѧ
рас-пнѝ
сїл-ве́-стрꙋ
сїл-ве́-стрꙋ
ѹ҆-сте́нъ
ᲂу҆-сте́нъ
}

